<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
                exclude-result-prefixes="msxsl cs">

  <msxsl:script language="C#" implements-prefix="cs">
    <![CDATA[
      public string Replace(System.String str, System.String dlm){
        return str.Replace("{0}", dlm);
     }
     
      public string StrToLower(System.String str){
        return str.ToLower();
     }
    
     public string Split(System.String str, System.String dlm){
        String[] strs;
        string[] delimiter = { "%,%"};

        strs = str.Split(delimiter, StringSplitOptions.None);
        StringBuilder sb = new StringBuilder();
        foreach(var s in strs){
          if(!string.IsNullOrEmpty(s))
          sb.AppendFormat("{0}{1}", s, dlm);
        }
        
        return sb.ToString();
     }
      
     public string TimeDiff(System.String device, System.String master)
     {
       DateTime dev = DateTime.Parse(device);
       DateTime mst = DateTime.Parse(master);
       TimeSpan diff = mst - dev;
       return diff.ToString();
     }
     
     public string GetAppName(string id, string device, XPathNodeIterator appnode)
     {
        return GetAppName(id, device, appnode, "");
     }
     
     public string GetAppName(string id, string device, XPathNodeIterator appnode, string typestr)
     {
        if(appnode.MoveNext()){
          XPathNavigator navi = appnode.Current;
          string apppath = string.Format(@"//Application[./CFBundleIdentifier = '{0}']/CFBundleDisplayName", id);
          XPathNodeIterator ite = (XPathNodeIterator)navi.Evaluate(apppath);
          if(ite.MoveNext()){
            return ite.Current.Value;
          }else{
            return DefaultApp(id, "", device, typestr);
          }
        }
        return id;
     }
     
	 public string FlagOn(System.String device, System.String bit)
     {
       int dev = int.Parse(device);
       int flag = int.Parse(bit);
       if((dev & flag) == flag)
		return "true";
       else
		return "false";
     }
	 
     public string DefaultApp(string id, string name, string device, string typestr)
        {
          if(!string.IsNullOrEmpty(name))
            return name;
            
            switch (id)
            {
                case "com.apple.mobilesafari":
                  if(typestr == "locationservice")
                    return "Safariのサイト";
                  else
                    return "Safari";

                case "com.apple.mobilemail":
                    return "メール";

                case "com.apple.mobilecal":
                    return "カレンダー";

                case "com.apple.mobileslideshow":
                    return "写真";

                case "com.apple.camera":
                    return "カメラ";

                case "com.apple.videos":
                    return "ビデオ";
                    
                    case "com.apple.tv":
                    return "TV";

                case "com.apple.youtube":
                    return "YouTube";

                case "com.apple.Maps":
                    return "マップ";

                case "com.apple.weather":
                    return "天気";

                case "com.apple.mobilenotes":
                    return "メモ";

                case "com.apple.mobileipod":
                    return "ミュージック";
                    
                 case "com.apple.Music":
                    return "ミュージック";

                case "com.apple.MobileStore":
                    return "iTunes Store";

                case "com.apple.AppStore":
                    return "App Store";
                    
                case "com.apple.podcasts":
                    return "Podcast";

                case "com.apple.Preferences":
                    return "設定";

                case "com.apple.gamecenter":
                    return "Game Center";

                case "com.apple.MobileAddressBook":
                    return "連絡先";

                case "com.apple.reminders":
                    return "リマインダー";

                case "com.apple.MobileSMS":
                    return "メッセージ";

                case "com.apple.mobiletimer":
                    return "時計";

                case "com.apple.Photo-Booth":
                    return "Photo Booth";

                case "com.apple.mobilephone":
                    if (device == "iPad")
                        return "FaceTime";
                    else
                        return "電話";
                case "com.apple.facetime":
                        return "FaceTime";
                case "com.apple.VoiceMemos":
                    return "ボイスメモ";

                case "com.apple.calculator":
                    return "計算機";

                case "com.apple.Shoebox":
                    return "Wallet";

                case "com.apple.compass":
                    return "コンパス";

                case "com.apple.stocks":
                    return "株価";

                case "com.apple.Passbook":
                    return "Wallet";
                    
                case "com.apple.iBooks":
                    return "ブック";
                    
                case "com.apple.Health":
                    return "ヘルスケア";
                    
                case "com.apple.Bridge":
                    return "Watch";
                                    
                case "com.apple.tips":
                    return "ヒント";
                    
                case "com.apple.mobileme.fmf1":
                    return "友達を探す";
                    
                case "com.apple.mobileme.fmip1":
                    if (device == "iPad")
                        return "iPhoneを探す";
                    else
                        return "iPhoneを探す";
                        
                case "com.apple.findmy":
                    return "探す";
                    
                case "com.apple.shortcuts":
                    return "ショートカット";
                    
                case "com.apple.appleseed.FeedbackAssistant":
                    return "Feedback";
                        
                case "DOMAIN_PARSEC":
                    return "Spotlightの検索候補";
                case "DOMAIN_WEBSEARCH":
                    return "BingのWeb検索結果";
                    
                case "com.apple.iCloudDriveApp":
                    return "iCloud Drive";
                    
                case "com.apple.Home":
                    return "ホーム";
                    
                case "com.apple.locationd.bundle-/System/Library/PrivateFrameworks/AssistantServices.framework":
                    return "Siriと音声入力";
                    
                case "com.apple.locationd.bundle-/System/Library/PrivateFrameworks/PassKitCore.framework":
                    return "Wallet";
                    
                case "com.apple.locationd.bundle-/System/Library/LocationBundles/ClipServicesLocation.bundle":
                    return "App Clip";
                    
                case "com.apple.DocumentsApp":
                    return "ファイル";
                    
                case "com.apple.news":
                    return "News";
					
				case "com.apple.Translate":
                    return "翻訳";
					
				case "com.apple.measure":
                    return "計測";
					
				case "com.apple.ScreenTimeNotifications":
                    return "スクリーンタイム";
                    
				case "com.apple.mobilecal.bulletin-subsection.upcomingEvents":
                    return "カレンダー（もうすぐ行われるイベント）";
					
				case "com.apple.mobilecal.bulletin-subsection.invitations":
                    return "カレンダー（参加依頼）";
				
				case "com.apple.mobilecal.bulletin-subsection.Responses":
                    return "カレンダー（予定出席者の回答）";
					
				case "com.apple.mobilecal.bulletin-subsection.resourceChanges":
                    return "カレンダー（共有カレンダーの変更）";
					
				case "com.apple.mobilecal.bulletin-subsection.suggestions":
                    return "カレンダー（SiriがAppで検出）";
					
				case "com.apple.mobileslideshow.memories":
                    return "写真（メモリー）";
				
				case "com.apple.mobileslideshow.iCloudPhotoSharing":
                    return "写真（共有アルバム）";
					
				case "com.apple.mobileslideshow.SharingSuggestions":
                    return "写真（共有の提案）";
					
				case "com.apple.tv.bulletins.explicit":
                    return "TV（次に観る）";
				
				case "com.apple.tv.bulletins.marketing":
                    return "TV（新機能）";
					
                default:
                    return id;
            }
        }
        
      ]]>
  </msxsl:script>
  
  <!--時間-->
  <xsl:template name="Second2Time">
    <xsl:param name="second" select="1"/>
    <xsl:choose>
      <xsl:when test="number($second) div 60 &lt; 60"><xsl:value-of select="number($second) div 60"/>分</xsl:when>
      <xsl:when test="number($second) div 3600 &gt;= 1"><xsl:value-of select="number($second) div 3600"/>時間</xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="min2hour">
    <xsl:param name="min"/>
    <xsl:choose>
      <xsl:when test="not($min) or $min=''">設定なし</xsl:when>
      <xsl:when test="$min='0'">即時</xsl:when>
      <xsl:when test="$min='60'">1分後</xsl:when>
      <xsl:when test="$min='300'">5分後</xsl:when>
      <xsl:when test="$min='900'">15分後</xsl:when>
      <xsl:when test="$min='3600'">1時間後</xsl:when>
      <xsl:when test="$min='14400'">4時間後</xsl:when>
      <xsl:otherwise>不正な値</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="MailBoxPlace">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = 'true'">サーバ上</xsl:when>
      <xsl:when test="$value = 'false'">デバイス上</xsl:when>
      <xsl:when test="$value = ''">デバイス上</xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="days2">
    <xsl:param name="day"/>
    <xsl:choose>
      <xsl:when test="$day = '1'">1日後</xsl:when>
      <xsl:when test="$day = '7'">1週間後</xsl:when>
      <xsl:when test="$day = '30'">1カ月後</xsl:when>
      <xsl:when test="not($day)"></xsl:when>
      <xsl:otherwise>しない</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--スライダーで表示されているもの-->
  <!--lengthの数縦棒を表示-->
  <xsl:template name="slider">
    <xsl:param name="length" select="1"/>
    <xsl:if test="$length > 0">
      <xsl:text>|</xsl:text>
      <xsl:call-template name="slider">
        <xsl:with-param name="length" select="$length - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  <xsl:template name="slider2">
    <xsl:param name="position" select="1"/>
    <xsl:param name="length" select="1"/>
    <xsl:call-template name="slider">
      <xsl:with-param name="length" select="$position - 1"/>
    </xsl:call-template>
    <font color="red">|</font>
    <xsl:call-template name="slider">
      <xsl:with-param name="length" select="$length - $position"/>
    </xsl:call-template>
  </xsl:template>


  <xsl:template name="slider3">
    <xsl:param name="position" select="1"/>
    <xsl:param name="default" select="0"/>
    <xsl:param name="length" select="48"/>
    <xsl:param name="range" select="1" />
    <xsl:variable name="_position">
      <xsl:choose>
        <xsl:when test="not($position) or $position=''">
          <xsl:value-of select="$default"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$position"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="_tmp">
      <xsl:choose>
        <xsl:when test="$range = '2'">
          <xsl:value-of select="(number($_position) +1 ) * $length div 2"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="(number($_position) ) * $length"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="pos" select="number($_tmp)"/>
    <xsl:if test="$pos &gt; 0">
      <font color="red">
        <xsl:call-template name="slider">
          <xsl:with-param name="length" select="$pos"/>
        </xsl:call-template>
      </font>
    </xsl:if>
    <xsl:call-template name="slider">
      <xsl:with-param name="length" select="$length - $pos"/>
    </xsl:call-template>
  </xsl:template>


  <!-- パーセント表示 -->
  <xsl:template name="slider4">
    <xsl:param name="position" />
    <xsl:param name="range" select="1"/>
    <xsl:param name="default" select="1"/>
    <xsl:choose>
      <xsl:when test="$position != ''">
        <xsl:choose>
          <xsl:when test="$range = 1"><xsl:value-of select="ceiling(number($position)*100) "/>%</xsl:when>
          <xsl:when test="$range = 2"><xsl:value-of select="ceiling((number($position)+1)*50) "/>%</xsl:when>
          <xsl:otherwise><xsl:value-of select="$position"/></xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:choose>
          <xsl:when test="$range = 1"><xsl:value-of select="ceiling(number($default) *100)"/>%</xsl:when>
          <xsl:when test="$range = 2"><xsl:value-of select="ceiling((number($default) +1) *50)"/>%</xsl:when>
          <xsl:otherwise><xsl:value-of select="$position"/></xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template name="slider5">
    <xsl:param name="position" select="1"/>
    <xsl:param name="default" select="0"/>
    <xsl:param name="length" select="48"/>
    <xsl:param name="min" select="0" />
    <xsl:param name="max" select="1" />
    <xsl:variable name="_position">
      <xsl:choose>
        <xsl:when test="not($position) or $position=''">
          <xsl:value-of select="$default"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$position"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="_tmp">
          <xsl:value-of select="(number($_position) - $min) * $length div ($max - $min)"/>
    </xsl:variable>
    <xsl:variable name="pos" select="number($_tmp)"/>
    <xsl:if test="$pos &gt; 0">
      <font color="red">
        <xsl:call-template name="slider">
          <xsl:with-param name="length" select="$pos"/>
        </xsl:call-template>
      </font>
    </xsl:if>
    <xsl:call-template name="slider">
      <xsl:with-param name="length" select="$length - $pos"/>
    </xsl:call-template>
  </xsl:template>
  
  <!--キャリア-->
  <xsl:template name="Network">
    <xsl:param name="country" select="1"/>
    <xsl:param name="network" select="1"/>
    <xsl:choose>
      <xsl:when test="$country ='440'">
        <xsl:choose>
          <xsl:when test="$network ='00'">EMOBILE</xsl:when>
          <xsl:when test="$network ='10'">NTT DOCOMO</xsl:when>
          <xsl:when test="$network ='20'">SoftBank</xsl:when>
          <xsl:when test="$network ='50'">KDDI</xsl:when>
          <xsl:when test="$network ='54'">KDDI</xsl:when>
          <xsl:otherwise>不明</xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>不明</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="NetworkCarrier">
    <xsl:param name="carrier" select="1"/>
    <xsl:choose>
      <xsl:when test="$carrier ='Softbank_jp'">ソフトバンク</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$carrier"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--認証方式-->
  <xsl:template name="AuthenticationScheme">
    <xsl:param name="scheme"/>
    <xsl:choose>
      <xsl:when test="$scheme ='ATOKEN'">Appleトークン</xsl:when>
      <xsl:when test="$scheme ='CRAM-MD5'">MD5チャレンジ応答</xsl:when>
      <xsl:when test="$scheme ='NTLM'">NTLM</xsl:when>
      <xsl:when test="$scheme ='DIGEST-MD5'">HTTP MD5 Digest</xsl:when>
      <xsl:otherwise>パスワード</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--キーボードの言語-->
  <xsl:template name ="keyboard_sw">
    <xsl:param name="key"/>
    <xsl:choose>
      <xsl:when test="$key = 'ja_JP-Kana' and $MajorVersion &lt; 14">かな</xsl:when>
	  <xsl:when test="$key = 'ja_JP-Kana' and $MajorVersion &gt;= 14">かな入力</xsl:when>
	  <xsl:when test="contains($key,'sw=Kana') and $MajorVersion &lt; 14">かな</xsl:when>
      <xsl:when test="contains($key,'sw=Kana') and $MajorVersion &gt;= 14">かな入力</xsl:when>
      <xsl:when test="$key = 'ja_JP-Romaji' and $MajorVersion &lt; 14">ローマ字</xsl:when>
	  <xsl:when test="$key = 'ja_JP-Romaji' and $MajorVersion &gt;= 14">ローマ字入力</xsl:when>
      <xsl:when test="contains($key,'sw=QWERTY-Japanese') and $MajorVersion &lt; 14">ローマ字</xsl:when>
	  <xsl:when test="contains($key,'sw=QWERTY-Japanese') and $MajorVersion &gt;= 14">ローマ字入力</xsl:when>
      <xsl:when test="$key = 'en_US'">QWERTY</xsl:when>
      <xsl:when test="contains($key,'sw=QWERTY-JIS')">QWERTY-JIS</xsl:when>
      <xsl:when test="contains($key,'sw=QWERTY')">QWERTY</xsl:when>
      <xsl:when test="contains($key,'sw=AZERTY')">AZERTY</xsl:when>
      <xsl:when test="contains($key,'sw=QWERTZ')">QWERTZ</xsl:when>
      <xsl:when test="contains($key,'sw=HWR')">手書き</xsl:when>
      <xsl:when test="contains($key,'sw=Icelandic')">アイスランド語</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name ="keyboard_hw">
    <xsl:param name="key"/>
    <xsl:choose>
      <xsl:when test="$key = 'ja_JP-Kana'">U.S.</xsl:when>
      <xsl:when test="contains($key,'hw=KANA')">かな入力</xsl:when>
      <xsl:when test="$key = 'ja_JP-Romaji'">U.S.</xsl:when>
      <xsl:when test="contains($key,'hw=USInternational-PC')">U.S.(インターナショナル)-PC</xsl:when>
      <xsl:when test="$key = 'en_US'">U.S.</xsl:when>
      <xsl:when test="contains($key,'hw=US')">U.S.</xsl:when>
      <xsl:when test="contains($key,'hw=Icelandic')">アイスランド語</xsl:when>
      <xsl:when test="contains($key,'hw=Macedonian')">マケドニア語</xsl:when>
      <xsl:when test="contains($key,'hw=British')">英語（イギリス）</xsl:when>
    </xsl:choose>
  </xsl:template>


  <xsl:template name ="keyboard_kana">
    <xsl:param name="key"/>
    <xsl:choose>
      <xsl:when test="not($key)"></xsl:when>
      <xsl:when test="$key = ''"></xsl:when>
      <xsl:when test="contains($key,'-Flick')">オン</xsl:when>
      <xsl:otherwise>オフ</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name ="keyboard_kanaRTL">
    <xsl:param name="key"/>
    <xsl:choose>
      <xsl:when test="not($key)"></xsl:when>
      <xsl:when test="$key = ''"></xsl:when>
      <xsl:when test="contains($key,'-RTL')">オフ</xsl:when>
      <xsl:otherwise>オン</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="language">
    <xsl:param name="countrycode" select="1"/>
    <xsl:choose>
      <xsl:when test="$countrycode='emoji'">絵文字</xsl:when>
      <xsl:when test="$countrycode='ja_JP'">日本語</xsl:when>
      <xsl:when test="$countrycode='ja_JP-Romaji'">日本語</xsl:when>
      <xsl:when test="$countrycode='ja_JP-Kana'">日本語</xsl:when>
      <xsl:when test="$countrycode='en_JP'">英語(日本)</xsl:when>
      <xsl:when test="$countrycode='en_US'">英語</xsl:when>
      <xsl:when test="$countrycode='is_IS'">アイスランド語</xsl:when>
      <xsl:when test="$countrycode='it_IT'">イタリア語</xsl:when>
      <xsl:when test="$countrycode='uk_UA'">ウクライナ語</xsl:when>
      <xsl:when test="$countrycode='et_EE'">エストニア語</xsl:when>
      <xsl:when test="$countrycode='ar'">アラビア語</xsl:when>
      <xsl:when test="$countrycode='id_ID'">インドネシア語</xsl:when>
      <xsl:when test="$countrycode='nl_NL'">オランダ語</xsl:when>
      <xsl:when test="$countrycode='ca_ES'">カタロニア語</xsl:when>
      <xsl:when test="$countrycode='el_GR'">ギリシャ語</xsl:when>
      <xsl:when test="$countrycode='hr_HR'">クロアチア語</xsl:when>
      <xsl:when test="$countrycode='sv_SE'">スウェーデン語</xsl:when>
      <xsl:when test="$countrycode='es_ES'">スペイン語</xsl:when>
      <xsl:when test="$countrycode='sk_SK'">スロバキア語</xsl:when>
      <xsl:when test="$countrycode='sr_Cyrl'">セルビア語</xsl:when>
      <xsl:when test="$countrycode='sr_Latn'">セルビア語(ラテン文字)</xsl:when>
      <xsl:when test="$countrycode='th_TH'">タイ語</xsl:when>
      <xsl:when test="$countrycode='cs_CZ'">チェコ語</xsl:when>
      <xsl:when test="$countrycode='chr'">チェロキー語</xsl:when>
      <xsl:when test="$countrycode='bo'">チベット語</xsl:when>
      <xsl:when test="$countrycode='da_DK'">デンマーク語</xsl:when>
      <xsl:when test="$countrycode='de_CH'">ドイツ語(スイス)</xsl:when>
      <xsl:when test="$countrycode='de_DE'">ドイツ語(ドイツ)</xsl:when>
      <xsl:when test="$countrycode='tr_TR'">トルコ語</xsl:when>
      <xsl:when test="$countrycode='nb_NO'">ノルウェー語</xsl:when>
      <xsl:when test="$countrycode='haw'">ハワイ語</xsl:when>
      <xsl:when test="$countrycode='hu_HU'">ハンガリー語</xsl:when>
      <xsl:when test="$countrycode='hi'">ヒンディー語</xsl:when>
      <xsl:when test="$countrycode='fi_FI'">フィンランド語</xsl:when>
      <xsl:when test="$countrycode='nl_BE'">フラマン語</xsl:when>
      <xsl:when test="$countrycode='fr_FR'">フランス語</xsl:when>
      <xsl:when test="$countrycode='fr_CA'">フランス語(カナダ)</xsl:when>
      <xsl:when test="$countrycode='fr_CH'">フランス語(スイス)</xsl:when>
      <xsl:when test="$countrycode='bg_BG'">ブルガリア語</xsl:when>
      <xsl:when test="$countrycode='vi_VN'">ベトナム語</xsl:when>
      <xsl:when test="$countrycode='he_IL'">ヘブライ語</xsl:when>
      <xsl:when test="$countrycode='pl_PL'">ポーランド語</xsl:when>
      <xsl:when test="$countrycode='pt_BR'">ポルトガル語(ブラジル)</xsl:when>
      <xsl:when test="$countrycode='pt_PT'">ポルトガル語(ポルトガル)</xsl:when>
      <xsl:when test="$countrycode='mk_MK'">マケドニア語</xsl:when>
      <xsl:when test="$countrycode='ms_MY'">マレー語</xsl:when>
      <xsl:when test="$countrycode='lv_LV'">ラトビア語</xsl:when>
      <xsl:when test="$countrycode='lt_LT'">リトアニア語</xsl:when>
      <xsl:when test="$countrycode='ro_RO'">ルーマニア語</xsl:when>
      <xsl:when test="$countrycode='ru_RU'">ロシア語</xsl:when>
      <xsl:when test="$countrycode='en_GB'">英語(イギリス)</xsl:when>
      <xsl:when test="$countrycode='en_AU'">英語(オーストラリア)</xsl:when>
      <xsl:when test="$countrycode='en_CA'">英語(カナダ)</xsl:when>
      <xsl:when test="$countrycode='ko_KO'">韓国語</xsl:when>
      <xsl:when test="$countrycode='zh_Hans-HWR'">中国語-簡体字</xsl:when>
      <xsl:when test="$countrycode='zh_Hans-Pinyin'">中国語-簡体字</xsl:when>
      <xsl:when test="$countrycode='zh_Hans-Wubihua'">中国語-簡体字</xsl:when>
      <xsl:when test="$countrycode='zh_Hant-HWR'">中国語-繁体字</xsl:when>
      <xsl:when test="$countrycode='zh_Hant-Pinyin'">中国語-繁体字</xsl:when>
      <xsl:when test="$countrycode='zh_Hant-Cangjie'">中国語-繁体字</xsl:when>
      <xsl:when test="$countrycode='zh_Hant-Wubihua'">中国語-繁体字</xsl:when>
      <xsl:when test="$countrycode='zh_Hant-Zhuyin'">中国語-繁体字</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$countrycode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!--言語ローターの言語-->
  <!--言語環境の言語と一部異なる-->
  <xsl:template name="language2">
    <xsl:param name="countrycode" select="1"/>
    <xsl:choose>
      <xsl:when test="$countrycode='fr-CA'">Français canadian</xsl:when>
      <xsl:when test="$countrycode='nl-BE'">Nederlands (Belgisch)</xsl:when>
      <xsl:when test="$countrycode='en-US'">English</xsl:when>
      <xsl:when test="$countrycode='en-GB'">English (UK)</xsl:when>
      <xsl:when test="$countrycode='en-AU'">English (Australia)</xsl:when>
      <xsl:when test="$countrycode='en-JP'">英語</xsl:when>
      <xsl:when test="$countrycode='pt-BR'">Portugués (Brasil)</xsl:when>
      <xsl:when test="$countrycode='es-MX'">Español (Mexico)</xsl:when>
      <xsl:when test="$countrycode='pt-PT'">Portugués (Portugal)</xsl:when>
      <xsl:when test="$countrycode='nb'">Norsk (Bokmål)</xsl:when>
      <xsl:when test="$countrycode='ms'">Bahasa Melayu</xsl:when>
      <xsl:when test="$countrycode='cs'">Čeština</xsl:when>
      <xsl:when test="$countrycode='da'">Dansk</xsl:when>
      <xsl:when test="$countrycode='nl'">Nederlands</xsl:when>
      <xsl:when test="$countrycode='fi'">Suomi</xsl:when>
      <xsl:when test="$countrycode='fr'">Français</xsl:when>
      <xsl:when test="$countrycode='de'">Deutsch</xsl:when>
      <xsl:when test="$countrycode='el'">Ελληνικά</xsl:when>
      <xsl:when test="$countrycode='hi'">हिन्दी</xsl:when>
      <xsl:when test="$countrycode='hu'">Magyar</xsl:when>
      <xsl:when test="$countrycode='id'">Bahasa Indonesia</xsl:when>
      <xsl:when test="$countrycode='it'">Italiano</xsl:when>
      <xsl:when test="$countrycode='ja'">日本語</xsl:when>
      <xsl:when test="$countrycode='ja-JP'">日本語</xsl:when>
	  <xsl:when test="contains($countrycode,'ja-')">日本語</xsl:when>
      <xsl:when test="$countrycode='ko'">한국어</xsl:when>
      <xsl:when test="$countrycode='pl'">Polski</xsl:when>
      <xsl:when test="$countrycode='ro'">Română</xsl:when>
      <xsl:when test="$countrycode='ru'">Русский</xsl:when>
      <xsl:when test="$countrycode='sk'">Slovenčina</xsl:when>
      <xsl:when test="$countrycode='es'">Español</xsl:when>
      <xsl:when test="$countrycode='sv'">Svenska</xsl:when>
      <xsl:when test="$countrycode='th'">ภาษาไทย</xsl:when>
      <xsl:when test="$countrycode='tr'">Türkçe</xsl:when>
      <xsl:when test="$countrycode='ar'">اللغة العربية</xsl:when>
      <xsl:when test="$countrycode='zh-HK'">中文 (廣東話)</xsl:when>
      <xsl:when test="$countrycode='zh-CN'">中文 (中国)</xsl:when>
      <xsl:when test="$countrycode='zh-TW'">中文 (台灣)</xsl:when>
      <xsl:when test="$countrycode='en-IE'">Irish English</xsl:when>
      <xsl:when test="$countrycode='en-ZA'">South African English</xsl:when>
      <xsl:when test="$countrycode='en-UK'">UK English</xsl:when>
      <xsl:when test="$countrycode='zh-Hans'">中文 (簡体字)</xsl:when>
      <xsl:when test="$countrycode='zh-Hant'">中文 (繁体字)</xsl:when>
      <xsl:when test="$countrycode='zh'">中文</xsl:when>
      <xsl:when test="$countrycode='en'">English</xsl:when>
      <xsl:when test="$countrycode='no'">Norsk</xsl:when>
      <xsl:when test="$countrycode='pt'">Portugués</xsl:when>
      <xsl:when test="$countrycode='vi'">Tiếng Việt</xsl:when>
      <xsl:when test="$countrycode='ca'">català</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$countrycode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- 音声コントロールSiri -->
  <xsl:template name="language3">
    <xsl:param name="countrycode" select="1"/>
    <xsl:choose>
      <xsl:when test="$countrycode='it-IT'">イタリア語</xsl:when>
      <xsl:when test="$countrycode='nl-NL'">オランダ語</xsl:when>
      <xsl:when test="$countrycode='el-GR'">ギリシャ語</xsl:when>
      <xsl:when test="$countrycode='sv-SE'">スウェーデン語</xsl:when>
      <xsl:when test="$countrycode='es-ES'">スペイン語(スペイン)</xsl:when>
      <xsl:when test="$countrycode='es-MX'">スペイン語(メキシコ)</xsl:when>
      <xsl:when test="$countrycode='da-DK'">デンマーク語</xsl:when>
      <xsl:when test="$countrycode='de-DE'">ドイツ語</xsl:when>
      <xsl:when test="$countrycode='nb-NO'">ノルウェー語</xsl:when>
      <xsl:when test="$countrycode='fi-FI'">フィンランド語</xsl:when>
      <xsl:when test="$countrycode='fr-FR'">フランス語(フランス)</xsl:when>
      <xsl:when test="$countrycode='fr-CA'">フランス語(カナダ)</xsl:when>
      <xsl:when test="$countrycode='pt-BR'">ポルトガル語(ブラジル)</xsl:when>
      <xsl:when test="$countrycode='pt-PT'">ポルトガル語(ポルトガル)</xsl:when>
      <xsl:when test="$countrycode='pl-PL'">ポーランド語</xsl:when>
      <xsl:when test="$countrycode='ru-RU'">ロシア語</xsl:when>
      <xsl:when test="$countrycode='zh-CH'">中国語(中国)</xsl:when>
      <xsl:when test="$countrycode='zh-TW'">中国語(台湾)</xsl:when>
      <xsl:when test="$countrycode='zh-HK'">中国語(広東語)</xsl:when>
      <xsl:when test="$countrycode='ja-JP'">日本語</xsl:when>
      <xsl:when test="$countrycode='en-US'">英語(アメリカ合衆国)</xsl:when>
      <xsl:when test="$countrycode='en-GB'">英語(イギリス)</xsl:when>
      <xsl:when test="$countrycode='en-AU'">英語(オーストラリア)</xsl:when>
      <xsl:when test="$countrycode='ko-KO'">韓国語</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$countrycode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--言語ISO639(書式)-->
  <xsl:template name="format">
    <xsl:param name="code" select="1"/>
    <xsl:choose>
      <xsl:when test="$code='aa'">アファル語</xsl:when>
      <xsl:when test="$code='ab'">アブハズ語</xsl:when>
      <xsl:when test="$code='af'">アフリカーンス語</xsl:when>
      <xsl:when test="$code='ak'">アカン語</xsl:when>
      <xsl:when test="$code='sq'">アルバニア語</xsl:when>
      <xsl:when test="$code='am'">アムハラ語</xsl:when>
      <xsl:when test="$code='ar'">アラビア語</xsl:when>
      <xsl:when test="$code='an'">アラゴン語</xsl:when>
      <xsl:when test="$code='hy'">アルメニア語</xsl:when>
      <xsl:when test="$code='as'">アッサム語</xsl:when>
      <xsl:when test="$code='av'">アヴァール語</xsl:when>
      <xsl:when test="$code='ae'">アヴェスター語</xsl:when>
      <xsl:when test="$code='ay'">アイマラ語</xsl:when>
      <xsl:when test="$code='az'">アゼルバイジャン語</xsl:when>
      <xsl:when test="$code='ba'">バシキール語</xsl:when>
      <xsl:when test="$code='bm'">バンバラ語</xsl:when>
      <xsl:when test="$code='eu'">バスク語</xsl:when>
      <xsl:when test="$code='be'">ベラルーシ語</xsl:when>
      <xsl:when test="$code='bn'">ベンガル語</xsl:when>
      <xsl:when test="$code='bh'">ビハール語</xsl:when>
      <xsl:when test="$code='bi'">ビスラマ語</xsl:when>
      <xsl:when test="$code='bs'">ボスニア語</xsl:when>
      <xsl:when test="$code='br'">ブルトン語</xsl:when>
      <xsl:when test="$code='bg'">ブルガリア語</xsl:when>
      <xsl:when test="$code='my'">ビルマ語</xsl:when>
      <xsl:when test="$code='ca'">カタルーニャ語</xsl:when>
      <xsl:when test="$code='ca'">バレンシア語</xsl:when>
      <xsl:when test="$code='ch'">チャモロ語</xsl:when>
      <xsl:when test="$code='ce'">チェチェン語</xsl:when>
      <xsl:when test="$code='zh'">中国語</xsl:when>
      <xsl:when test="$code='cu'">古代教会スラヴ語</xsl:when>
      <xsl:when test="$code='cv'">チュヴァシ語</xsl:when>
      <xsl:when test="$code='kw'">コーンウォル語</xsl:when>
      <xsl:when test="$code='co'">コルシカ語</xsl:when>
      <xsl:when test="$code='cr'">クリー語</xsl:when>
      <xsl:when test="$code='cs'">チェコ語</xsl:when>
      <xsl:when test="$code='da'">デンマーク語</xsl:when>
      <xsl:when test="$code='dv'">ディベヒ語</xsl:when>
      <xsl:when test="$code='nl'">オランダ語</xsl:when>
      <xsl:when test="$code='dz'">ゾンカ語</xsl:when>
      <xsl:when test="$code='en'">英語</xsl:when>
      <xsl:when test="$code='eo'">エスペラント</xsl:when>
      <xsl:when test="$code='et'">エストニア語</xsl:when>
      <xsl:when test="$code='ee'">エウェ語</xsl:when>
      <xsl:when test="$code='fo'">フェロー語</xsl:when>
      <xsl:when test="$code='fa'">ペルシア語</xsl:when>
      <xsl:when test="$code='fj'">フィジー語</xsl:when>
      <xsl:when test="$code='fi'">フィンランド語</xsl:when>
      <xsl:when test="$code='fr'">フランス語</xsl:when>
      <xsl:when test="$code='fy'">フリジア語</xsl:when>
      <xsl:when test="$code='ff'">フラ語</xsl:when>
      <xsl:when test="$code='ka'">グルジア語</xsl:when>
      <xsl:when test="$code='de'">ドイツ語</xsl:when>
      <xsl:when test="$code='gd'">スコットランド・ゲール語</xsl:when>
      <xsl:when test="$code='ga'">アイルランド語</xsl:when>
      <xsl:when test="$code='gl'">ガリシア語</xsl:when>
      <xsl:when test="$code='gv'">マン島語</xsl:when>
      <xsl:when test="$code='el'">ギリシア語</xsl:when>
      <xsl:when test="$code='gn'">グアラニー語</xsl:when>
      <xsl:when test="$code='gu'">グジャラート語</xsl:when>
      <xsl:when test="$code='ht'">ハイチ語</xsl:when>
      <xsl:when test="$code='ha'">ハウサ語</xsl:when>
      <xsl:when test="$code='he'">ヘブライ語</xsl:when>
      <xsl:when test="$code='iw'">ヘブライ語</xsl:when>
      <xsl:when test="$code='hz'">ヘレロ語</xsl:when>
      <xsl:when test="$code='hi'">ヒンディー語</xsl:when>
      <xsl:when test="$code='ho'">ヒリモトゥ語</xsl:when>
      <xsl:when test="$code='hu'">ハンガリー語</xsl:when>
      <xsl:when test="$code='ig'">イボ語</xsl:when>
      <xsl:when test="$code='is'">アイスランド語</xsl:when>
      <xsl:when test="$code='io'">イド語</xsl:when>
      <xsl:when test="$code='ii'">彝語（ロロ語）</xsl:when>
      <xsl:when test="$code='iu'">イヌイット語</xsl:when>
      <xsl:when test="$code='ie'">インターリング</xsl:when>
      <xsl:when test="$code='ia'">インターリングア</xsl:when>
      <xsl:when test="$code='in'">インドネシア語</xsl:when>
      <xsl:when test="$code='id'">インドネシア語</xsl:when>
      <xsl:when test="$code='ik'">イヌピア語</xsl:when>
      <xsl:when test="$code='it'">イタリア語</xsl:when>
      <xsl:when test="$code='jv'">ジャワ語</xsl:when>
      <xsl:when test="$code='ja'">日本</xsl:when>
      <xsl:when test="$code='kl'">グリーンランド語</xsl:when>
      <xsl:when test="$code='kn'">カンナダ語</xsl:when>
      <xsl:when test="$code='ks'">カシミール語</xsl:when>
      <xsl:when test="$code='kr'">カヌリ語</xsl:when>
      <xsl:when test="$code='kk'">カザフ語</xsl:when>
      <xsl:when test="$code='km'">クメール語</xsl:when>
      <xsl:when test="$code='ki'">キクユ語</xsl:when>
      <xsl:when test="$code='rw'">ルワンダ語</xsl:when>
      <xsl:when test="$code='ky'">キルギス語</xsl:when>
      <xsl:when test="$code='kv'">コミ語</xsl:when>
      <xsl:when test="$code='kg'">コンゴ語</xsl:when>
      <xsl:when test="$code='ko'">朝鮮語</xsl:when>
      <xsl:when test="$code='kj'">クワニャマ語</xsl:when>
      <xsl:when test="$code='ku'">クルド語</xsl:when>
      <xsl:when test="$code='lo'">ラーオ語</xsl:when>
      <xsl:when test="$code='la'">ラテン語</xsl:when>
      <xsl:when test="$code='lv'">ラトビア語</xsl:when>
      <xsl:when test="$code='li'">リンブルフ語</xsl:when>
      <xsl:when test="$code='ln'">リンガラ語</xsl:when>
      <xsl:when test="$code='lt'">リトアニア語</xsl:when>
      <xsl:when test="$code='lb'">ルクセンブルク語</xsl:when>
      <xsl:when test="$code='lu'">ルバ語</xsl:when>
      <xsl:when test="$code='lg'">ガンダ語</xsl:when>
      <xsl:when test="$code='mk'">マケドニア語</xsl:when>
      <xsl:when test="$code='mh'">マーシャル語</xsl:when>
      <xsl:when test="$code='ml'">マラヤーラム語</xsl:when>
      <xsl:when test="$code='mi'">マオリ語</xsl:when>
      <xsl:when test="$code='mr'">マラッタ語</xsl:when>
      <xsl:when test="$code='ms'">マレー語</xsl:when>
      <xsl:when test="$code='mg'">マダガスカル語</xsl:when>
      <xsl:when test="$code='mt'">マルタ語</xsl:when>
      <xsl:when test="$code='mo'">モルダビア語</xsl:when>
      <xsl:when test="$code='mn'">モンゴル語</xsl:when>
      <xsl:when test="$code='na'">ナウル語</xsl:when>
      <xsl:when test="$code='nv'">ナヴァホ語</xsl:when>
      <xsl:when test="$code='nr'">南ンデベレ語</xsl:when>
      <xsl:when test="$code='nd'">北ンデベレ語</xsl:when>
      <xsl:when test="$code='ng'">ンドンガ語</xsl:when>
      <xsl:when test="$code='ne'">ネパール語</xsl:when>
      <xsl:when test="$code='nn'">ノルウェー語（ニーノシュク）</xsl:when>
      <xsl:when test="$code='nb'">ノルウェー語（ブークモール）</xsl:when>
      <xsl:when test="$code='no'">ノルウェー語</xsl:when>
      <xsl:when test="$code='ny'">チェワ語</xsl:when>
      <xsl:when test="$code='oc'">オック語</xsl:when>
      <xsl:when test="$code='oj'">オジブワ語</xsl:when>
      <xsl:when test="$code='or'">オリヤー語</xsl:when>
      <xsl:when test="$code='om'">オロモ語</xsl:when>
      <xsl:when test="$code='os'">オセット語</xsl:when>
      <xsl:when test="$code='pa'">パンジャーブ語</xsl:when>
      <xsl:when test="$code='fa'">ペルシア語</xsl:when>
      <xsl:when test="$code='pi'">パーリ語</xsl:when>
      <xsl:when test="$code='pl'">ポーランド語</xsl:when>
      <xsl:when test="$code='pt'">ポルトガル語</xsl:when>
      <xsl:when test="$code='ps'">パシュトー語</xsl:when>
      <xsl:when test="$code='qu'">ケチュア語</xsl:when>
      <xsl:when test="$code='rm'">レト・ロマン語</xsl:when>
      <xsl:when test="$code='ro'">ルーマニア語</xsl:when>
      <xsl:when test="$code='rn'">ルンディ語</xsl:when>
      <xsl:when test="$code='ru'">ロシア語</xsl:when>
      <xsl:when test="$code='sg'">サンゴ語</xsl:when>
      <xsl:when test="$code='sa'">サンスクリット</xsl:when>
      <xsl:when test="$code='sr'">セルビア語</xsl:when>
      <xsl:when test="$code='hr'">クロアチア語</xsl:when>
      <xsl:when test="$code='si'">シンハラ語</xsl:when>
      <xsl:when test="$code='sk'">スロバキア語</xsl:when>
      <xsl:when test="$code='sl'">スロベニア語</xsl:when>
      <xsl:when test="$code='se'">サモス語</xsl:when>
      <xsl:when test="$code='sm'">サモア語</xsl:when>
      <xsl:when test="$code='sn'">ショナ語</xsl:when>
      <xsl:when test="$code='sd'">シンディー語</xsl:when>
      <xsl:when test="$code='so'">ソマリ語</xsl:when>
      <xsl:when test="$code='st'">南ソト語</xsl:when>
      <xsl:when test="$code='es'">スペイン語</xsl:when>
      <xsl:when test="$code='sc'">サルデーニャ語</xsl:when>
      <xsl:when test="$code='ss'">スワジ語</xsl:when>
      <xsl:when test="$code='su'">スンダ語</xsl:when>
      <xsl:when test="$code='sw'">スワヒリ語</xsl:when>
      <xsl:when test="$code='sv'">スウェーデン語</xsl:when>
      <xsl:when test="$code='ty'">タヒチ語</xsl:when>
      <xsl:when test="$code='ta'">タミル語</xsl:when>
      <xsl:when test="$code='tt'">タタール語</xsl:when>
      <xsl:when test="$code='te'">テルグ語</xsl:when>
      <xsl:when test="$code='tg'">タジク語</xsl:when>
      <xsl:when test="$code='tl'">タガログ語</xsl:when>
      <xsl:when test="$code='th'">タイ語</xsl:when>
      <xsl:when test="$code='bo'">チベット語</xsl:when>
      <xsl:when test="$code='ti'">ティグリニャ語</xsl:when>
      <xsl:when test="$code='to'">トンガ語（トンガ）</xsl:when>
      <xsl:when test="$code='tn'">ツワナ語</xsl:when>
      <xsl:when test="$code='ts'">ツォンガ語</xsl:when>
      <xsl:when test="$code='tk'">トルクメン語</xsl:when>
      <xsl:when test="$code='tr'">トルコ語</xsl:when>
      <xsl:when test="$code='tw'">トウィ語</xsl:when>
      <xsl:when test="$code='ug'">ウイグル語</xsl:when>
      <xsl:when test="$code='uk'">ウクライナ語</xsl:when>
      <xsl:when test="$code='ur'">ウルドゥー語</xsl:when>
      <xsl:when test="$code='uz'">ウズベク語</xsl:when>
      <xsl:when test="$code='ve'">ベンダ語</xsl:when>
      <xsl:when test="$code='vi'">ベトナム語</xsl:when>
      <xsl:when test="$code='vo'">ヴォラピュク</xsl:when>
      <xsl:when test="$code='cy'">ウェールズ語</xsl:when>
      <xsl:when test="$code='wa'">ワロン語</xsl:when>
      <xsl:when test="$code='wo'">ウォロフ語</xsl:when>
      <xsl:when test="$code='xh'">コサ語</xsl:when>
      <xsl:when test="$code='yi'">イディッシュ語</xsl:when>
      <xsl:when test="$code='ji'">イディッシュ語</xsl:when>
      <xsl:when test="$code='yo'">ヨルバ語</xsl:when>
      <xsl:when test="$code='za'">チワン語</xsl:when>
      <xsl:when test="$code='zh'">中国語</xsl:when>
      <xsl:when test="$code='zu'">ズールー語</xsl:when>
    </xsl:choose>
  </xsl:template>
  <!--国名ISO 3166-1(レートの対象)-->
  <xsl:template name="country">
    <xsl:param name="countrycode" select="1"/>
    <xsl:choose>
      <xsl:when test="$countrycode='is'">アイスランド</xsl:when>
      <xsl:when test="$countrycode='ie'">アイルランド</xsl:when>
      <xsl:when test="$countrycode='az'">アゼルバイジャン</xsl:when>
      <xsl:when test="$countrycode='af'">アフガニスタン</xsl:when>
      <xsl:when test="$countrycode='us'">アメリカ合衆国</xsl:when>
      <xsl:when test="$countrycode='vi'">アメリカ領ヴァージン諸島</xsl:when>
      <xsl:when test="$countrycode='as'">アメリカ領サモア</xsl:when>
      <xsl:when test="$countrycode='ae'">アラブ首長国連邦</xsl:when>
      <xsl:when test="$countrycode='dz'">アルジェリア</xsl:when>
      <xsl:when test="$countrycode='ar'">アルゼンチン</xsl:when>
      <xsl:when test="$countrycode='aw'">アルバ</xsl:when>
      <xsl:when test="$countrycode='al'">アルバニア</xsl:when>
      <xsl:when test="$countrycode='am'">アルメニア</xsl:when>
      <xsl:when test="$countrycode='ai'">アンギラ</xsl:when>
      <xsl:when test="$countrycode='ao'">アンゴラ</xsl:when>
      <xsl:when test="$countrycode='ag'">アンティグア・バーブーダ</xsl:when>
      <xsl:when test="$countrycode='ad'">アンドラ</xsl:when>
      <xsl:when test="$countrycode='ye'">イエメン</xsl:when>
      <xsl:when test="$countrycode='gb'">イギリス</xsl:when>
      <xsl:when test="$countrycode='io'">イギリス領インド洋地域</xsl:when>
      <xsl:when test="$countrycode='vg'">イギリス領ヴァージン諸島</xsl:when>
      <xsl:when test="$countrycode='il'">イスラエル</xsl:when>
      <xsl:when test="$countrycode='it'">イタリア</xsl:when>
      <xsl:when test="$countrycode='iq'">イラク</xsl:when>
      <xsl:when test="$countrycode='ir'">イラン・イスラム共和国</xsl:when>
      <xsl:when test="$countrycode='in'">インド</xsl:when>
      <xsl:when test="$countrycode='id'">インドネシア</xsl:when>
      <xsl:when test="$countrycode='wf'">ウォリス・フツナ</xsl:when>
      <xsl:when test="$countrycode='ug'">ウガンダ</xsl:when>
      <xsl:when test="$countrycode='ua'">ウクライナ</xsl:when>
      <xsl:when test="$countrycode='uz'">ウズベキスタン</xsl:when>
      <xsl:when test="$countrycode='uy'">ウルグアイ</xsl:when>
      <xsl:when test="$countrycode='ec'">エクアドル</xsl:when>
      <xsl:when test="$countrycode='eg'">エジプト</xsl:when>
      <xsl:when test="$countrycode='ee'">エストニア</xsl:when>
      <xsl:when test="$countrycode='et'">エチオピア</xsl:when>
      <xsl:when test="$countrycode='er'">エリトリア</xsl:when>
      <xsl:when test="$countrycode='sv'">エルサルバドル</xsl:when>
      <xsl:when test="$countrycode='au'">オーストラリア</xsl:when>
      <xsl:when test="$countrycode='at'">オーストリア</xsl:when>
      <xsl:when test="$countrycode='ax'">オーランド諸島</xsl:when>
      <xsl:when test="$countrycode='om'">オマーン</xsl:when>
      <xsl:when test="$countrycode='nl'">オランダ</xsl:when>
      <xsl:when test="$countrycode='gh'">ガーナ</xsl:when>
      <xsl:when test="$countrycode='cv'">カーボベルデ</xsl:when>
      <xsl:when test="$countrycode='gg'">ガーンジー</xsl:when>
      <xsl:when test="$countrycode='gy'">ガイアナ</xsl:when>
      <xsl:when test="$countrycode='kz'">カザフスタン</xsl:when>
      <xsl:when test="$countrycode='qa'">カタール</xsl:when>
      <xsl:when test="$countrycode='um'">合衆国領有小離島</xsl:when>
      <xsl:when test="$countrycode='ca'">カナダ</xsl:when>
      <xsl:when test="$countrycode='ga'">ガボン</xsl:when>
      <xsl:when test="$countrycode='cm'">カメルーン</xsl:when>
      <xsl:when test="$countrycode='gm'">ガンビア</xsl:when>
      <xsl:when test="$countrycode='kh'">カンボジア</xsl:when>
      <xsl:when test="$countrycode='mp'">北マリアナ諸島</xsl:when>
      <xsl:when test="$countrycode='gn'">ギニア</xsl:when>
      <xsl:when test="$countrycode='gw'">ギニアビサウ</xsl:when>
      <xsl:when test="$countrycode='cy'">キプロス</xsl:when>
      <xsl:when test="$countrycode='cu'">キューバ</xsl:when>
      <xsl:when test="$countrycode='cw'">キュラソー</xsl:when>
      <xsl:when test="$countrycode='gr'">ギリシャ</xsl:when>
      <xsl:when test="$countrycode='ki'">キリバス</xsl:when>
      <xsl:when test="$countrycode='kg'">キルギス</xsl:when>
      <xsl:when test="$countrycode='gt'">グアテマラ</xsl:when>
      <xsl:when test="$countrycode='gp'">グアドループ</xsl:when>
      <xsl:when test="$countrycode='gu'">グアム</xsl:when>
      <xsl:when test="$countrycode='kw'">クウェート</xsl:when>
      <xsl:when test="$countrycode='ck'">クック諸島</xsl:when>
      <xsl:when test="$countrycode='gl'">グリーンランド</xsl:when>
      <xsl:when test="$countrycode='cx'">クリスマス島</xsl:when>
      <xsl:when test="$countrycode='ge'">グルジア</xsl:when>
      <xsl:when test="$countrycode='gd'">グレナダ</xsl:when>
      <xsl:when test="$countrycode='hr'">クロアチア</xsl:when>
      <xsl:when test="$countrycode='ky'">ケイマン諸島</xsl:when>
      <xsl:when test="$countrycode='ke'">ケニア</xsl:when>
      <xsl:when test="$countrycode='ci'">コートジボワール</xsl:when>
      <xsl:when test="$countrycode='cc'">ココス（キーリング）諸島</xsl:when>
      <xsl:when test="$countrycode='cr'">コスタリカ</xsl:when>
      <xsl:when test="$countrycode='km'">コモロ</xsl:when>
      <xsl:when test="$countrycode='co'">コロンビア</xsl:when>
      <xsl:when test="$countrycode='cg'">コンゴ共和国</xsl:when>
      <xsl:when test="$countrycode='cd'">コンゴ民主共和国</xsl:when>
      <xsl:when test="$countrycode='sa'">サウジアラビア</xsl:when>
      <xsl:when test="$countrycode='gs'">サウスジョージア・サウスサンドウィッチ諸島</xsl:when>
      <xsl:when test="$countrycode='ws'">サモア</xsl:when>
      <xsl:when test="$countrycode='st'">サントメ・プリンシペ</xsl:when>
      <xsl:when test="$countrycode='bl'">サン・バルテルミー</xsl:when>
      <xsl:when test="$countrycode='zm'">ザンビア</xsl:when>
      <xsl:when test="$countrycode='pm'">サンピエール島・ミクロン島</xsl:when>
      <xsl:when test="$countrycode='sm'">サンマリノ</xsl:when>
      <xsl:when test="$countrycode='mf'">サン・マルタン（フランス領）</xsl:when>
      <xsl:when test="$countrycode='sl'">シエラレオネ</xsl:when>
      <xsl:when test="$countrycode='dj'">ジブチ</xsl:when>
      <xsl:when test="$countrycode='gi'">ジブラルタル</xsl:when>
      <xsl:when test="$countrycode='je'">ジャージー</xsl:when>
      <xsl:when test="$countrycode='jm'">ジャマイカ</xsl:when>
      <xsl:when test="$countrycode='sy'">シリア・アラブ共和国</xsl:when>
      <xsl:when test="$countrycode='sg'">シンガポール</xsl:when>
      <xsl:when test="$countrycode='sx'">シント・マールテン（オランダ領）</xsl:when>
      <xsl:when test="$countrycode='zw'">ジンバブエ</xsl:when>
      <xsl:when test="$countrycode='ch'">スイス</xsl:when>
      <xsl:when test="$countrycode='se'">スウェーデン</xsl:when>
      <xsl:when test="$countrycode='sd'">スーダン</xsl:when>
      <xsl:when test="$countrycode='sj'">スヴァールバル諸島およびヤンマイエン島</xsl:when>
      <xsl:when test="$countrycode='es'">スペイン</xsl:when>
      <xsl:when test="$countrycode='sr'">スリナム</xsl:when>
      <xsl:when test="$countrycode='lk'">スリランカ</xsl:when>
      <xsl:when test="$countrycode='sk'">スロバキア</xsl:when>
      <xsl:when test="$countrycode='si'">スロベニア</xsl:when>
      <xsl:when test="$countrycode='sz'">スワジランド</xsl:when>
      <xsl:when test="$countrycode='sc'">セーシェル</xsl:when>
      <xsl:when test="$countrycode='gq'">赤道ギニア</xsl:when>
      <xsl:when test="$countrycode='sn'">セネガル</xsl:when>
      <xsl:when test="$countrycode='rs'">セルビア</xsl:when>
      <xsl:when test="$countrycode='kn'">セントクリストファー・ネイビス</xsl:when>
      <xsl:when test="$countrycode='vc'">セントビンセントおよびグレナディーン諸島</xsl:when>
      <xsl:when test="$countrycode='sh'">セントヘレナ・アセンションおよびトリスタンダクーニャ</xsl:when>
      <xsl:when test="$countrycode='lc'">セントルシア</xsl:when>
      <xsl:when test="$countrycode='so'">ソマリア</xsl:when>
      <xsl:when test="$countrycode='sb'">ソロモン諸島</xsl:when>
      <xsl:when test="$countrycode='tc'">タークス・カイコス諸島</xsl:when>
      <xsl:when test="$countrycode='th'">タイ</xsl:when>
      <xsl:when test="$countrycode='kr'">大韓民国</xsl:when>
      <xsl:when test="$countrycode='tw'">台湾（台湾省/中華民国）</xsl:when>
      <xsl:when test="$countrycode='tj'">タジキスタン</xsl:when>
      <xsl:when test="$countrycode='tz'">タンザニア</xsl:when>
      <xsl:when test="$countrycode='cz'">チェコ</xsl:when>
      <xsl:when test="$countrycode='td'">チャド</xsl:when>
      <xsl:when test="$countrycode='cf'">中央アフリカ共和国</xsl:when>
      <xsl:when test="$countrycode='cn'">中国</xsl:when>
      <xsl:when test="$countrycode='tn'">チュニジア</xsl:when>
      <xsl:when test="$countrycode='kp'">朝鮮民主主義人民共和国</xsl:when>
      <xsl:when test="$countrycode='cl'">チリ</xsl:when>
      <xsl:when test="$countrycode='tv'">ツバル</xsl:when>
      <xsl:when test="$countrycode='dk'">デンマーク</xsl:when>
      <xsl:when test="$countrycode='de'">ドイツ</xsl:when>
      <xsl:when test="$countrycode='tg'">トーゴ</xsl:when>
      <xsl:when test="$countrycode='tk'">トケラウ</xsl:when>
      <xsl:when test="$countrycode='do'">ドミニカ共和国</xsl:when>
      <xsl:when test="$countrycode='dm'">ドミニカ国</xsl:when>
      <xsl:when test="$countrycode='tt'">トリニダード・トバゴ</xsl:when>
      <xsl:when test="$countrycode='tm'">トルクメニスタン</xsl:when>
      <xsl:when test="$countrycode='tr'">トルコ</xsl:when>
      <xsl:when test="$countrycode='to'">トンガ</xsl:when>
      <xsl:when test="$countrycode='ng'">ナイジェリア</xsl:when>
      <xsl:when test="$countrycode='nr'">ナウル</xsl:when>
      <xsl:when test="$countrycode='na'">ナミビア</xsl:when>
      <xsl:when test="$countrycode='aq'">南極</xsl:when>
      <xsl:when test="$countrycode='nu'">ニウエ</xsl:when>
      <xsl:when test="$countrycode='ni'">ニカラグア</xsl:when>
      <xsl:when test="$countrycode='ne'">ニジェール</xsl:when>
      <xsl:when test="$countrycode='jp'">日本</xsl:when>
      <xsl:when test="$countrycode='eh'">西サハラ</xsl:when>
      <xsl:when test="$countrycode='nc'">ニューカレドニア</xsl:when>
      <xsl:when test="$countrycode='nz'">ニュージーランド</xsl:when>
      <xsl:when test="$countrycode='np'">ネパール</xsl:when>
      <xsl:when test="$countrycode='nf'">ノーフォーク島</xsl:when>
      <xsl:when test="$countrycode='no'">ノルウェー</xsl:when>
      <xsl:when test="$countrycode='hm'">ハード島とマクドナルド諸島</xsl:when>
      <xsl:when test="$countrycode='bh'">バーレーン</xsl:when>
      <xsl:when test="$countrycode='ht'">ハイチ</xsl:when>
      <xsl:when test="$countrycode='pk'">パキスタン</xsl:when>
      <xsl:when test="$countrycode='va'">バチカン市国</xsl:when>
      <xsl:when test="$countrycode='pa'">パナマ</xsl:when>
      <xsl:when test="$countrycode='vu'">バヌアツ</xsl:when>
      <xsl:when test="$countrycode='bs'">バハマ</xsl:when>
      <xsl:when test="$countrycode='pg'">パプアニューギニア</xsl:when>
      <xsl:when test="$countrycode='bm'">バミューダ</xsl:when>
      <xsl:when test="$countrycode='pw'">パラオ</xsl:when>
      <xsl:when test="$countrycode='py'">パラグアイ</xsl:when>
      <xsl:when test="$countrycode='bb'">バルバドス</xsl:when>
      <xsl:when test="$countrycode='ps'">パレスチナ</xsl:when>
      <xsl:when test="$countrycode='hu'">ハンガリー</xsl:when>
      <xsl:when test="$countrycode='bd'">バングラデシュ</xsl:when>
      <xsl:when test="$countrycode='tl'">東ティモール</xsl:when>
      <xsl:when test="$countrycode='pn'">ピトケアン</xsl:when>
      <xsl:when test="$countrycode='fj'">フィジー</xsl:when>
      <xsl:when test="$countrycode='ph'">フィリピン</xsl:when>
      <xsl:when test="$countrycode='fi'">フィンランド</xsl:when>
      <xsl:when test="$countrycode='bt'">ブータン</xsl:when>
      <xsl:when test="$countrycode='bv'">ブーベ島</xsl:when>
      <xsl:when test="$countrycode='pr'">プエルトリコ</xsl:when>
      <xsl:when test="$countrycode='fo'">フェロー諸島</xsl:when>
      <xsl:when test="$countrycode='fk'">フォークランド（マルビナス）諸島</xsl:when>
      <xsl:when test="$countrycode='br'">ブラジル</xsl:when>
      <xsl:when test="$countrycode='fr'">フランス</xsl:when>
      <xsl:when test="$countrycode='gf'">フランス領ギアナ</xsl:when>
      <xsl:when test="$countrycode='pf'">フランス領ポリネシア</xsl:when>
      <xsl:when test="$countrycode='tf'">フランス領南方・南極地域</xsl:when>
      <xsl:when test="$countrycode='bg'">ブルガリア</xsl:when>
      <xsl:when test="$countrycode='bf'">ブルキナファソ</xsl:when>
      <xsl:when test="$countrycode='bn'">ブルネイ・ダルサラーム</xsl:when>
      <xsl:when test="$countrycode='bi'">ブルンジ</xsl:when>
      <xsl:when test="$countrycode='vn'">ベトナム</xsl:when>
      <xsl:when test="$countrycode='bj'">ベナン</xsl:when>
      <xsl:when test="$countrycode='ve'">ベネズエラ・ボリバル共和国</xsl:when>
      <xsl:when test="$countrycode='by'">ベラルーシ</xsl:when>
      <xsl:when test="$countrycode='bz'">ベリーズ</xsl:when>
      <xsl:when test="$countrycode='pe'">ペルー</xsl:when>
      <xsl:when test="$countrycode='be'">ベルギー</xsl:when>
      <xsl:when test="$countrycode='pl'">ポーランド</xsl:when>
      <xsl:when test="$countrycode='ba'">ボスニア・ヘルツェゴビナ</xsl:when>
      <xsl:when test="$countrycode='bw'">ボツワナ</xsl:when>
      <xsl:when test="$countrycode='bq'">ボネール、シント・ユースタティウスおよびサバ</xsl:when>
      <xsl:when test="$countrycode='bo'">ボリビア多民族国</xsl:when>
      <xsl:when test="$countrycode='pt'">ポルトガル</xsl:when>
      <xsl:when test="$countrycode='hk'">香港</xsl:when>
      <xsl:when test="$countrycode='hn'">ホンジュラス</xsl:when>
      <xsl:when test="$countrycode='mh'">マーシャル諸島</xsl:when>
      <xsl:when test="$countrycode='mo'">マカオ</xsl:when>
      <xsl:when test="$countrycode='mk'">マケドニア旧ユーゴスラビア共和国</xsl:when>
      <xsl:when test="$countrycode='mg'">マダガスカル</xsl:when>
      <xsl:when test="$countrycode='yt'">マヨット</xsl:when>
      <xsl:when test="$countrycode='mw'">マラウイ</xsl:when>
      <xsl:when test="$countrycode='ml'">マリ</xsl:when>
      <xsl:when test="$countrycode='mt'">マルタ</xsl:when>
      <xsl:when test="$countrycode='mq'">マルティニーク</xsl:when>
      <xsl:when test="$countrycode='my'">マレーシア</xsl:when>
      <xsl:when test="$countrycode='im'">マン島</xsl:when>
      <xsl:when test="$countrycode='fm'">ミクロネシア連邦</xsl:when>
      <xsl:when test="$countrycode='za'">南アフリカ</xsl:when>
      <xsl:when test="$countrycode='ss'">南スーダン</xsl:when>
      <xsl:when test="$countrycode='mm'">ミャンマー</xsl:when>
      <xsl:when test="$countrycode='mx'">メキシコ</xsl:when>
      <xsl:when test="$countrycode='mu'">モーリシャス</xsl:when>
      <xsl:when test="$countrycode='mr'">モーリタニア</xsl:when>
      <xsl:when test="$countrycode='mz'">モザンビーク</xsl:when>
      <xsl:when test="$countrycode='mc'">モナコ</xsl:when>
      <xsl:when test="$countrycode='mv'">モルディブ</xsl:when>
      <xsl:when test="$countrycode='md'">モルドバ共和国</xsl:when>
      <xsl:when test="$countrycode='ma'">モロッコ</xsl:when>
      <xsl:when test="$countrycode='mn'">モンゴル</xsl:when>
      <xsl:when test="$countrycode='me'">モンテネグロ</xsl:when>
      <xsl:when test="$countrycode='ms'">モントセラト</xsl:when>
      <xsl:when test="$countrycode='jo'">ヨルダン</xsl:when>
      <xsl:when test="$countrycode='la'">ラオス人民民主共和国</xsl:when>
      <xsl:when test="$countrycode='lv'">ラトビア</xsl:when>
      <xsl:when test="$countrycode='lt'">リトアニア</xsl:when>
      <xsl:when test="$countrycode='ly'">リビア</xsl:when>
      <xsl:when test="$countrycode='li'">リヒテンシュタイン</xsl:when>
      <xsl:when test="$countrycode='lr'">リベリア</xsl:when>
      <xsl:when test="$countrycode='ro'">ルーマニア</xsl:when>
      <xsl:when test="$countrycode='lu'">ルクセンブルク</xsl:when>
      <xsl:when test="$countrycode='rw'">ルワンダ</xsl:when>
      <xsl:when test="$countrycode='ls'">レソト</xsl:when>
      <xsl:when test="$countrycode='lb'">レバノン</xsl:when>
      <xsl:when test="$countrycode='re'">レユニオン</xsl:when>
      <xsl:when test="$countrycode='ru'">ロシア連邦</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$countrycode"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="CompactVoice">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='true'">デフォルト</xsl:when>
      <xsl:when test="$value='false'">高品質</xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="Gender">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">女性</xsl:when>
      <xsl:when test="$value='1'">男性</xsl:when>
      <xsl:otherwise>女性</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="SBSearchResultsDomain">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='DOMAIN_PERSON'">連絡先</xsl:when>
      <xsl:when test="$value='DOMAIN_APPLICATION'">App</xsl:when>
      <xsl:when test="$value='DOMAIN_MUSIC'">ミュージック</xsl:when>
      <xsl:when test="$value='DOMAIN_PODCAST'">Podcast</xsl:when>
      <xsl:when test="$value='DOMAIN_VIDEO'">ビデオ</xsl:when>
      <xsl:when test="$value='DOMAIN_AUDIOBOOK'">オーディオブック</xsl:when>
      <xsl:when test="$value='DOMAIN_NOTE'">メモ</xsl:when>
      <xsl:when test="$value='DOMAIN_EVENT'">イベント</xsl:when>
      <xsl:when test="$value='DOMAIN_MESSAGE'">メール</xsl:when>
      <xsl:when test="$value='DOMAIN_VOICEMEMO'">ボイスメモ</xsl:when>
      <xsl:when test="$value='DOMAIN_REMINDER'">リマインダー</xsl:when>
      <xsl:when test="$value='DOMAIN_PARSEC'">Spotlightの検索候補</xsl:when>
      <xsl:when test="$value='DOMAIN_WEBSEARCH'">BingのWeb検索結果</xsl:when>
      <xsl:when test="$value='com.apple.MobileSMS SMSSearch'">メッセージ</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$value"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="TimeZone">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value=''">東京</xsl:when>
      <xsl:when test="contains($value, 'Tokyo')">東京</xsl:when>
      <xsl:when test="$value='Tokyo, Japan'">東京</xsl:when>
      <xsl:when test="$value='Osaka, Japan'">大阪</xsl:when>
      <xsl:otherwise><xsl:value-of select="$value"/></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="HandsFreeMode">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:when test="$value='1'">常にオン</xsl:when>
      <xsl:when test="$value='2'">ハンズフリーのみ</xsl:when>
      <xsl:otherwise>常にオン</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="SiriAudioFeedback">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:when test="$value='1'">着信スイッチ/消音設定で制御</xsl:when>
      <xsl:when test="$value='2'">常にオン</xsl:when>
	  <xsl:when test="$value='3'">ハンズフリーのみ</xsl:when>
      <xsl:otherwise>常にオン</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="Orientation">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:when test="$value='1'">通常</xsl:when>
      <xsl:when test="$value='2'">180°</xsl:when>
      <xsl:when test="$value='3'">左90°</xsl:when>
      <xsl:when test="$value='4'">右90°</xsl:when>
      <xsl:otherwise>ロックなし</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="VoiceOverTouchTypingFeedback">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">文字</xsl:when>
      <xsl:when test="$value='1'">単語</xsl:when>
      <xsl:when test="$value='2'">文字と単語</xsl:when>
	  <xsl:when test="$value='3'">なし</xsl:when>
      <xsl:when test="$value=''">文字と単語</xsl:when>
      <xsl:otherwise><xsl:value-of select="$value"/></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ZeroOffOneOn">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">オフ</xsl:when>
      <xsl:when test="$value='1'">オン</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="locationAuthorization">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='4'">オン</xsl:when>
      <xsl:when test="$value='1'">オフ</xsl:when>
	  <xsl:when test="$value='' and $MajorVersion &gt;= 14">オン</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:otherwise>オン</xsl:otherwise>
  </xsl:choose>
  </xsl:template>

  <xsl:template name="locationAuthorization2">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='300' and $MajorVersion &gt;= 14">このAppまたはウィジェットの使用中のみ許可</xsl:when>
      <xsl:when test="$value='4' and $MajorVersion &lt; 14">常に許可</xsl:when>
      <xsl:when test="$value='4' and $MajorVersion &gt;= 14">常に</xsl:when>
      <xsl:when test="$value='2'">このAppの使用中のみ許可</xsl:when>
      <xsl:when test="$value='1' and $MajorVersion &lt; 13">許可しない</xsl:when>
      <xsl:when test="$value='1' and $MajorVersion &gt;= 13">なし</xsl:when>
      <xsl:when test="$value='100'">次回確認</xsl:when>
      <xsl:when test="$value='' and $MajorVersion &lt; 14">次回確認</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="locationAuthorization3">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='4'">常に許可</xsl:when>
      <xsl:when test="$value='1'">許可しない</xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="addrCollect">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:when test="$value='2'">オン</xsl:when>
      <xsl:otherwise>オフ</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="strOnOff">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='on'">オン</xsl:when>
      <xsl:when test="$value='onAndOverrideAirplaneMode'">オン</xsl:when>
      <xsl:when test="$value='off'">オフ</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ConfirmConnect">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">オフ</xsl:when>
      <xsl:when test="$value='1'">通知</xsl:when>
      <xsl:when test="$value='2'">確認</xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ConnectHotspot">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='Never'">しない</xsl:when>
      <xsl:when test="$value='Ask to Join'">接続を確認</xsl:when>
      <xsl:when test="$value='Automatic'">自動</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:when test="$value=''">接続を確認</xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="httpproxy">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='Off'">オフ</xsl:when>
      <xsl:when test="$value='Manual'">手動</xsl:when>
      <xsl:when test="$value='Auto'">自動</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="NetworkConfigMethod">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='DHCP'">自動</xsl:when>
      <xsl:when test="$value='BOOTP'">BootP</xsl:when>
      <xsl:when test="$value='Manual'">手動</xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="AppUpdate">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = '0'">オフ</xsl:when>
      <xsl:when test="$value = '1'">オン</xsl:when>
      <xsl:when test="$value = '2'">Wi-Fi</xsl:when>
      <xsl:when test="$value = '3'">オン（Wi-Fiとモバイルデータ通信）</xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="NoticeOrderRule">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">手動で並べ替え</xsl:when>
      <xsl:when test="$value='1'">時間で並べ替え</xsl:when>
      <xsl:when test="$value='2'">新着順</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="NoticeUnlocked">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='true'">常に知らせない</xsl:when>
      <xsl:when test="$value='false'">ロック中のみ知らせない</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ContentPreviewsSetting">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = '1'">
        <xsl:text>常に</xsl:text>
      </xsl:when>
      <xsl:when test="$value = '2'">
        <xsl:text>ロックされていないときのみ</xsl:text>
      </xsl:when>
      <xsl:when test="$value = '3'">
        <xsl:text>しない</xsl:text>
      </xsl:when>
	  <xsl:when test="$value = '0'">
        <xsl:text>常に</xsl:text>
      </xsl:when>
      <xsl:when test="$value = ''">
        <xsl:text>常に</xsl:text>
      </xsl:when>
	  <xsl:when test="not($value)">常に</xsl:when>
      <xsl:otherwise>
        <xsl:text></xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="allowModification">
    <xsl:param name="value"/>
  <xsl:choose>
    <xsl:when test="$value='true'">
      <xsl:text>変更を許可</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>変更を許可しない</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
  </xsl:template>

  <xsl:template name="disallowModification">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='true'">
        <xsl:text>変更を許可しない</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>変更を許可</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="Phonetics">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">オフ</xsl:when>
      <xsl:when test="$value='1'">文字と欧文通話表</xsl:when>
      <xsl:when test="$value='2'">欧文通話表のみ</xsl:when>
      <xsl:otherwise>文字と欧文通話表</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="Phonetics11">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">オフ</xsl:when>
      <xsl:when test="$value='1'">文字および文字の説明</xsl:when>
      <xsl:when test="$value='2'">文字の説明のみ</xsl:when>
      <xsl:otherwise>文字および文字の説明</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="BrailleContractionMode">
    <xsl:param name="value"/>
      <xsl:choose>
        <xsl:when test="$value='0'">オン</xsl:when>
        <xsl:when test="$value='1'">オフ</xsl:when>
        <xsl:otherwise>オフ</xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <xsl:template name="BrailleInputMode">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='1'">1級英語点字(6点式)</xsl:when>
      <xsl:when test="$value='2'">1級英語点字(8点式)</xsl:when>
      <xsl:when test="$value='3'">2級英語点字</xsl:when>
      <xsl:otherwise>1級英語点字(6点式)</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!-- 未使用 -->
  <xsl:template name="BrailleVirtualStatusAlignment">
    <xsl:param name="this"/>
      <xsl:choose>
        <xsl:when test="not($this)"></xsl:when>
        <xsl:when test="$this='1'">右揃え</xsl:when>
        <xsl:when test="$this='0'">左揃え</xsl:when>
        <xsl:otherwise>オフ</xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <!-- 未使用 -->
  <xsl:template name="BrailleStatus">
    <xsl:param name="CellIndex"/>
    <xsl:param name="Alignment"/>
    <xsl:choose>
      <xsl:when test="$CellIndex='-1' and $Alignment='0'">オフ</xsl:when>
      <xsl:when test="$CellIndex='0' and $Alignment='0'">左揃え</xsl:when>
      <xsl:when test="$CellIndex='0' and $Alignment='1'">右揃え</xsl:when>
      <xsl:otherwise>左揃え</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="BrailleStatus2">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='-1'">オフ</xsl:when>
      <xsl:when test="$value='0'">左揃え</xsl:when>
      <xsl:when test="$value='1'">右揃え</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="TouchRotorItem">
    <xsl:param name="item"/>
    <xsl:choose>
      <xsl:when test="$item = 'Character'">文字</xsl:when>
      <xsl:when test="$item = 'Word'">単語</xsl:when>
      <xsl:when test="$item = 'Line'">行</xsl:when>
      <xsl:when test="$item = 'SpeechRate'">読み上げ速度</xsl:when>
      <xsl:when test="$item = 'Volume'">音量</xsl:when>
      <xsl:when test="$item = 'Punctuation'">句読点</xsl:when>
      <xsl:when test="$item = 'AudioDucking'">オーディオダッキング</xsl:when>
      <xsl:when test="$item = 'Hints'">ヒント</xsl:when>
      <xsl:when test="$item = 'Handwriting'">手書き</xsl:when>
      <xsl:when test="$item = 'Sounds'">サウンド</xsl:when>
      <xsl:when test="$item = 'BrailleGesture'">点字画面入力</xsl:when>
      <xsl:when test="$item = 'Containers'">コンテナ</xsl:when>
      <xsl:when test="$item = 'Header'">見出し</xsl:when>
      <xsl:when test="$item = 'Link'">リンク</xsl:when>
      <xsl:when test="$item = 'FormElement'">フォームコントロール</xsl:when>
      <xsl:when test="$item = 'TableStart'">表</xsl:when>
      <xsl:when test="$item = 'ListStart'">リスト</xsl:when>
      <xsl:when test="$item = 'Landmarks'">ランドマーク</xsl:when>
      <xsl:when test="$item = 'VisitedLink'">訪問済みリンク</xsl:when>
      <xsl:when test="$item = 'NonVisitedLink'">未訪問リンク</xsl:when>
      <xsl:when test="$item = 'Button'">ボタン</xsl:when>
      <xsl:when test="$item = 'TextField'">テキストフィールド</xsl:when>
      <xsl:when test="$item = 'SearchField'">検索フィールド</xsl:when>
      <xsl:when test="$item = 'Image'">イメージ</xsl:when>
      <xsl:when test="$item = 'StaticText'">静的テキスト</xsl:when>
      <xsl:when test="$item = 'InternalLink'">ページ内リンク</xsl:when>
      <xsl:when test="$item = 'Zoom'">拡大または縮小</xsl:when>
      <xsl:when test="$item = 'Same'">同じ項目</xsl:when>
      <xsl:when test="$item = 'VerticalNavigation'">縦方向のナビゲーション</xsl:when>
	  <xsl:when test="$item = 'TextSelection'">テキスト選択</xsl:when>
	  <xsl:when test="$item = 'TypingMode'">入力モード</xsl:when>
	  <xsl:when test="$item = 'Language'">言語</xsl:when>
      <xsl:when test="$item = 'Article'">記事</xsl:when>
	  <xsl:when test="$item = 'AudioDestination'">オーディオの書き出し先</xsl:when>
	  <xsl:when test="$item = 'NavigationDirection'">ジェスチャーの方向</xsl:when>
	  <xsl:when test="$item = 'BrailleLanguage'">点字表</xsl:when>
	  <xsl:when test="$item = 'BrailleAutoAdvance'">点字自動前進スピード</xsl:when>
	  <xsl:when test="$item = 'Activities'">アクティビティ</xsl:when>
	  <xsl:when test="$item = 'ContinuousPath'">なぞり入力</xsl:when>
	  <xsl:when test="$item = 'ImageDescriptions'">画像を説明</xsl:when>
	  <xsl:when test="$item = 'DirectTouchMode'">ダイレクトタッチ</xsl:when>
	  <xsl:when test="$item = 'MLElementsMode'">画面認識</xsl:when>
      <xsl:otherwise><xsl:value-of select="$item"/></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="TypingMode">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">標準入力モード</xsl:when>
      <xsl:when test="$value='1'">タッチ入力モード</xsl:when>
      <xsl:when test="$value='2'">直接入力モード</xsl:when>
      <xsl:otherwise>標準入力モード</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="MACaptionActiveProfile">
    <xsl:param name="value"/>
  <xsl:choose>
    <xsl:when test="$value = '' and $MajorVersion &lt; 14">デフォルト</xsl:when>
	<xsl:when test="$value = '' and $MajorVersion &gt;= 14">アウトラインテキスト</xsl:when>
	<xsl:when test="$value = 'MACaptionProfile-OutlineText'">アウトラインテキスト</xsl:when>
    <xsl:when test="$value = 'MACaptionProfile-Default'">透明な背景</xsl:when>
    <xsl:when test="$value = 'MACaptionProfile-LargeText'">大きな文字</xsl:when>
    <xsl:when test="$value = 'MACaptionProfile-Classic'">クラシック</xsl:when>
    <xsl:otherwise>カスタム</xsl:otherwise>
  </xsl:choose>
  </xsl:template>


  <xsl:template name="ZoomMode">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="$this=''">ウィンドウズーム</xsl:when>
      <xsl:when test="$this='Fullscreen'">フルスクリーンズーム</xsl:when>
      <xsl:when test="$this='Window'">ウィンドウズーム</xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ZoomScale">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="not($this)">5x</xsl:when>
      <xsl:when test="$this = ''">5x</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="substring-before($this, '.')"/>
        <xsl:if test="contains($this, '.25')">
          <xsl:value-of select="'.2'" />
        </xsl:if>
        <xsl:if test="contains($this, '.5')">
          <xsl:value-of select="'.5'" />
        </xsl:if>
        <xsl:if test="contains($this, '.75')">
          <xsl:value-of select="'.8'" />
        </xsl:if>
        <xsl:text>x</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="ZoomOpacity">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="not($this)">50%</xsl:when>
      <xsl:when test="$this = ''">50%</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="format-number(number($this)*100, '#')"/>
        <xsl:text>%</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="NavigateImagesPreference">
    <xsl:param name="this"/>
      <xsl:choose>
        <xsl:when test="not($this)"></xsl:when>
        <xsl:when test="$this='2'">説明付き</xsl:when>
        <xsl:when test="$this='3'">しない</xsl:when>
        <xsl:when test="$this='1'">常にする</xsl:when>
        <xsl:otherwise>常にする</xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <!-- デフォルト:空or0.34999 遅く:0.5 最も遅く:0.6999 -->
  <xsl:template name="HomeClickSpeed">
    <xsl:param name="this"/>
      <xsl:choose>
        <xsl:when test="not($this)"></xsl:when>
        <xsl:when test="number($this) &gt; 0.30 and number($this) &lt; 0.4">デフォルト</xsl:when>
        <xsl:when test="number($this) &gt; 0.6">最も遅く</xsl:when>
        <xsl:when test="number($this) &lt; 0.6">遅く</xsl:when>
        <xsl:otherwise>デフォルト</xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <xsl:template name="QuickSpeakLocaleForLanguage-en">
    <xsl:param name="this"/>
      <xsl:choose>
        <xsl:when test="not($this)"></xsl:when>
        <xsl:when test="$this = 'en_AU'">Australian English</xsl:when>
        <xsl:when test="$this = 'en_GB'">British English</xsl:when>
        <xsl:when test="$this = 'en_IE'">Irish English</xsl:when>
        <xsl:when test="$this = 'en_ZA'">South African English</xsl:when>
        <xsl:otherwise>U.S. English</xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <xsl:template name="QuickSpeakLocaleForLanguage-es">
    <xsl:param name="this"/>
      <xsl:choose>
        <xsl:when test="not($this)"></xsl:when>
        <xsl:when test="$this='es_MX'">Español (Mexico)</xsl:when>
        <xsl:otherwise>Español (España)</xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <xsl:template name="QuickSpeakLocaleForLanguage">
    <xsl:param name="this"/>
    <xsl:param name="language"/>
    <xsl:param name="match"/>
    <xsl:param name="notmatch"/>
      <xsl:choose>
        <xsl:when test="not($this)"></xsl:when>
        <xsl:when test="$this=$language"><xsl:value-of select="$match"/></xsl:when>
        <xsl:otherwise><xsl:value-of select="$notmatch"/></xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <xsl:template name="QuickSpeakLocaleForLanguage-fr">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="not($this)"></xsl:when>
      <xsl:when test="$this='fr_CA'">Français canadian</xsl:when>
      <xsl:otherwise>Français (France)</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="QuickSpeakLocaleForLanguage-nl">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="not($this)"></xsl:when>
      <xsl:when test="$this='nl_BE'">Nederlands (Belgisch)</xsl:when>
      <xsl:otherwise>Nederlands (Nederland)</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="QuickSpeakLocaleForLanguage-pt">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="not($this)"></xsl:when>
      <xsl:when test="$this='pt_BR'">Portugués (Brasil)</xsl:when>
      <xsl:otherwise>Portugués (Portugal)</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="QuickSpeakLocaleForLanguage-zh">
    <xsl:param name="this"/>
      <xsl:choose>
        <xsl:when test="not($this)"></xsl:when>
        <xsl:when test="$this='zh_HK'">中文 (廣東話)</xsl:when>
        <xsl:when test="$this='zh_TW'">中文 (台灣)</xsl:when>
        <xsl:otherwise>中文 (中国)</xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <xsl:template name="KeyboardBias">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='Right'">右側</xsl:when>
      <xsl:when test="$value='Left'">左側</xsl:when>
      <xsl:when test="$value='None'">オフ</xsl:when>
      <xsl:otherwise>オフ</xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <xsl:template name="Calender">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="contains($value,'calendar=japanese')">和暦</xsl:when>
      <xsl:when test="contains($value,'calendar=buddhist')">タイ仏歴</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:otherwise>西暦</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="TemperatureUnit">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='Fahrenheit'">華氏（℉）</xsl:when>
      <xsl:when test="$value='Celsius'">摂氏（℃）</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:otherwise>摂氏（℃）</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="UISize">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = 'UICTContentSizeCategoryXS'">左端</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryS'">左から2番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryM'">左から3番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryL'">左から4番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryXL'">左から5番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryXXL'">左から6番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryXXXL'">左から7番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryAccessibilityM'">左から8番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryAccessibilityL'">左から9番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryAccessibilityXL'">左から10番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryAccessibilityXXL'">左から11番目</xsl:when>
      <xsl:when test="$value = 'UICTContentSizeCategoryAccessibilityXXXL'">右端</xsl:when>
      <xsl:otherwise>
        <xsl:text>左から4番目</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ScreenSize">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = '{320, 568}'">拡大</xsl:when>
      <xsl:when test="$value = '{375, 667}'">標準</xsl:when>
      <xsl:otherwise>
        <xsl:text></xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template name="ratingMovies">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0' and $MajorVersion &lt; 11">ムービーを許可しない</xsl:when>
      <xsl:when test="$value='0' and $MajorVersion &gt;= 11">映画を許可しない</xsl:when>
      <xsl:when test="$value='100'">G</xsl:when>
      <xsl:when test="$value='200'">PG12</xsl:when>
      <xsl:when test="$value='300'">R15+</xsl:when>
      <xsl:when test="$value='400'">R18+</xsl:when>
      <xsl:when test="$value='1000' and $MajorVersion &lt; 11">すべてのムービーを許可</xsl:when>
      <xsl:when test="$value='1000' and $MajorVersion &gt;= 11">すべての映画を許可</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:otherwise>不正な値</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ratingMovies8">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">ムービーを許可しない</xsl:when>
      <xsl:when test="$value='100'">G</xsl:when>
      <xsl:when test="$value='200'">PG12</xsl:when>
      <xsl:when test="$value='300'">R15+</xsl:when>
      <xsl:when test="$value='400'">R18+</xsl:when>
      <xsl:when test="$value='1000'">すべてのムービーを許可</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:otherwise>不正な値</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ratingMovies11">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">映画を許可しない</xsl:when>
      <xsl:when test="$value='100'">G</xsl:when>
      <xsl:when test="$value='200'">PG12</xsl:when>
      <xsl:when test="$value='300'">R15+</xsl:when>
      <xsl:when test="$value='400'">R18+</xsl:when>
      <xsl:when test="$value='1000'">すべての映画を許可</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:otherwise>不正な値</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="ratingTVShows">
    <xsl:param name="value"/>
      <xsl:choose>
        <xsl:when test="$value='0'">テレビ番組を許可しない</xsl:when>
        <xsl:when test="$value='100'">0+</xsl:when>
        <xsl:when test="$value='250'">9+</xsl:when>
        <xsl:when test="$value='350'">12+</xsl:when>
        <xsl:when test="$value='500'">不適切な内容</xsl:when>
        <xsl:when test="$value='600'">18+</xsl:when>
        <xsl:when test="$value='1000'">すべてのテレビ番組を許可</xsl:when>
        <xsl:when test="not($value)"></xsl:when>
        <xsl:otherwise>不正な値</xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <xsl:template name="BookstoreErotica">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='true'">すべて</xsl:when>
      <xsl:when test="$value='false'">制限あり</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="disallow">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='true'">変更を許可しない</xsl:when>
      <xsl:when test="$value='false'">変更を許可</xsl:when>
      <xsl:otherwise>不明</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ClosedCaption">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value=''">オフ</xsl:when>
      <xsl:when test="$value='2'">オフ</xsl:when>
      <xsl:when test="$value='3'">オン</xsl:when>
      <xsl:otherwise>不明</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="MultiPlayer">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">許可しない</xsl:when>
      <xsl:when test="$value='1'">友達のみを許可</xsl:when>
      <xsl:when test="$value='2'">すべての人を許可</xsl:when>
      <xsl:otherwise>不明</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="ratingApps">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">Appを許可しない</xsl:when>
      <xsl:when test="$value='100' and $MajorVersion &lt; 12">4+</xsl:when>
      <xsl:when test="$value='200' and $MajorVersion &lt; 12">9+</xsl:when>
      <xsl:when test="$value='100' and $MajorVersion &gt;= 12">4歳以上</xsl:when>
      <xsl:when test="$value='200' and $MajorVersion &gt;= 12">9歳以上</xsl:when>
      <xsl:when test="$value='300' and $MajorVersion &lt; 14">12+</xsl:when>
	  <xsl:when test="$value='300' and $MajorVersion &gt;= 14">12歳以上</xsl:when>
      <xsl:when test="$value='600' and $MajorVersion &lt; 12">17</xsl:when>
      <xsl:when test="$value='600' and $MajorVersion &gt;= 12">17歳以上</xsl:when>
      <xsl:when test="$value='1000'">すべてのAppを許可</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:otherwise>不正な値</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="forceITunesStorePasswordEntry">
    <xsl:param name="value"/>
      <xsl:choose>
        <xsl:when test="$value='true'">常に要求</xsl:when>
        <xsl:when test="not($value)"></xsl:when>
        <xsl:otherwise>15分後に要求</xsl:otherwise>
      </xsl:choose>
  </xsl:template>

  <xsl:template name="AccountPaidPurchasesPasswordSetting">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='1'">常に要求</xsl:when>
      <xsl:when test="$value='2'">15分後に要求</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="AccountFreeDownloadsPasswordSetting">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='1'">オン１</xsl:when>
      <xsl:when test="$value='2'">オン２</xsl:when>
      <xsl:when test="$value='3'">オフ３</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="restrictWeb">
    <xsl:param name="whitelistEnabled"/>
    <xsl:param name="useContentFilter"/>
    <xsl:choose>
      <xsl:when test="$whitelistEnabled='false' and $useContentFilter='false'">すべてのWebサイト</xsl:when>
      <xsl:when test="$whitelistEnabled='false' and $useContentFilter='true'">アダルトコンテンツを制限</xsl:when>
      <xsl:when test="$whitelistEnabled='true' and $useContentFilter='false'">指定したWebサイトのみ</xsl:when>
    </xsl:choose>
  </xsl:template>

    <xsl:template name="restrictWeb2">
    <xsl:param name="whitelistEnabled"/>
    <xsl:param name="useContentFilter"/>
    <xsl:choose>
      <xsl:when test="$whitelistEnabled='false' and $useContentFilter='false'">無制限アクセス</xsl:when>
      <xsl:when test="$whitelistEnabled='false' and $useContentFilter='true'">成人向けWebサイトを制限</xsl:when>
      <xsl:when test="$whitelistEnabled='true' and $useContentFilter='false'">許可されたWebサイトのみ</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="CustomDarkMode">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='false'">日の入から日の出まで</xsl:when>
      <xsl:when test="$value='true'">カスタムスケジュール</xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="BlueReductionMode">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">時間指定オフ</xsl:when>
      <xsl:when test="$value='1'">日の入から日の出まで</xsl:when>
      <xsl:when test="$value='2'">カスタムスケジュール</xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="SmartCharging">
    <xsl:param name="value"/>
    <xsl:choose>
	  <xsl:when test="$value=''">オン</xsl:when>
      <xsl:when test="$value='0'">オフ</xsl:when>
      <xsl:when test="$value='1'">オン</xsl:when>
      <xsl:when test="$value='3'">明日までオフ</xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:template>
    
  <xsl:template name="SweepSpeed">
    <xsl:param name="value" select="210"/>
    <xsl:choose>
      <xsl:when test="$value = ''">
        <xsl:text>31</xsl:text>
      </xsl:when>
      <xsl:when test="not($value)">
        <xsl:text>31</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="format-number(($value - 55) div 5, '#0')"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="CursorColor">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='3'">ブルー</xsl:when>
      <xsl:when test="$value='4'">レッド</xsl:when>
      <xsl:when test="$value='5'">グリーン</xsl:when>
      <xsl:when test="$value='6'">イエロー</xsl:when>
      <xsl:when test="$value='7'">オレンジ</xsl:when>
      <xsl:otherwise>ブルー</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="DefaultRouteForCall">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="not($value)">デフォルト</xsl:when>
      <xsl:when test="$value=''">デフォルト</xsl:when>
      <xsl:when test="$value='0'">デフォルト</xsl:when>
      <xsl:when test="$value='1'">ヘッドセット</xsl:when>
      <xsl:when test="$value='2'">スピーカー</xsl:when>
      <xsl:otherwise>不明</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="TripleClickName">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = '7'">アクセスガイド</xsl:when>
      <xsl:when test="$value = '1'">VoiceOver</xsl:when>
      <xsl:when test="$value = '2'">色を反転</xsl:when>
      <xsl:when test="$value = '4'">ズーム機能</xsl:when>
      <xsl:when test="$value = '5'">オフ</xsl:when>
      <xsl:when test="$value = '6'">AssistiveTouch</xsl:when>
      <xsl:when test="$value = '9'">スイッチコントロール</xsl:when>
      <xsl:when test="$value = '10'">グレイスケール</xsl:when>
	  <xsl:when test="$value = '11'">タッチ調整</xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="TripleClick">
    <xsl:param name="value"/>
    <xsl:param name="delimiter"/>
    <xsl:variable name="choice"><xsl:for-each select="$value">
      <xsl:if test="*/text() = '7'">アクセスガイド<xsl:value-of select="$delimiter"/></xsl:if>
      <xsl:if test="*/text() = '1'">VoiceOver<xsl:value-of select="$delimiter"/></xsl:if>
      <xsl:if test="*/text() = '2'">色を反転<xsl:value-of select="$delimiter"/></xsl:if>
      <xsl:if test="*/text() = '4'">ズーム機能<xsl:value-of select="$delimiter"/></xsl:if>
      <xsl:if test="*/text() = '5'">オフ<xsl:value-of select="$delimiter"/></xsl:if>
      <xsl:if test="*/text() = '6'">AssistiveTouch<xsl:value-of select="$delimiter"/></xsl:if>
      <xsl:if test="*/text() = '9'">スイッチコントロール<xsl:value-of select="$delimiter"/></xsl:if>
    </xsl:for-each></xsl:variable>
    <xsl:choose>
      <xsl:when test="not($value)"></xsl:when>
      <xsl:when test="$choice = ''">オフ</xsl:when>
      <xsl:otherwise><xsl:value-of select="$choice"/></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="TripleClickMaster">
    <xsl:param name="value"/>
    <xsl:param name="delimiter"/>
    <xsl:variable name="choice"><xsl:for-each select="$value">
        <xsl:if test="*/@master = '7'">アクセスガイド<xsl:value-of select="$delimiter"/></xsl:if>
        <xsl:if test="*/@master = '1'">VoiceOver<xsl:value-of select="$delimiter"/></xsl:if>
        <xsl:if test="*/@master = '2'">色を反転<xsl:value-of select="$delimiter"/></xsl:if>
        <xsl:if test="*/@master = '4'">ズーム機能<xsl:value-of select="$delimiter"/></xsl:if>
        <xsl:if test="*/@master = '5'">オフ<xsl:value-of select="$delimiter"/></xsl:if>
        <xsl:if test="*/@master = '6'">AssistiveTouch<xsl:value-of select="$delimiter"/></xsl:if>
        <xsl:if test="*/@master = '9'">スイッチコントロール<xsl:value-of select="$delimiter"/></xsl:if>
      </xsl:for-each></xsl:variable>
    <xsl:choose>
      <xsl:when test="not($value/@master)"></xsl:when>
      <xsl:when test="$choice = ''">オフ</xsl:when>
      <xsl:otherwise><xsl:value-of select="$choice"/></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="HardwareSwitch">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value = 'true'">画面の向きをロック</xsl:when>
      <xsl:otherwise>消音</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--

  -->
  <xsl:template name="AccountType">
    <xsl:param name="class"/>
    <xsl:param name="host" />
    <xsl:choose>
      <xsl:when test="$class = 'YahooAccount'">Yahoo</xsl:when>
      <xsl:when test="$class = 'CastleIMAPAccount'">iCloud</xsl:when>
      <xsl:when test="$class = 'iCloud'">iCloud</xsl:when>
      <xsl:when test="$class = 'AOLAccount'">AOL</xsl:when>
      <xsl:when test="$class = 'GmailAccount'">Gmail</xsl:when>
      <xsl:when test="$class = 'ASAccount'">
        <xsl:if test="$host = 'm.hotmail.com'">Hotmail</xsl:if>
        <xsl:if test="$host != 'm.hotmail.com'">Exchange</xsl:if>
      </xsl:when>
      <xsl:when test="$class = 'IMAPAccount'">IMAP</xsl:when>
      <xsl:when test="$class = 'POPAccount'">POP</xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="MailPort">
    <xsl:param name="port"/>
    <xsl:param name="class"/>
    <xsl:param name="ssl"/>

    <xsl:choose>
      <xsl:when test="not($port) or $port = ''">
        <xsl:choose>
          <xsl:when test="$class = 'SMTPAccount'">デフォルト(587)</xsl:when>
          <xsl:when test="$class = 'IMAPAccount'">
            <xsl:choose>
              <xsl:when test="$ssl = 'true'">デフォルト(993)</xsl:when>
              <xsl:otherwise>デフォルト(143)</xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:when test="$class = 'POPAccount'">
            <xsl:choose>
              <xsl:when test="$ssl = 'true'">デフォルト(995)</xsl:when>
              <xsl:otherwise>デフォルト(110)</xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:when test="$class = 'GmaiAccount'">デフォルト(993)</xsl:when>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$port"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ArchiveMessages">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="not($value)">削除済みメールボックス</xsl:when>
      <xsl:when test="$value='true'">アーカイブメールボックス</xsl:when>
      <xsl:otherwise>削除済みメールボックス</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="FlagStyle">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="not($value)">カラー</xsl:when>
      <xsl:when test="$value='shape'">アイコン</xsl:when>
	  <xsl:when test="$value='color'">カラー</xsl:when>
      <xsl:otherwise>カラー</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="PushFetch">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='0'">プッシュ</xsl:when>
	  <xsl:when test="$value='1'">フェッチ</xsl:when>
	  <xsl:when test="$value='2' and $MajorVersion &lt; 13">自動</xsl:when>
    <xsl:when test="$value='2' and $MajorVersion &gt;= 14">手動</xsl:when>
    </xsl:choose>
  </xsl:template>
  <!-- 自動手動は表記の違いで動作は同じ(Appの使用中に確認) -->

  <xsl:template name="MutedThreadAction">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='MoveToArchiveOrDelete'">アーカイブ/削除</xsl:when>
      <xsl:when test="$value='MarkAsRead'">開封済みにする</xsl:when>
      <xsl:when test="$value=''">開封済みにする</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="BlockedSenderMode">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='true0'">受信拒否にして、受信トレイに残す</xsl:when>
      <xsl:when test="$value='true1'">ゴミ箱に入れる</xsl:when>
      <xsl:when test="$value='false'">なし</xsl:when>
      <xsl:when test="$value='false0'">なし</xsl:when>
      <xsl:when test="$value=''">受信拒否にして、受信トレイに残す</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="IncludeAttachment">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="$value='IncludeAttachmentRepliesWhenAdding'">受信者を追加したとき</xsl:when>
      <xsl:when test="$value='IncludeAttachmentRepliesAsk'">確認</xsl:when>
      <xsl:when test="$value='IncludeAttachmentRepliesAlways'">常に</xsl:when>
      <xsl:when test="$value='IncludeAttachmentRepliesNever'">しない</xsl:when>
      <xsl:when test="$value=''">しない</xsl:when>
      <xsl:when test="not($value)"></xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="SwipeAction">
    <xsl:param name="value"/>
	<xsl:param name="dir"/>
    <xsl:choose>
      <xsl:when test="$value='SwipeActionAlternateDestructiveAction'">アーカイブ</xsl:when>
      <xsl:when test="$value='SwipeActionMove'">メッセージを移動</xsl:when>
      <xsl:when test="$value='SwipeActionRead'">開封済みにする</xsl:when>
      <xsl:when test="$value='SwipeActionFlag'">フラグ</xsl:when>
      <xsl:when test="$value='SwipeActionNone'">なし</xsl:when>
	  <xsl:otherwise>
	    <xsl:if test="$dir='left'">フラグ</xsl:if>
		<xsl:if test="$dir='right'">開封済みにする</xsl:if>
	  </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="GetAppName">
    <xsl:param name="appID"/>
    <xsl:param name="device"/>
    <xsl:param name="appnode" select="//Applications"/>
    <xsl:param name="type" select="''"/>
    <xsl:value-of select="cs:GetAppName($appID, $device, $appnode, $type)" />
    <!--<xsl:choose>
      <xsl:when test="//Applications/Application[./CFBundleIdentifier = $appID]/CFBundleDisplayName">
        <xsl:value-of select="//Applications/Application[./CFBundleIdentifier = $appID]/CFBundleDisplayName"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="DefaultApp">
          <xsl:with-param name="appID" select="$appID"/>
          <xsl:with-param name="device" select="$device"/>
          <xsl:with-param name="type" select="$type"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>-->
  </xsl:template>
  
  <xsl:template name="DefaultApp">
    <xsl:param name="appID"/>
    <xsl:param name="device"/>
    <xsl:param name="type" select="''"/>
    <xsl:choose>
      <xsl:when test ="$appID = 'com.apple.mobilesafari'">
        <xsl:choose>
          <xsl:when test="$type = 'locationservice'">Safariのサイト</xsl:when>
          <xsl:otherwise>Safari</xsl:otherwise>
        </xsl:choose>
      </xsl:when>
	  <xsl:when test ="$appID = 'com.apple.Translate'">翻訳</xsl:when>
      <xsl:when test ="$appID = 'com.apple.mobilemail'">メール</xsl:when>
      <xsl:when test ="$appID = 'com.apple.Music'">ミュージック</xsl:when>
      <xsl:when test ="$appID = 'com.apple.mobilecal'">カレンダー</xsl:when>
      <xsl:when test ="$appID = 'com.apple.mobileslideshow'">写真</xsl:when>
      <xsl:when test ="$appID = 'com.apple.camera'">カメラ</xsl:when>
      <xsl:when test ="$appID = 'com.apple.videos'">ビデオ</xsl:when>
      <xsl:when test ="$appID = 'com.apple.youtube'">YouTube</xsl:when>
      <xsl:when test ="$appID = 'com.apple.Maps'">マップ</xsl:when>
      <xsl:when test ="$appID = 'com.apple.weather'">天気</xsl:when>
      <xsl:when test ="$appID = 'com.apple.mobilenotes'">メモ</xsl:when>
      <xsl:when test ="$appID = 'com.apple.facetime'">FaceTime</xsl:when>
      <xsl:when test ="$appID = 'com.apple.mobileipod'">ミュージック</xsl:when>
      <xsl:when test ="$appID = 'com.apple.MobileStore'">iTunes Store</xsl:when>
      <xsl:when test ="$appID = 'com.apple.AppStore'">App Store</xsl:when>
      <xsl:when test ="$appID = 'com.apple.podcasts'">Podcast</xsl:when>
      <xsl:when test ="$appID = 'com.apple.Preferences'">設定</xsl:when>
      <xsl:when test ="$appID = 'com.apple.gamecenter'">Game Center</xsl:when>
      <xsl:when test ="$appID = 'com.apple.MobileAddressBook'">連絡先</xsl:when>
      <xsl:when test ="$appID = 'com.apple.reminders'">リマインダー</xsl:when>
	  <xsl:when test ="$appID = 'com.apple.tv'">TV</xsl:when>
      <xsl:when test ="$appID = 'com.apple.MobileSMS'">メッセージ</xsl:when>
      <xsl:when test ="$appID = 'com.apple.mobiletimer'">時計</xsl:when>
      <xsl:when test ="$appID = 'com.apple.Photo-Booth'">Photo Booth</xsl:when>
      <xsl:when test ="$appID = 'com.apple.mobilephone'">
        <xsl:choose>
          <xsl:when test="$device = 'iPad'">FaceTime</xsl:when>
          <xsl:when test="$device = 'iPhone'">電話</xsl:when>
        </xsl:choose>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.VoiceMemos'">ボイスメモ</xsl:when>
      <xsl:when test ="$appID = 'com.apple.calculator'">計算機</xsl:when>
      <xsl:when test ="$appID = 'com.apple.Shoebox'">Wallet</xsl:when>
      <xsl:when test ="$appID = 'com.apple.compass'">コンパス</xsl:when>
      <xsl:when test ="$appID = 'com.apple.stocks'">株価</xsl:when>
      <xsl:when test ="$appID = 'com.apple.Passbook'">Wallet</xsl:when>
      <xsl:when test ="$appID = 'com.apple.iBooks'">ブック</xsl:when>
      <xsl:when test ="$appID = 'com.apple.Health'">ヘルスケア</xsl:when>
      <xsl:when test ="$appID = 'com.apple.Bridge'">Watch</xsl:when>
      <xsl:when test ="$appID = 'com.apple.tips'">ヒント</xsl:when>
      <xsl:when test ="$appID = 'com.apple.mobileme.fmip1'">
        <xsl:choose>
          <xsl:when test="$device = 'iPad'">iPadを探す</xsl:when>
          <xsl:when test="$device = 'iPhone'">iPhoneを探す</xsl:when>
        </xsl:choose>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.mobileme.fmf1'">友達を探す</xsl:when>
      <xsl:when test ="$appID = 'com.apple.Home'">ホーム</xsl:when>
      <xsl:when test ="$appID = 'com.apple.DocumentsApp'">ファイル</xsl:when>
      <xsl:when test ="$appID = 'com.apple.findmy'">探す</xsl:when>
      <xsl:when test ="$appID = 'com.apple.shortcuts'">ショートカット</xsl:when>
      <xsl:when test ="$appID = 'com.apple.appleseed.FeedbackAssistant'">Feedback</xsl:when>
      <xsl:when test ="$appID = 'com.apple.measure'">計測</xsl:when>
	  <xsl:when test ="$appID = 'com.apple.ScreenTimeNotifications'">スクリーンタイム</xsl:when>
	  <xsl:when test="$appID='com.apple.mobilecal.bulletin-subsection.upcomingEvents'">もうすぐ行われるイベント</xsl:when>
	  <xsl:when test="$appID='com.apple.mobilecal.bulletin-subsection.invitations'">カレンダー（参加依頼）</xsl:when>
	  <xsl:when test="$appID='com.apple.mobilecal.bulletin-subsection.Responses'">カレンダー（予定出席者の回答）</xsl:when>
	  <xsl:when test="$appID='com.apple.mobilecal.bulletin-subsection.resourceChanges'">カレンダー（共有カレンダーの変更）</xsl:when>
	  <xsl:when test="$appID='com.apple.mobilecal.bulletin-subsection.suggestions'">カレンダー（SiriがAppで検出）</xsl:when>
	  <xsl:when test ="$appID='com.apple.mobileslideshow.memories'">写真（メモリー）</xsl:when>
	  <xsl:when test ="$appID='com.apple.mobileslideshow.iCloudPhotoSharing'">写真（共有アルバム）</xsl:when>
	  <xsl:when test ="$appID='com.apple.mobileslideshow.SharingSuggestions'">写真（共有の提案）</xsl:when>
	  <xsl:when test ="$appID = 'com.apple.tv.bulletins.explicit'">TV（次に観る）</xsl:when>
	  <xsl:when test ="$appID = 'com.apple.tv.bulletins.marketing'">TV（新機能）</xsl:when>
      <xsl:when test ="$appID = ''"></xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$appID"/>
      </xsl:otherwise>
	  
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ControlCenterModule">
    <xsl:param name="appID"/>
    <xsl:choose>
	  <xsl:when test = "$appID = 'com.apple.control-center.FlashlightModule'">
        <xsl:text>フラッシュライト</xsl:text>
      </xsl:when>
	  <xsl:when test = "$appID = 'com.apple.control-center.CalculatorModule'">
        <xsl:text>計算機</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.control-center.AlarmModule'">
        <xsl:text>アラーム</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.control-center.CameraModule'">
        <xsl:text>カメラ</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.control-center.QuickNoteModule'">
        <xsl:text>メモ</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.mobiletimer.controlcenter.timer'">
        <xsl:text>タイマー</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.control-center.AppleTVRemoteModule'">
        <xsl:text>Apple TV Remote</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.accessibility.controlcenter.general'">
        <xsl:text>アクセシビリティのショートカット</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.accessibility.controlcenter.guidedaccess'">
        <xsl:text>アクセスガイド</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.control-center.stopwatch'">
        <xsl:text>ストップウォッチ</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.accessibility.controlcenter.text.size'">
        <xsl:text>テキストサイズ</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.replaykit.controlcenter.screencapture'">
        <xsl:text>画面収録</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.control-center.MagnifierModule'">
        <xsl:text>拡大鏡</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.control-center.QRCodeModule' and $MajorVersion &lt; 13">
        <xsl:text>QRコードをスキャン</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.control-center.QRCodeModule' and $MajorVersion &gt;= 13 and $MajorVersion &lt; 14">
        <xsl:text>QRコードリーダー</xsl:text>
      </xsl:when>
	  <xsl:when test ="$appID = 'com.apple.control-center.QRCodeModule' and $MajorVersion &gt;= 14">
        <xsl:text>コードスキャナー</xsl:text>
      </xsl:when>
	  <xsl:when test ="$appID = 'com.apple.control-center.WalletModule'">
        <xsl:text>Wallet</xsl:text>
      </xsl:when>
	   <xsl:when test ="$appID = 'com.apple.control-center.VoiceMemosModule'">
        <xsl:text>ボイスメモ</xsl:text>
      </xsl:when>
	  <xsl:when test ="$appID = 'com.apple.control-center.CarModeModule'">
        <xsl:text>運転中の通知を停止</xsl:text>
      </xsl:when>
	   <xsl:when test ="$appID = 'com.apple.accessibility.controlcenter.hearingdevices' and $MajorVersion &lt; 13">
        <xsl:text>聴覚サポート</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.accessibility.controlcenter.hearingdevices' and $MajorVersion = 13">
        <xsl:text>ヒアリング</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.accessibility.controlcenter.hearingdevices' and $MajorVersion &gt;= 14">
        <xsl:text>聴覚</xsl:text>
      </xsl:when>
	   <xsl:when test ="$appID = 'com.apple.control-center.LowPowerModule'">
        <xsl:text>低電力モード</xsl:text>
      </xsl:when>
	  <xsl:when test ="$appID = 'com.apple.Home.ControlCenter'">
        <xsl:text>ホーム</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.control-center.AppearanceModule'">
        <xsl:text>ダークモード</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.control-center.FeedbackAssistantModule'">
        <xsl:text>フィードバックアシスタント</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.accessibility.controlcenter.sounddetection'">
        <xsl:text>サウンド認識</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.sleep.controlcenter.sleepmode'">
        <xsl:text>睡眠モード</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = 'com.apple.control-center.MuteModule'">
        <xsl:text>消音モード</xsl:text>
      </xsl:when>
	  <xsl:when test ="$appID = 'com.apple.Home.CompactControlCenter'">
        <xsl:text>ホーム</xsl:text>
      </xsl:when>
	  <xsl:when test ="$appID = 'com.apple.shazamkit.controlcenter.ShazamModule'">
        <xsl:text>ミュージック認識</xsl:text>
      </xsl:when>
	   <xsl:when test ="$appID = ''">
        <xsl:text></xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$appID"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="Widget">
    <xsl:param name="appID"/>
    <xsl:choose>
      <xsl:when test = "$appID = 'com.apple.UpNextWidget.extension'">
        <xsl:text>次の予定</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.AppPredictionWidget.extension'">
        <xsl:text>Siriからの提案（App）</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.ScreenTimeUI.ScreenTimeWidget'">
        <xsl:text>スクリーンタイム</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.shortcuts.Today-Extension'">
        <xsl:text>ショートカット</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.google.Maps.TransitToGoExtension'">
        <xsl:text>Google ルート案内</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.google.Maps.LocalGuidesTodayExtension'">
        <xsl:text>Google ローカルガイド</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.google.Maps.HomeAndWorkTodayExtension'">
        <xsl:text>Google 移動所要時間</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.google.Maps.NearbyTransitTodayExtension'">
        <xsl:text>Google 交通機関の出発時刻</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.google.Maps.NearbyTrafficTodayExtension'">
        <xsl:text>Google 交通状況</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.podcasts.TodayExtension'">
        <xsl:text>Podcast</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.tv.TVUpNextExtension'">
        <xsl:text>TV</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.mobilecal.widget'">
        <xsl:text>カレンダー</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.news.widget'">
        <xsl:text>News</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.tips.TipsWidgetExtension'">
        <xsl:text>ヒント</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.DocumentsApp.widget'">
        <xsl:text>ファイル</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.Maps.Nearby'">
        <xsl:text>マップ：この周辺</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.Maps.Widget'">
        <xsl:text>マップ：目的地</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.Music.RecentlyPlayedTodayExtension'">
        <xsl:text>ミュージック</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.mobilemail.MailVIPWidget'">
        <xsl:text>メール</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.mobilenotes.TodayExtension'">
        <xsl:text>メモ</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.Maps.TransitWidget'">
        <xsl:text>マップ：交通機関</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.TelephonyUI.FavoritesWidget'">
        <xsl:text>よく使う項目</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.reminders.todayextension'">
        <xsl:text>リマインダー</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.stocks.widget'">
        <xsl:text>株価</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.weather.WeatherAppTodayWidget'">
        <xsl:text>天気</xsl:text>
      </xsl:when>
      <xsl:when test = "$appID = 'com.apple.mobileslideshow.photoswidget'">
        <xsl:text>写真</xsl:text>
      </xsl:when>
      <xsl:when test ="$appID = ''">
        <xsl:text></xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$appID"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="Loop">
    <xsl:param name="count"/>
    <xsl:if test="$count &gt; 0">
    <xsl:text>,</xsl:text><xsl:call-template name="Loop">
            <xsl:with-param name="count" select="$count - 1"/>
        </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="Loop2">
    <xsl:param name="count"/>
    <xsl:if test="$count &gt; 0">
      <xsl:text>,,</xsl:text><xsl:call-template name="Loop2">
        <xsl:with-param name="count" select="$count - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <!-- countの数だけ,,,を出力する -->
  <xsl:template name="Loop3">
    <xsl:param name="count"/>
    <xsl:if test="$count &gt; 0">
      <xsl:text>,,,</xsl:text><xsl:call-template name="Loop3">
        <xsl:with-param name="count" select="$count - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="Loop4">
    <xsl:param name="count"/>
    <xsl:if test="$count &gt; 0">
      <xsl:text>,,,,</xsl:text>
      <xsl:call-template name="Loop4">
        <xsl:with-param name="count" select="$count - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="Loop5">
    <xsl:param name="count"/>
    <xsl:if test="$count &gt; 0">
      <xsl:text>,,,,,</xsl:text>
      <xsl:call-template name="Loop5">
        <xsl:with-param name="count" select="$count - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="LoopStr">
    <xsl:param name="count"/>
    <xsl:param name="str" select="','"/>
    <xsl:if test="$count &gt; 0">
      <xsl:value-of select="$str"/>
      <xsl:call-template name="LoopStr">
        <xsl:with-param name="str" select="$str"/>
        <xsl:with-param name="count" select="$count - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>
  
  
   <!-- バイブレーション -->
  <xsl:template name="vibration">
    <xsl:param name="value" select="1"/>
		<xsl:choose>
			<xsl:when test="$value='Accent'">アクセント</xsl:when>
			<xsl:when test="$value='Heartbeat'">心臓の鼓動</xsl:when>
			<xsl:when test="$value='Alert'">警告</xsl:when>
			<xsl:when test="$value='Beethoven - Symphony No. 5'">交響曲</xsl:when>
			<xsl:when test="$value='Staccato'">スタッカート</xsl:when>
			<xsl:when test="$value='Quick'">クイック</xsl:when>
			<xsl:when test="$value='SOS'">SOS</xsl:when>
			<xsl:when test="$value='Rapid'">ラピット</xsl:when>
			<xsl:when test="$value='&lt;none&gt;'">なし</xsl:when>
			<!-- <xsl:when test="$value=''">同期</xsl:when> -->
		</xsl:choose>
  </xsl:template>
  
  <!-- 着信音 -->
  <xsl:template name="sound">
    <xsl:param name="value" select="1"/>
    <xsl:choose>
		<xsl:when test="$value='&lt;default&gt;'">オープニング</xsl:when>
		<xsl:when test="$value='system:Uplift'">アップリフト</xsl:when>
		<xsl:when test="$value='system:Twinkle'">きらめき</xsl:when>
		<xsl:when test="$value='system:Circuit'">サーキット</xsl:when>
		<xsl:when test="$value='system:Ripples'">さざ波</xsl:when>
		<xsl:when test="$value='system:Summit'">サミット</xsl:when>
		<xsl:when test="$value='system:Silk'">シルク</xsl:when>
		<xsl:when test="$value='system:Stargaze'">スターゲイズ</xsl:when>
		<xsl:when test="$value='system:Slow Rise'">スローライズ</xsl:when>
		<xsl:when test="$value='system:Chimes'">チャイム</xsl:when>
		<xsl:when test="$value='system:Bulletin'">ニュース</xsl:when>
		<xsl:when test="$value='system:Hillside'">ヒルサイド</xsl:when>
		<xsl:when test="$value='system:Night Owl'">フクロウ</xsl:when>
		<xsl:when test="$value='system:Playtime'">プレイタイム</xsl:when>
		<xsl:when test="$value='system:Presto'">プレスト</xsl:when>
		<xsl:when test="$value='system:Radar'">レーダー</xsl:when>
		<xsl:when test="$value='system:Cosmic'">宇宙</xsl:when>
		<xsl:when test="$value='system:By The Seaside'">海岸で</xsl:when>
		<xsl:when test="$value='system:Illuminate'">照明</xsl:when>
		<xsl:when test="$value='system:Signal'">信号</xsl:when>
		<xsl:when test="$value='system:Crystals'">水晶</xsl:when>
		<xsl:when test="$value='system:Constellation'">星座</xsl:when>
		<xsl:when test="$value='system:Sencha'">煎茶</xsl:when>
		<xsl:when test="$value='system:Apex'">頂点</xsl:when>
		<xsl:when test="$value='system:Beacon'">灯台</xsl:when>
		<xsl:when test="$value='system:Waves'">波</xsl:when>
		<xsl:when test="$value='system:Radiate'">放射</xsl:when>
		<xsl:when test="$value='&lt;none&gt;'">なし</xsl:when>
		<xsl:when test="$value='texttone:Aurora'">オーロラ</xsl:when>
		<xsl:when test="$value='texttone:Complete'">コンプリート</xsl:when>
		<xsl:when test="$value='texttone:Circles'">サークル</xsl:when>
		<xsl:when test="$value='texttone:Synth'">シンセ</xsl:when>
		<xsl:when test="$value='texttone:Air Drop Invitation'">パルス</xsl:when> 
		<xsl:when test="$value='texttone:Hello'">ハロー</xsl:when>
		<xsl:when test="$value='texttone:Popcorn'">ポップコーン</xsl:when>
		<xsl:when test="$value='texttone:Note'">メモ</xsl:when>
		<xsl:when test="$value='texttone:Keys'">鍵</xsl:when>
		<xsl:when test="$value='texttone:Bamboo'">竹</xsl:when>
		<xsl:when test="$value='texttone:Input'">入力</xsl:when>
		<xsl:when test="$value='texttone:Calendar Alert'">和音</xsl:when>
		<xsl:when test="$value='texttone:Tri-tone'">クラシック</xsl:when> 
		<xsl:when test="$value='system:Sci-Fi'">クラシック/SF</xsl:when>
		<xsl:when test="$value='system:Duck'">クラシック/アヒル</xsl:when>
		<xsl:when test="$value='system:Alarm'">クラシック/アラーム</xsl:when>
		<xsl:when test="$value='system:Motorcycle'">クラシック/オートバイ</xsl:when>
		<xsl:when test="$value='system:Old Car Horn'">クラシック/クラクション</xsl:when>
		<xsl:when test="$value='system:Crickets'">クラシック/こおろぎの鳴き声</xsl:when>
		<xsl:when test="$value='system:Xylophone'">クラシック/シロフォン</xsl:when>
		<xsl:when test="$value='system:Ascending'">クラシック/ステップ</xsl:when>
		<xsl:when test="$value='system:Strum'">クラシック/ストラム</xsl:when>
		<xsl:when test="$value='system:Sonar'">クラシック/ソナー</xsl:when>
		<xsl:when test="$value='system:Time Passing'">クラシック/タイムパス</xsl:when>
		<xsl:when test="$value='system:Timba'">クラシック/ティンバ</xsl:when>
		<xsl:when test="$value='system:Digital'">クラシック/デジタル</xsl:when>
		<xsl:when test="$value='system:Doorbell'">クラシック/ドアベル</xsl:when>
		<xsl:when test="$value='system:Trill'">クラシック/トリル</xsl:when>
		<xsl:when test="$value='system:Harp'">クラシック/ハープ</xsl:when>
		<xsl:when test="$value='system:Boing'">クラシック/バネ</xsl:when>
		<xsl:when test="$value='system:Piano Riff'">クラシック/ピアノリフ</xsl:when>
		<xsl:when test="$value='system:Pinball'">クラシック/ピンボール</xsl:when>
		<xsl:when test="$value='system:Blues'">クラシック/ブルース</xsl:when>
		<xsl:when test="$value='system:Marimba'">クラシック/マリンバ</xsl:when>
		<xsl:when test="$value='system:Robot'">クラシック/ロボット</xsl:when>
		<xsl:when test="$value='system:Bell Tower'">クラシック/教会の鐘</xsl:when>
		<xsl:when test="$value='system:Bark'">クラシック/犬の吠え声</xsl:when>
		<xsl:when test="$value='system:Old Phone'">クラシック/黒電話</xsl:when>
		<xsl:when test="$value='texttone:Tri-tone'">クラシック/トライトーン</xsl:when>
		<xsl:when test="$value='texttone:Sent Mail'">クラシック/スウォッシュ</xsl:when>
		<xsl:when test="$value='texttone:Update'">クラシック/アップデート</xsl:when>
		<xsl:when test="$value='texttone:Electronic'">クラシック/エレクトロニック</xsl:when>
		<xsl:when test="$value='texttone:Glass'">クラシック/ガラス</xsl:when>
		<xsl:when test="$value='texttone:Calypso'">クラシック/カリプソ</xsl:when>
		<xsl:when test="$value='Suspense'">クラシック/サスペンス</xsl:when>
		<xsl:when test="$value='Sherwood Forest'">クラシック/シャーウッドの森</xsl:when>
		<xsl:when test="$value='texttone:Sharing Post'">クラシック/スウィッシュ</xsl:when>
		<xsl:when test="$value='texttone:Spell'">クラシック/スペル</xsl:when>
		<xsl:when test="$value='texttone:Typewriters'">クラシック/タイプライター</xsl:when>
		<xsl:when test="$value='texttone:Chime'">クラシック/チャイム</xsl:when>
		<xsl:when test="$value='texttone:Sent Tweet'">クラシック/ツイート</xsl:when>
		<xsl:when test="$value='texttone:Tiptoes'">クラシック/つま先</xsl:when>
		<xsl:when test="$value='texttone:News Flash'">クラシック/ニュースフラッシュ</xsl:when>
		<xsl:when test="$value='texttone:Noir'">クラシック/ノアール</xsl:when>
		<xsl:when test="$value='texttone:Ladder'">クラシック/はしご</xsl:when>
		<xsl:when test="$value='texttone:Ladder'">クラシック/ファンファーレ</xsl:when>
		<xsl:when test="$value='texttone:Bell'">クラシック/ベル</xsl:when>
		<xsl:when test="$value='texttone:Horn'">クラシック/ホルン</xsl:when>
		<xsl:when test="$value='texttone:Minuet'">クラシック/エヌエット</xsl:when>
		<xsl:when test="$value='texttone:Choo Choo'">クラシック/機関車</xsl:when>
		<xsl:when test="$value='texttone:Alert'">クラシック/警告</xsl:when>
		<xsl:when test="$value='texttone:Descent'">クラシック/降下</xsl:when>
		<xsl:when test="$value='texttone:New Mail'">クラシック/鐘</xsl:when>
		<xsl:when test="$value='texttone:Telegraph'">クラシック/電報</xsl:when>
		<xsl:when test="$value='texttone:Bloom'">クラシック/曇り</xsl:when>
		<xsl:when test="$value='texttone:Anticipate'">クラシック/予感</xsl:when>
	</xsl:choose>
  </xsl:template>
  
  <!-- カレンダー/デフォルトの通知の時間/イベント -->
  <xsl:template name="eventcal">
    <xsl:param name="value" select="1"/>
	  <xsl:choose>
	     <xsl:when test="$value='0'">イベントの予定時刻</xsl:when>
	     <xsl:when test="$value='-300'">5分前</xsl:when>
	     <xsl:when test="$value='-600'">10分前</xsl:when>
		 <xsl:when test="$value='-900'">15分前</xsl:when>
		 <xsl:when test="$value='-1800'">30分前</xsl:when>
		 <xsl:when test="$value='-3600'">1時間前</xsl:when>
		 <xsl:when test="$value='-7200'">2時間前</xsl:when>
		 <xsl:when test="$value='-86400'">1日前</xsl:when>
		 <xsl:when test="$value='-172800'">2日前</xsl:when>
		 <xsl:when test="$value='-604800'">1週間前</xsl:when>
		 <xsl:when test="$value=''">なし</xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="weeks">
    <xsl:param name="value" select="1"/>
	  <xsl:choose>
		<xsl:when test="$value='0'">日曜日</xsl:when>
		<xsl:when test="$value='2'">月曜日</xsl:when>
		<xsl:when test="$value='3'">火曜日</xsl:when>
		<xsl:when test="$value='4'">水曜日</xsl:when>
		<xsl:when test="$value='5'">木曜日</xsl:when>
		<xsl:when test="$value='6'">金曜日</xsl:when>
		<xsl:when test="$value='7'">土曜日</xsl:when>
      </xsl:choose>
  </xsl:template>

  <xsl:template name="Zoom">
    <xsl:param name="value" select="1"/>
	  <xsl:choose>
	  <xsl:when test="$value='0'">50%</xsl:when>
		<xsl:when test="$value='1'">75%</xsl:when>
		<xsl:when test="$value='2'">85%</xsl:when>
	    <xsl:when test="$value='3'">100%</xsl:when>
		<xsl:when test="$value='4'">115%</xsl:when>
		<xsl:when test="$value='5'">125%</xsl:when>
		<xsl:when test="$value='6'">150%</xsl:when>
		<xsl:when test="$value='7'">175%</xsl:when>
		<xsl:when test="$value='8'">200%</xsl:when>
		<xsl:when test="$value='9'">250%</xsl:when>
		<xsl:when test="$value='10'">300%</xsl:when>
	  </xsl:choose>
  </xsl:template>
  
  <xsl:template name="AlertCount">
    <xsl:param name="value" select="1"/>
	  <xsl:choose>
		<xsl:when test="$value='1'">しない</xsl:when>
		<xsl:when test="$value='2'">1回</xsl:when>
		<xsl:when test="$value='3'">2回</xsl:when>
		<xsl:when test="$value='4'">3回</xsl:when>
		<xsl:when test="$value='6'">5回</xsl:when>
		<xsl:when test="$value='11'">10回</xsl:when>
      </xsl:choose>
  </xsl:template>
  
</xsl:stylesheet>