<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
exclude-result-prefixes="msxsl">

  <xsl:template name="SectionAccessibility14">
  
  <xsl:if test="$MajorVersion &lt;= 13">
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverTouchEnabled'" />
      <xsl:with-param name="title1" select="'アクセシビリティ'" />
      <xsl:with-param name="title2" select="'VoiceOver'" />
      <xsl:with-param name="title3" select="'VoiceOver'" />
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverTouchEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	</xsl:if>
	
	<xsl:if test="$MajorVersion &gt;= 14">
	  <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'VoiceOverTouchEnabled14'" />
		<xsl:with-param name="title1" select="'アクセシビリティ'" />
		<xsl:with-param name="title2" select="'VoiceOver'" />
		<xsl:with-param name="title3" select="'VoiceOver'" />
		<xsl:with-param name="valueNode" select="/RESULT/VoiceOverTouchEnabled14" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/VoiceOverTouchEnabled14 = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/VoiceOverTouchEnabled14 = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/VoiceOverTouchEnabled14 = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/VoiceOverTouchEnabled14/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/VoiceOverTouchEnabled14/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/VoiceOverTouchEnabled14/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	  </xsl:call-template>
	</xsl:if>
 	<!-- iOS14 ver. -->

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverTouchSpeakingRate'" />
      <xsl:with-param name="title3" select="'読み上げ速度'" />
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverTouchSpeakingRate" />
      <xsl:with-param name="value">
        <xsl:call-template name="slider4">
          <xsl:with-param name="position" select="/RESULT/VoiceOverTouchSpeakingRate"/>
          <xsl:with-param name="range" select="1"/>
          <xsl:with-param name="default" select="0.3"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:if test="VoiceOverTouchSpeakingRate/@master">
          <xsl:call-template name="slider4">
            <xsl:with-param name="position" select="VoiceOverTouchSpeakingRate/@master"/>
            <xsl:with-param name="range" select="1"/>
            <xsl:with-param name="default" select="0.3"/>
          </xsl:call-template>
          <xsl:call-template name="Margin">
            <xsl:with-param name="margin" select="VoiceOverTouchSpeakingRate/@margin"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>


    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverTouchPitchChangePreference'" />
      <xsl:with-param name="title3" select="'ピッチ変更を使用'" />
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverTouchPitchChangePreference" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverUseSoundEffects'" />
      <xsl:with-param name="title3" select="'サウンドエフェクトを使用'" />
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverUseSoundEffects" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:if test="/RESULT/VoiceOverTouchLanguageRotor = ''">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'VoiceOverTouchLanguageRotor/Item_RotorItem=en-ZA/Enabled'" />
        <xsl:with-param name="title3" select="'スピーチ'" />
        <xsl:with-param name="title4" select="'声'" />
        <xsl:with-param name="valueNode" select="/RESULT/AXSVoiceOverCompactVoicePreference/Item[position()=1]/Enabled" />
        <xsl:with-param name="value">
          <xsl:call-template name="CompactVoice">
            <xsl:with-param name="value" select="/RESULT/AXSVoiceOverCompactVoicePreference/Item[position()=1]/Enabled"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:call-template name="CompactVoice">
            <xsl:with-param name="value" select="/RESULT/AXSVoiceOverCompactVoicePreference/Item[position()=1]/Enabled/@master"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="create" select="'true'" />
      </xsl:call-template>
    </xsl:if>

    <xsl:for-each select="/RESULT/VoiceOverTouchLanguageRotor/Item[./Enabled='true']">
      <xsl:variable name="rotorItem" select="RotorItem" />
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="concat('AXSVoiceOverCompactVoicePreference/Item_RotorItem=',RotorItem,'/Enabled')" />
        <xsl:with-param name="title3">
          <xsl:if test="position() = 1">言語をローテーション</xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title4">
          <xsl:call-template name="language">
            <xsl:with-param name="countrycode" select="RotorItem"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="title5" select="'高品質'" />
        <xsl:with-param name="valueNode" select="Enabled" />
        <xsl:with-param name="value">
          <xsl:call-template name="CompactVoice">
            <xsl:with-param name="value" select="/RESULT/AXSVoiceOverCompactVoicePreference/Item[starts-with(./RotorItem,$rotorItem)]/Enabled"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="sign" select="' '"/>
        <xsl:with-param name="mastervalue" select="' '"/>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="concat('VoiceOverTouchLanguageSpeakingRate/Item_RotorItem=',RotorItem,'/SpeakingRate')" />
        <xsl:with-param name="title5" select="'読み上げ速度'" />
        <xsl:with-param name="valueNode" select="Enabled" />
        <xsl:with-param name="value">
          <xsl:text>遅</xsl:text>
          <xsl:call-template name="slider3">
            <xsl:with-param name="position" select="/RESULT/VoiceOverTouchLanguageSpeakingRate/Item[starts-with(./RotorItem,$rotorItem)]/SpeakingRate"/>
            <xsl:with-param name="default" select="0.35"/>
            <xsl:with-param name="range" select="1"/>
          </xsl:call-template>
          <xsl:text>速(</xsl:text>
          <xsl:call-template name="slider4">
            <xsl:with-param name="position" select="/RESULT/VoiceOverTouchLanguageSpeakingRate/Item[starts-with(./RotorItem,$rotorItem)]/SpeakingRate"/>
            <xsl:with-param name="range" select="1"/>
            <xsl:with-param name="default" select="0.35"/>
          </xsl:call-template>
          <xsl:text>)</xsl:text>
          <!--<xsl:call-template name="Margin">
              <xsl:with-param name="margin" select="VoiceOverTouchLanguageSpeakingRate/@margin"/>
            </xsl:call-template>-->
        </xsl:with-param>
        <xsl:with-param name="sign" select="' '"/>
        <xsl:with-param name="mastervalue" select="' '"/>
      </xsl:call-template>

    </xsl:for-each>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AXSVoiceOverTouchBrailleDisplayOutputMode'" />
      <xsl:with-param name="title3" select="'点字'" />
      <xsl:with-param name="title4">
        <xsl:text>出力</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/AXSVoiceOverTouchBrailleDisplayOutputMode" />
      <xsl:with-param name="value">
        <xsl:call-template name="BrailleInputMode">
          <xsl:with-param name="value" select="/RESULT/AXSVoiceOverTouchBrailleDisplayOutputMode"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:if test="/RESULT/AXSVoiceOverTouchBrailleDisplayOutputMode/@master">
          <xsl:call-template name="BrailleInputMode">
            <xsl:with-param name="value" select="/RESULT/AXSVoiceOverTouchBrailleDisplayOutputMode/@master"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AXSVoiceOverTouchBrailleDisplayInputMode'" />
      <xsl:with-param name="title4">
        <xsl:text>入力</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/AXSVoiceOverTouchBrailleDisplayInputMode" />
      <xsl:with-param name="value">
        <xsl:call-template name="BrailleInputMode">
          <xsl:with-param name="value" select="/RESULT/AXSVoiceOverTouchBrailleDisplayInputMode"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:if test="/RESULT/AXSVoiceOverTouchBrailleDisplayInputMode/@master">
          <xsl:call-template name="BrailleInputMode">
            <xsl:with-param name="value" select="/RESULT/AXSVoiceOverTouchBrailleDisplayInputMode/@master"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverShowGrade2AutoTranslate'" />
      <xsl:with-param name="title5" select="'自動点訳'" />
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverShowGrade2AutoTranslate" />
      <xsl:with-param name="template" select="'defaultOff'"/>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AXSVoiceOverTouchBrailleGesturesInputMode'" />
      <xsl:with-param name="title4" select="'点字画面入力'" />
      <xsl:with-param name="valueNode" select="/RESULT/AXSVoiceOverTouchBrailleGesturesInputMode" />
      <xsl:with-param name="value">
        <xsl:call-template name="BrailleInputMode">
          <xsl:with-param name="value" select="/RESULT/AXSVoiceOverTouchBrailleGesturesInputMode"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:if test="/RESULT/AXSVoiceOverTouchBrailleGesturesInputMode/@master">
          <xsl:call-template name="BrailleInputMode">
            <xsl:with-param name="value" select="/RESULT/AXSVoiceOverTouchBrailleGesturesInputMode/@master"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>




    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'BrailleStatus2'" />
      <xsl:with-param name="title4" select="'状況セル'" />
      <xsl:with-param name="valueNode" select="/RESULT/BrailleStatus2" />
      <xsl:with-param name="value">
        <xsl:call-template name="BrailleStatus2">
          <xsl:with-param name="value" select="/RESULT/BrailleStatus2"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="BrailleStatus2">
          <xsl:with-param name="value" select="/RESULT/BrailleStatus2/@master"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'voiceOverAlwaysUseNemethCodeForMathEnabled'" />
      <xsl:with-param name="title4" select="'方程式でNemethコードを使用'" />
      <xsl:with-param name="valueNode" select="/RESULT/voiceOverAlwaysUseNemethCodeForMathEnabled" />
      <xsl:with-param name="template" select="'defaultOff'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverShowSWKeyboardWithBraille'" />
      <xsl:with-param name="title4" select="'オンスクリーンキーボード表示'" />
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverShowSWKeyboardWithBraille" />
      <xsl:with-param name="template" select="'defaultOff'"/>
    </xsl:call-template>


    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AXSVoiceOverTouchBraillePanningAutoTurnsReadingContent'" />
      <xsl:with-param name="title4" select="'パンでページめくり'" />
      <xsl:with-param name="valueNode" select="/RESULT/AXSVoiceOverTouchBraillePanningAutoTurnsReadingContent" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>
	<xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverTouchHintsEnabled'" />
      <xsl:with-param name="title3">
        <xsl:text>詳細度</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:text>ヒントを読み上げる</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverTouchHintsEnabled" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>
    <!--ローター-->
    <xsl:for-each select="/RESULT/VoiceOverTouchRotorItemsPreference/Item">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="concat('VoiceOverTouchRotorItemsPreference/Item_',position(),'/RotorItem')" />
        <xsl:with-param name="title3">
          <xsl:if test="position() = 1">ローター</xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title4" select="position()" />
        <xsl:with-param name="title5" select="'項目名'" />
        <xsl:with-param name="valueNode" select="RotorItem" />
        <xsl:with-param name="value">
          <xsl:call-template name="TouchRotorItem">
            <xsl:with-param name="item" select="RotorItem"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:if test="RotorItem/@master">
            <xsl:call-template name="TouchRotorItem">
              <xsl:with-param name="item" select="RotorItem/@master"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="concat('VoiceOverTouchRotorItemsPreference/Item_',position(),'/Enabled')" />
        <xsl:with-param name="title5" select="'有効化'" />
        <xsl:with-param name="valueNode" select="Enabled" />
        <xsl:with-param name="template" select="'defaultOff'"/>
      </xsl:call-template>

    </xsl:for-each>



    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverTouchTypingMode'" />
      <xsl:with-param name="title3" select="'入力モード'" />
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverTouchTypingMode" />
      <xsl:with-param name="value">
        <xsl:call-template name="TypingMode">
          <xsl:with-param name="value" select="/RESULT/VoiceOverTouchTypingMode"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:if test="/RESULT/VoiceOverTouchTypingMode/@master">
          <xsl:call-template name="TypingMode">
            <xsl:with-param name="value" select="/RESULT/VoiceOverTouchTypingMode/@master"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverTouchPhoneticsEnabledPreference7'" />
      <xsl:with-param name="title3">
        <xsl:text>文字説明フィードバック</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverTouchPhoneticsEnabledPreference7" />
      <xsl:with-param name="value">
        <xsl:call-template name="Phonetics11">
          <xsl:with-param name="value" select="/RESULT/VoiceOverTouchPhoneticsEnabledPreference7"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:if test="/RESULT/VoiceOverTouchPhoneticsEnabledPreference7/@master">
          <xsl:call-template name="Phonetics11">
            <xsl:with-param name="value" select="/RESULT/VoiceOverTouchPhoneticsEnabledPreference7/@master"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>



    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverTouchTypingFeedback8'" />
      <xsl:with-param name="title3" select="'入力フィードバック'" />
      <xsl:with-param name="title4" select="'ソフトウェアキーボード'" />
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverTouchTypingFeedback8" />
      <xsl:with-param name="value">
        <xsl:call-template name="VoiceOverTouchTypingFeedback">
          <xsl:with-param name="value" select="/RESULT/VoiceOverTouchTypingFeedback8"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="VoiceOverTouchTypingFeedback">
          <xsl:with-param name="value" select="/RESULT/VoiceOverTouchTypingFeedback8/@master"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VoiceOverTouchTypingHardwareFeedback8'" />
      <xsl:with-param name="title4" select="'ハードウェアキーボード'" />
      <xsl:with-param name="valueNode" select="/RESULT/VoiceOverTouchTypingHardwareFeedback8" />
      <xsl:with-param name="value">
        <xsl:call-template name="VoiceOverTouchTypingFeedback">
          <xsl:with-param name="value" select="/RESULT/VoiceOverTouchTypingHardwareFeedback8"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="VoiceOverTouchTypingFeedback">
          <xsl:with-param name="value" select="/RESULT/VoiceOverTouchTypingHardwareFeedback8/@master"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>


    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'SpeakNotificationInLockScreen8'" />
      <xsl:with-param name="title3">
        <xsl:text>常に通知を読み上げる</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/SpeakNotificationInLockScreen8" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'NavigateImagesPreference8'" />
      <xsl:with-param name="title3" select="'イメージをナビゲート'" />
      <xsl:with-param name="valueNode" select="/RESULT/NavigateImagesPreference8" />
      <xsl:with-param name="value">
        <xsl:call-template name="NavigateImagesPreference">
          <xsl:with-param name="this" select="/RESULT/NavigateImagesPreference8"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="NavigateImagesPreference">
          <xsl:with-param name="this" select="/RESULT/NavigateImagesPreference8/@master"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'com.apple.voiceovertouch.cursors.style'" />
      <xsl:with-param name="title3" select="'大きいカーソルを使用'" />
      <xsl:with-param name="valueNode" select="/RESULT/com.apple.voiceovertouch.cursors.style" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>


    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ZoomTouchEnabled'" />
      <xsl:with-param name="title2" select="'ズーム機能'" />
      <xsl:with-param name="valueNode" select="/RESULT/ZoomTouchEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ZoomShouldFollowFocus'" />
      <xsl:with-param name="title3" select="'カーソルに追従'" />
      <xsl:with-param name="valueNode" select="/RESULT/ZoomShouldFollowFocus" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ZoomAlwaysUseWindowZoomForTyping'" />
      <xsl:with-param name="title3" select="'ズームキーボード'" />
      <xsl:with-param name="valueNode" select="/RESULT/ZoomAlwaysUseWindowZoomForTyping" />
      <xsl:with-param name="value">
        <xsl:call-template name="falseOndefaultOff">
          <xsl:with-param name="bool" select="/RESULT/ZoomAlwaysUseWindowZoomForTyping"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="falseOndefaultOff">
          <xsl:with-param name="bool" select="/RESULT/ZoomAlwaysUseWindowZoomForTyping/@master"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ZoomShouldShowSlug'" />
      <xsl:with-param name="title3" select="'コントローラを表示'" />
      <xsl:with-param name="valueNode" select="/RESULT/ZoomShouldShowSlug" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ZoomIdleSlugOpacity'" />
      <xsl:with-param name="title3" select="'待機状態表示'" />
      <xsl:with-param name="valueNode" select="/RESULT/ZoomIdleSlugOpacity" />
      <xsl:with-param name="value">
        <xsl:call-template name="ZoomOpacity">
          <xsl:with-param name="this" select="/RESULT/ZoomIdleSlugOpacity"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:if test="/RESULT/ZoomIdleSlugOpacity/@master">
          <xsl:call-template name="ZoomOpacity">
            <xsl:with-param name="this" select="/RESULT/ZoomIdleSlugOpacity/@master"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ZoomPreferredLensMode'" />
      <xsl:with-param name="title3" select="'ズーム領域'" />
      <xsl:with-param name="valueNode" select="/RESULT/ZoomPreferredLensMode" />
      <xsl:with-param name="value">
        <xsl:call-template name="ZoomMode">
          <xsl:with-param name="this" select="/RESULT/ZoomPreferredLensMode"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="ZoomMode">
          <xsl:with-param name="this" select="/RESULT/ZoomPreferredLensMode/@master"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ZoomPreferredMaximumZoomScale'" />
      <xsl:with-param name="title3" select="'最大ズームレベル'" />
      <xsl:with-param name="valueNode" select="/RESULT/ZoomPreferredMaximumZoomScale" />
      <xsl:with-param name="value">
        <xsl:call-template name="ZoomScale">
          <xsl:with-param name="this" select="/RESULT/ZoomPreferredMaximumZoomScale"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:if test="/RESULT/ZoomPreferredMaximumZoomScale/@master">
          <xsl:call-template name="ZoomScale">
            <xsl:with-param name="this" select="/RESULT/ZoomPreferredMaximumZoomScale/@master"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>
	
	<!-- 追加 -->
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'MagnifierEnabled'" />
        <xsl:with-param name="title2" select="'拡大鏡'" />
        <xsl:with-param name="valueNode" select="/RESULT/MagnifierEnabled" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
		<xsl:with-param name="id" select="'EnhancedTextLegibilityEnabled'" />
		<xsl:with-param name="title2" select="'画面表示とテキストサイズ'" />
		<xsl:with-param name="title3" select="'文字を太くする'" />
		<xsl:with-param name="valueNode" select="/RESULT/EnhancedTextLegibilityEnabled" />
		<xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	<xsl:call-template name="settingtable">
		<xsl:with-param name="id" select="'largeTextUsesExtendedRange'" />
		<xsl:with-param name="title3" select="'さらに大きな文字'" />
		<xsl:with-param name="valueNode" select="/RESULT/largeTextUsesExtendedRange" />
		<xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	<xsl:if test="not(starts-with(/RESULT/ProductVersion, '7.0'))">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ButtonShapesEnabled'" />
        <xsl:with-param name="title3" select="'ボタンの形'" />
        <xsl:with-param name="valueNode" select="/RESULT/ButtonShapesEnabled" />
        <xsl:with-param name="template" select="'defaultOff'" />
      </xsl:call-template>
    </xsl:if>
	
	    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'IncreaseButtonLegibilityEnabled'" />
      <xsl:with-param name="title3" select="'オン/オフラベル'" />
      <xsl:with-param name="valueNode" select="/RESULT/IncreaseButtonLegibilityEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	<xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'EnhancedBackgroundContrastEnabled'" />
      <xsl:with-param name="title3" select="'透明度を下げる'" />
      <xsl:with-param name="valueNode" select="/RESULT/EnhancedBackgroundContrastEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	<xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'DarkenSystemColors'" />
      <xsl:with-param name="title3" select="'コントラストを上げる'" />
      <xsl:with-param name="valueNode" select="/RESULT/DarkenSystemColors" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'DifferentiateWithoutColor'" />
		<xsl:with-param name="title3" select="'カラー以外で区別'" />
		<xsl:with-param name="valueNode" select="/RESULT/DifferentiateWithoutColor" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/DifferentiateWithoutColor = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DifferentiateWithoutColor = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DifferentiateWithoutColor = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/DifferentiateWithoutColor/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DifferentiateWithoutColor/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DifferentiateWithoutColor/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'InvertColorsEnabled'" />
      <xsl:with-param name="title3" select="'反転（スマート）'" />
      <xsl:with-param name="valueNode" select="/RESULT/InvertColorsEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AXSClassicInvertColorsPreference'" />
		<xsl:with-param name="title3" select="'反転（クラシック）'" />
		<xsl:with-param name="valueNode" select="/RESULT/AXSClassicInvertColorsPreference" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/AXSClassicInvertColorsPreference = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXSClassicInvertColorsPreference = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXSClassicInvertColorsPreference = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/AXSClassicInvertColorsPreference/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXSClassicInvertColorsPreference/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXSClassicInvertColorsPreference/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ColorMADisplayFilterCategoryEnabled'" />
		<xsl:with-param name="title3" select="'カラーフィルター'" />
		<xsl:with-param name="valueNode" select="/RESULT/ColorMADisplayFilterCategoryEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/ColorMADisplayFilterCategoryEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ColorMADisplayFilterCategoryEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ColorMADisplayFilterCategoryEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/ColorMADisplayFilterCategoryEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ColorMADisplayFilterCategoryEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ColorMADisplayFilterCategoryEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ReduceWhitePointEnabled'" />
      <xsl:with-param name="title3" select="'ホワイトポイントを下げる'" />
      <xsl:with-param name="valueNode" select="/RESULT/ReduceWhitePointEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>

	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'BKEnableALS'" />
        <xsl:with-param name="title3" select="'明るさの自動調節'" />
        <xsl:with-param name="valueNode" select="/RESULT/BKEnableALS" />
        <xsl:with-param name="template" select="'defaultOn'"/>
	</xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ReduceMotionEnabled'" />
	  <xsl:with-param name="title2" select="'動作'" />
      <xsl:with-param name="title3" select="'視差効果を減らす'" />
      <xsl:with-param name="valueNode" select="/RESULT/ReduceMotionEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ReduceMotionAutoplayMessagesEffectsEnabled'" />
		<xsl:with-param name="title3" select="'メッセージエフェクト自動再生'" />
		<xsl:with-param name="valueNode" select="/RESULT/ReduceMotionAutoplayMessagesEffectsEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/ReduceMotionAutoplayMessagesEffectsEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ReduceMotionAutoplayMessagesEffectsEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ReduceMotionAutoplayMessagesEffectsEnabled = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/ReduceMotionAutoplayMessagesEffectsEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ReduceMotionAutoplayMessagesEffectsEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ReduceMotionAutoplayMessagesEffectsEnabled/@master = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>

	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ReduceMotionAutoplayVideoPreviewsEnabled'" />
		<xsl:with-param name="title3" select="'ビデオプレビューの自動再生'" />
		<xsl:with-param name="valueNode" select="/RESULT/ReduceMotionAutoplayVideoPreviewsEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/ReduceMotionAutoplayVideoPreviewsEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ReduceMotionAutoplayVideoPreviewsEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ReduceMotionAutoplayVideoPreviewsEnabled = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/ReduceMotionAutoplayVideoPreviewsEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ReduceMotionAutoplayVideoPreviewsEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ReduceMotionAutoplayVideoPreviewsEnabled/@master = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'QuickSpeak'" />
      <xsl:with-param name="title2">
        <xsl:text>読み上げコンテンツ</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:text>選択項目の読み上げ</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/QuickSpeak" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'QuickSpeakHighlightText8'" />
      <xsl:with-param name="title4" select="'内容を強調表示'" />
      <xsl:with-param name="valueNode" select="/RESULT/QuickSpeakHighlightText8" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>

	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'SpeakThisEnabled'" />
		<xsl:with-param name="title3" select="'画面の読み上げ'" />
		<xsl:with-param name="valueNode" select="/RESULT/SpeakThisEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/SpeakThisEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/SpeakThisEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/SpeakThisEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/SpeakThisEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/SpeakThisEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/SpeakThisEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'LetterFeedbackEnabled'" />
		<xsl:with-param name="title3" select="'入力フィードバック'" />
		<xsl:with-param name="title4" select="'文字'" />
		<xsl:with-param name="valueNode" select="/RESULT/LetterFeedbackEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/LetterFeedbackEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/LetterFeedbackEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/LetterFeedbackEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/LetterFeedbackEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/LetterFeedbackEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/LetterFeedbackEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'PhoneticFeedbackEnabled'" />
		<xsl:with-param name="title4" select="'文字発音'" />
		<xsl:with-param name="valueNode" select="/RESULT/PhoneticFeedbackEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/PhoneticFeedbackEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/PhoneticFeedbackEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/PhoneticFeedbackEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/PhoneticFeedbackEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/PhoneticFeedbackEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/PhoneticFeedbackEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'WordFeedbackEnabled'" />
		<xsl:with-param name="title4" select="'単語を読み上げる'" />
		<xsl:with-param name="valueNode" select="/RESULT/WordFeedbackEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/WordFeedbackEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/WordFeedbackEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/WordFeedbackEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/WordFeedbackEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/WordFeedbackEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/WordFeedbackEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'SpeakCorrectionsEnabled'" />
      <xsl:with-param name="title4">
        <xsl:text>自動テキスト読み上げ</xsl:text>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/SpeakCorrectionsEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'QuickTypePredictionFeedbackEnabled'" />
		<xsl:with-param name="title4" select="'押さえて予測変換を読み上げる'" />
		<xsl:with-param name="valueNode" select="/RESULT/QuickTypePredictionFeedbackEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/QuickTypePredictionFeedbackEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/QuickTypePredictionFeedbackEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/QuickTypePredictionFeedbackEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/QuickTypePredictionFeedbackEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/QuickTypePredictionFeedbackEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/QuickTypePredictionFeedbackEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	    <xsl:if test="/RESULT/SpeakThisEnabled = '1' or /RESULT/SpeakThisEnabled = 'true' or /RESULT/QuickSpeak = 'true'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'QuickSpeakPrefersCompactForLanguage/Item_Name=ja-JP/Enabled'" />
        <xsl:with-param name="title3" select="'声'" />
        <xsl:with-param name="title4" select="'日本語'" />
        <xsl:with-param name="valueNode" select="/RESULT/QuickSpeakPrefersCompactForLanguage/Item[Name='ja-JP']/Enabled" />
        <xsl:with-param name="value">
          <xsl:call-template name="CompactVoice">
            <xsl:with-param name="value" select="/RESULT/QuickSpeakPrefersCompactForLanguage/Item[Name='ja-JP']/Enabled"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:call-template name="CompactVoice">
            <xsl:with-param name="value" select="/RESULT/QuickSpeakPrefersCompactForLanguage/Item[Name='ja-JP']/Enabled/@master"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
	  
	  

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'QuickSpeakRate8'" />
        <xsl:with-param name="title3" select="'読み上げ速度'" />
        <xsl:with-param name="valueNode" select="/RESULT/QuickSpeakRate8" />
        <xsl:with-param name="value">
          <xsl:text>遅</xsl:text>
          <xsl:call-template name="slider3">
            <xsl:with-param name="position" select="/RESULT/QuickSpeakRate8/text()"/>
            <xsl:with-param name="default" select="0.35"/>
            <xsl:with-param name="range" select="1"/>
          </xsl:call-template>
          <xsl:text>速(</xsl:text>
          <xsl:call-template name="slider4">
            <xsl:with-param name="position" select="/RESULT/QuickSpeakRate8"/>
            <xsl:with-param name="range" select="1"/>
            <xsl:with-param name="default" select="0.35"/>
          </xsl:call-template>
          <xsl:text>)</xsl:text>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:text>遅</xsl:text>
          <xsl:call-template name="slider3">
            <xsl:with-param name="position" select="/RESULT/QuickSpeakRate8/@master"/>
            <xsl:with-param name="default" select="0.35"/>
            <xsl:with-param name="range" select="1"/>
          </xsl:call-template>
          <xsl:text>速(</xsl:text>
          <xsl:call-template name="slider4">
            <xsl:with-param name="position" select="/RESULT/QuickSpeakRate8/@master"/>
            <xsl:with-param name="range" select="1"/>
            <xsl:with-param name="default" select="0.35"/>
          </xsl:call-template>
          <xsl:text>)</xsl:text>
          <xsl:call-template name="Margin">
            <xsl:with-param name="margin" select="QuickSpeakRate8/@margin"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'MAAudibleMediaPrefPreferDescriptiveVideo'" />
        <xsl:with-param name="title2" select="'バリアフリー音声ガイド'" />
        <xsl:with-param name="valueNode" select="/RESULT/MAAudibleMediaPrefPreferDescriptiveVideo" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	</xsl:call-template>
	
	    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchEnabled'" />
	  <xsl:with-param name="title2" select="'タッチ'" />
      <xsl:with-param name="title3" select="'AssistiveTouch'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchEnabled" />
      <xsl:with-param name="value">
		<xsl:choose>
		  <xsl:when test="/RESULT/AssistiveTouchEnabled = ''">
			<xsl:text>オフ</xsl:text>
		  </xsl:when>
		  <xsl:otherwise>
            <xsl:call-template name="ZeroOffOneOn">
              <xsl:with-param name="value" select="/RESULT/AssistiveTouchEnabled"/>
            </xsl:call-template>
		  </xsl:otherwise>
		</xsl:choose>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
	  <xsl:choose>
		  <xsl:when test="/RESULT/AssistiveTouchEnabled/@master = ''">
			<xsl:text>オフ</xsl:text>
		  </xsl:when>
		  <xsl:otherwise>
            <xsl:call-template name="ZeroOffOneOn">
              <xsl:with-param name="value" select="/RESULT/AssistiveTouchEnabled/@master"/>
            </xsl:call-template>
		  </xsl:otherwise>
		</xsl:choose>
      </xsl:with-param>
    </xsl:call-template>
	    <xsl:for-each select="/RESULT/AssistiveTouchCustomGestures/*">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchEnabled'" />
        <xsl:with-param name="title3">
          <xsl:if test="position() = 1">カスタムジェスチャ</xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title4">
          ジェスチャ<xsl:value-of select="position()"/>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="."/>
        <xsl:with-param name="template" select="'text'" />
      </xsl:call-template>
    </xsl:for-each>

	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ForceTouchEnabled'" />
		<xsl:with-param name="title3" select="'3D Touchおよび触覚タッチ'" />
		<xsl:with-param name="title4" select="'3D Touch'" />
		<xsl:with-param name="valueNode" select="/RESULT/ForceTouchEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/ForceTouchEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ForceTouchEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ForceTouchEnabled = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/ForceTouchEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ForceTouchEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ForceTouchEnabled/@master = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ForceTouchTiming'" />
		<xsl:with-param name="title4" select="'タッチの継続時間'" />
		<xsl:with-param name="valueNode" select="/RESULT/ForceTouchTiming" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/ForceTouchTiming = '1'">
					<xsl:text>速い</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ForceTouchTiming = '0'">
					<xsl:text>遅く</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ForceTouchTiming = ''">
					<xsl:text>速い</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/ForceTouchTiming/@master = '1'">
					<xsl:text>速い</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ForceTouchTiming/@master = '0'">
					<xsl:text>遅く</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ForceTouchTiming/@master = ''">
					<xsl:text>速い</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'TouchAccommodationsEnabledPreference'" />
        <xsl:with-param name="title3" select="'タッチ調整'" />
		<xsl:with-param name="title4" select="'タッチ調整'" />
        <xsl:with-param name="valueNode" select="/RESULT/TouchAccommodationsEnabledPreference" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'TouchAccommodationsHoldDurationEnabledPreference'" />
		<xsl:with-param name="title4" select="'保持継続時間'" />
        <xsl:with-param name="valueNode" select="/RESULT/TouchAccommodationsHoldDurationEnabledPreference" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'TouchAccommodationsIgnoreRepeatEnabledPreference'" />
		<xsl:with-param name="title4" select="'繰り返しを無視'" />
        <xsl:with-param name="valueNode" select="/RESULT/TouchAccommodationsIgnoreRepeatEnabledPreference" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'TouchAccommodationsTapActivationMethodPreference'" />
		<xsl:with-param name="title4" select="'タップ補助'" />
		<xsl:with-param name="valueNode" select="/RESULT/TouchAccommodationsTapActivationMethodPreference" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/TouchAccommodationsTapActivationMethodPreference = '1'">
					<xsl:text>タッチ開始位置を使用</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/TouchAccommodationsTapActivationMethodPreference = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/TouchAccommodationsTapActivationMethodPreference = '2'">
					<xsl:text>タッチ終了位置を使用</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/TouchAccommodationsTapActivationMethodPreference = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/TouchAccommodationsTapActivationMethodPreference/@master = '1'">
					<xsl:text>タッチ開始位置を使用</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/TouchAccommodationsTapActivationMethodPreference/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/TouchAccommodationsTapActivationMethodPreference/@master = '2'">
					<xsl:text>タッチ終了位置を使用</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/TouchAccommodationsTapActivationMethodPreference/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ShakeToUndoDisabled'" />
		<xsl:with-param name="title3" select="'シェイクで取り消し'" />
		<xsl:with-param name="valueNode" select="/RESULT/ShakeToUndoDisabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/ShakeToUndoDisabled = '0'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ShakeToUndoDisabled = '1'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ShakeToUndoDisabled = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/ShakeToUndoDisabled/@master = '0'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ShakeToUndoDisabled/@master = '1'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ShakeToUndoDisabled/@master = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'DefaultRouteForCallPreference'" />
		<xsl:with-param name="title3" select="'通話オーディオルーティング'" />
		<xsl:with-param name="valueNode" select="/RESULT/DefaultRouteForCallPreference" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/DefaultRouteForCallPreference = '0'">
					<xsl:text>自動</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DefaultRouteForCallPreference = '1'">
					<xsl:text>Bluetoothヘッドセット</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DefaultRouteForCallPreference = '2'">
					<xsl:text>スピーカー</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DefaultRouteForCallPreference = ''">
					<xsl:text>自動</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/DefaultRouteForCallPreference/@master = '0'">
					<xsl:text>自動</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DefaultRouteForCallPreference/@master = '1'">
					<xsl:text>Bluetoothヘッドセット</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DefaultRouteForCallPreference/@master = '2'">
					<xsl:text>スピーカー</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/DefaultRouteForCallPreference/@master = ''">
					<xsl:text>自動</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchAutoAddedTCItem'" />
		<xsl:with-param name="title2" select="'スイッチコントロール'" />
		<xsl:with-param name="title3" select="'スイッチコントロール'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchAutoAddedTCItem" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	</xsl:call-template>
	 <!-- <xsl:call-template name="settingtable"> -->
      <!-- <xsl:with-param name="id" select="'SCScanningStyle'" /> -->
      <!-- <xsl:with-param name="title3" select="'ハイライトのスタイル'" /> -->
      <!-- <xsl:with-param name="valueNode" select="/RESULT/SCScanningStyle" /> -->
      <!-- <xsl:with-param name="value"> -->
			<!-- <xsl:choose> -->
				<!-- <xsl:when test="/RESULT/SCScanningStyle = '0'"> -->
					<!-- <xsl:text>自動ハイライト</xsl:text> -->
				<!-- </xsl:when> -->
				<!-- <xsl:when test="/RESULT/SCScanningStyle = '1'"> -->
					<!-- <xsl:text>手動ハイライト</xsl:text> -->
				<!-- </xsl:when> -->
				<!-- <xsl:when test="/RESULT/SCScanningStyle = '2'"> -->
					<!-- <xsl:text>単一スイッチステップハイライト</xsl:text> -->
				<!-- </xsl:when> -->
				<!-- <xsl:when test="/RESULT/SCScanningStyle = ''"> -->
					<!-- <xsl:text>自動ハイライト</xsl:text> -->
				<!-- </xsl:when> -->
			<!-- </xsl:choose> -->
		<!-- </xsl:with-param> -->
		<!-- <xsl:with-param name="mastervalue"> -->
			<!-- <xsl:choose> -->
				<!-- <xsl:when test="/RESULT/SCScanningStyle/@master = '0'"> -->
					<!-- <xsl:text>自動ハイライト</xsl:text> -->
				<!-- </xsl:when> -->
				<!-- <xsl:when test="/RESULT/SCScanningStyle/@master = '1'"> -->
					<!-- <xsl:text>手動ハイライト</xsl:text> -->
				<!-- </xsl:when> -->
				<!-- <xsl:when test="/RESULT/SCScanningStyle/@master = '2'"> -->
					<!-- <xsl:text>単一スイッチステップハイライト</xsl:text> -->
				<!-- </xsl:when> -->
				<!-- <xsl:when test="/RESULT/SCScanningStyle/@master = ''"> -->
					<!-- <xsl:text>自動ハイライト</xsl:text> -->
				<!-- </xsl:when> -->
			<!-- </xsl:choose> -->
		<!-- </xsl:with-param> -->
    <!-- </xsl:call-template> -->

    <!-- <xsl:if test="/RESULT/SCScanningStyle = '0'  or /RESULT/SCScanningStyle = ''"> -->
	<xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchAutoScanningEnabled'" />
      <xsl:with-param name="title3" select="'自動ハイライト'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchAutoScanningEnabled" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>

    <xsl:if test="/RESULT/AssistiveTouchAutoScanningEnabled = 'true'  or /RESULT/AssistiveTouchAutoScanningEnabled = ''">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchStepInterval'" />
        <xsl:with-param name="title3" select="'自動ハイライトの時間'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchStepInterval" />
        <xsl:with-param name="value">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchStepInterval = ''">1.0秒</xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(/RESULT/AssistiveTouchStepInterval,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchStepInterval/@master = ''">1.0秒</xsl:when>
            <xsl:when test="not(/RESULT/AssistiveTouchStepInterval/@master)"></xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(AssistiveTouchStepInterval/@master,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchDelayAfterInputEnabledPreference'" />
        <xsl:with-param name="title3" select="'最初の項目で一時停止'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchDelayAfterInputEnabledPreference" />
        <xsl:with-param name="template" select="'defaultOff'" />
      </xsl:call-template>

      <xsl:if test="/RESULT/AssistiveTouchDelayAfterInputEnabledPreference = 'true'">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AssistiveTouchDelayAfterInputPreference'" />
          <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchDelayAfterInputPreference" />
          <xsl:with-param name="value">
            <xsl:choose>
              <xsl:when test="/RESULT/AssistiveTouchDelayAfterInputPreference = ''">0.5秒</xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="format-number(/RESULT/AssistiveTouchDelayAfterInputPreference,'0.0#')"/>秒
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
          <xsl:with-param name="mastervalue">
            <xsl:choose>
              <xsl:when test="/RESULT/AssistiveTouchDelayAfterInputPreference/@master = ''">0.5秒</xsl:when>
              <xsl:when test="not(/RESULT/AssistiveTouchDelayAfterInputPreference/@master)"></xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="format-number(/RESULT/AssistiveTouchDelayAfterInputPreference/@master,'0.0#')"/>秒
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
        </xsl:call-template>

      </xsl:if>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchScanCyclesPreference'" />
        <xsl:with-param name="title3" select="'繰り返し'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchScanCyclesPreference" />
        <xsl:with-param name="value">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchScanCyclesPreference = ''">4</xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="/RESULT/AssistiveTouchScanCyclesPreference"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchScanCyclesPreference/@master = ''">4</xsl:when>
            <xsl:when test="not(/RESULT/AssistiveTouchScanCyclesPreference/@master)"></xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="/RESULT/AssistiveTouchScanCyclesPreference/@master"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <!-- <xsl:if test="/RESULT/SCScanningStyle = '2' or /RESULT/SCScanningStyle = '1'"> -->
	<xsl:if test="/RESULT/AssistiveTouchAutoScanningEnabled = 'false'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchScannerScanTimeoutEnabled'" />
        <xsl:with-param name="title3" select="'自動的に隠す'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchScannerScanTimeoutEnabled" />
        <xsl:with-param name="template" select="'defaultOff'" />
      </xsl:call-template>

      <xsl:if test="/RESULT/AssistiveTouchScannerScanTimeoutEnabled = 'true'">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AssistiveTouchScannerScanTimeout'" />
          <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchScannerScanTimeout" />
          <xsl:with-param name="value">
            <xsl:value-of select="format-number(/RESULT/AssistiveTouchScannerScanTimeout,'#0')"/>秒
          </xsl:with-param>
          <xsl:with-param name="mastervalue">
            <xsl:value-of select="format-number(/RESULT/AssistiveTouchScannerScanTimeout/@master,'#0')"/>秒
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchScannerSelectTimeoutEnabled'" />
      <xsl:with-param name="title3" select="'自動タップ'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchScannerSelectTimeoutEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>

    <xsl:if test="/RESULT/AssistiveTouchScannerSelectTimeoutEnabled = 'true'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchScannerSelectTimeout'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchScannerSelectTimeout" />
        <xsl:with-param name="value">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchScannerSelectTimeout = ''">0.75秒</xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(/RESULT/AssistiveTouchScannerSelectTimeout,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchScannerSelectTimeout/@master = ''">0.75秒</xsl:when>
            <xsl:when test="not(/RESULT/AssistiveTouchScannerSelectTimeout/@master)"></xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(/RESULT/AssistiveTouchScannerSelectTimeout/@master,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchActionRepeatEnabledPreference'" />
      <xsl:with-param name="title3" select="'移動の繰り返し'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchActionRepeatEnabledPreference" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
    <xsl:if test="/RESULT/AssistiveTouchActionRepeatEnabledPreference = 'true'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchActionRepeatIntervalPreference'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchActionRepeatIntervalPreference" />
        <xsl:with-param name="value">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchActionRepeatIntervalPreference = ''">0.5秒</xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(/RESULT/AssistiveTouchActionRepeatIntervalPreference,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchActionRepeatIntervalPreference/@master = ''">0.5秒</xsl:when>
            <xsl:when test="not(/RESULT/AssistiveTouchActionRepeatIntervalPreference/@master)"></xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(/RESULT/AssistiveTouchActionRepeatIntervalPreference/@master,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchInputHoldEnabledPreference'" />
      <xsl:with-param name="title3" select="'保持継続時間'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchInputHoldEnabledPreference" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
    <xsl:if test="/RESULT/AssistiveTouchInputHoldEnabledPreference = 'true'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchInputHoldDurationPreference'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchInputHoldDurationPreference" />
        <xsl:with-param name="value">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchInputHoldDurationPreference = ''">0.1秒</xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(/RESULT/AssistiveTouchInputHoldDurationPreference,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchInputHoldDurationPreference/@master = ''">0.1秒</xsl:when>
            <xsl:when test="not(/RESULT/AssistiveTouchInputHoldDurationPreference/@master)"></xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(/RESULT/AssistiveTouchInputHoldDurationPreference/@master,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchInputCoalescingEnabledPreference'" />
      <xsl:with-param name="title3" select="'繰り返しを無視'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchInputCoalescingEnabledPreference" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
    <xsl:if test="/RESULT/AssistiveTouchInputCoalescingEnabledPreference = 'true'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchInputCoalescingEnabledPreference'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchInputCoalescingEnabledPreference" />
        <xsl:with-param name="value">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchInputCoalescingDurationPreference = ''">0.1秒</xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(/RESULT/AssistiveTouchInputCoalescingDurationPreference,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:choose>
            <xsl:when test="/RESULT/AssistiveTouchInputCoalescingDurationPreference/@master = ''">0.1秒</xsl:when>
            <xsl:when test="not(/RESULT/AssistiveTouchInputCoalescingDurationPreference/@master)"></xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="format-number(/RESULT/AssistiveTouchInputCoalescingDurationPreference/@master,'0.0#')"/>秒
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchAxisSweepSpeed'" />
      <xsl:with-param name="title3" select="'グライドカーソルの速度'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchAxisSweepSpeed" />
      <xsl:with-param name="value">
        <xsl:call-template name="SweepSpeed">
          <xsl:with-param name="value" select="/RESULT/AssistiveTouchAxisSweepSpeed"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="SweepSpeed">
          <xsl:with-param name="value" select="/RESULT/AssistiveTouchAxisSweepSpeed/@master"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchScannerSoundEnabled'" />
      <xsl:with-param name="title3" select="'効果音'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchScannerSoundEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchScannerSpeechEnabled'" />
      <xsl:with-param name="title3" select="'音声読み上げ'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchScannerSpeechEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	<xsl:if test="/RESULT/AssistiveTouchScannerSpeechEnabled = 'true'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AssistiveTouchScannerSpeechRatePreference'" />
        <xsl:with-param name="title4" select="'読み上げ速度'" />
        <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchScannerSpeechRatePreference" />
        <xsl:with-param name="value">
          <xsl:text>遅</xsl:text>
          <xsl:call-template name="slider3">
            <xsl:with-param name="position" select="/RESULT/AssistiveTouchScannerSpeechRatePreference/text()"/>
            <xsl:with-param name="default" select="0.3"/>
            <xsl:with-param name="range" select="1"/>
          </xsl:call-template>
          <xsl:text>速(</xsl:text>
          <xsl:call-template name="slider4">
            <xsl:with-param name="position" select="/RESULT/AssistiveTouchScannerSpeechRatePreference"/>
            <xsl:with-param name="range" select="1"/>
            <xsl:with-param name="default" select="0.3"/>
          </xsl:call-template>
          <xsl:text>)</xsl:text>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:text>遅</xsl:text>
          <xsl:call-template name="slider3">
            <xsl:with-param name="position" select="AssistiveTouchScannerSpeechRatePreference//@master"/>
            <xsl:with-param name="default" select="0.3"/>
            <xsl:with-param name="range" select="1"/>
          </xsl:call-template>
          <xsl:text>速(</xsl:text>
          <xsl:call-template name="slider4">
            <xsl:with-param name="position" select="AssistiveTouchScannerSpeechRatePreference/@master"/>
            <xsl:with-param name="range" select="1"/>
            <xsl:with-param name="default" select="0.3"/>
          </xsl:call-template>
          <xsl:text>)</xsl:text>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AXSAssistiveTouchScannerMenuIncludeHomeItem'" />
      <xsl:with-param name="title3" select="'含まれているメニュー項目'" />
      <xsl:with-param name="title4" select="'ホーム'" />
      <xsl:with-param name="valueNode" select="/RESULT/AXSAssistiveTouchScannerMenuIncludeHomeItem" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AXSAssistiveTouchScannerMenuIncludeScrollItem'" />
      <xsl:with-param name="title4" select="'スクロール'" />
      <xsl:with-param name="valueNode" select="/RESULT/AXSAssistiveTouchScannerMenuIncludeScrollItem" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AXSAssistiveTouchScannerMenuIncludeDeviceItem'" />
      <xsl:with-param name="title4" select="'デバイス'" />
      <xsl:with-param name="valueNode" select="/RESULT/AXSAssistiveTouchScannerMenuIncludeDeviceItem" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AXSAssistiveTouchScannerMenuIncludeGesturesItem'" />
      <xsl:with-param name="title4" select="'ジェスチャ'" />
      <xsl:with-param name="valueNode" select="/RESULT/AXSAssistiveTouchScannerMenuIncludeGesturesItem" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AXSAssistiveTouchScannerMenuIncludeSettingsItem'" />
      <xsl:with-param name="title4" select="'設定'" />
      <xsl:with-param name="valueNode" select="/RESULT/AXSAssistiveTouchScannerMenuIncludeSettingsItem" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchScanShouldGroupElements'" />
      <xsl:with-param name="title3" select="'項目をグループ化'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchScanShouldGroupElements" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchCursorHighVisibilityPreference'" />
      <xsl:with-param name="title3" select="'大きいカーソルを使用'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchCursorHighVisibilityPreference" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchCursorColorPreference'" />
      <xsl:with-param name="title3" select="'カーソルの色'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchCursorColorPreference" />
      <xsl:with-param name="value">
        <xsl:call-template name="CursorColor">
          <xsl:with-param name="value" select="/RESULT/AssistiveTouchCursorColorPreference"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="CursorColor">
          <xsl:with-param name="value" select="/RESULT/AssistiveTouchCursorColorPreference/@master"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchSavedGestures'" />
      <xsl:with-param name="title3" select="'保存済みのジェスチャ'" />
      <xsl:with-param name="valueNode" select="/RESULT/AssistiveTouchSavedGestures" />
      <xsl:with-param name="value" select="' '" />
      <xsl:with-param name="sign" select="' '" />
      <xsl:with-param name="mastervalue" select="' '" />
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AssistiveTouchSavedGesturesCount'" />
      <xsl:with-param name="title4" select="'設定数'" />
      <xsl:with-param name="value">
        <xsl:value-of select="count(/RESULT/AssistiveTouchSavedGestures/*/text())"/>
      </xsl:with-param>
      <xsl:with-param name="sign" select="' '" />
      <xsl:with-param name="mastervalue" select="' '" />
    </xsl:call-template>
    <xsl:for-each select="/RESULT/AssistiveTouchSavedGestures/*">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="concat('AssistiveTouchSavedGestures_', position())" />
        <xsl:with-param name="title5">
          ジェスチャ<xsl:value-of select="position()"/>
        </xsl:with-param>
        <xsl:with-param name="value">
          <xsl:value-of select="./text()"/>
        </xsl:with-param>
        <xsl:with-param name="sign" select="' '" />
        <xsl:with-param name="mastervalue" select="' '" />
      </xsl:call-template>
    </xsl:for-each>

	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'CommandAndControlEnabled'" />
		<xsl:with-param name="title2" select="'音声コントロール'" />
		<xsl:with-param name="valueNode" select="/RESULT/CommandAndControlEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/CommandAndControlEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/CommandAndControlEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/CommandAndControlEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/CommandAndControlEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/CommandAndControlEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/CommandAndControlEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	<!-- ◆8)音声コントロール -->

	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'HomeClickSpeed'" />
		<xsl:with-param name="title2" select="'ホームボタン'" />
		<xsl:with-param name="title3" select="'クリックの間隔'" />
		<xsl:with-param name="valueNode" select="/RESULT/HomeClickSpeed" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/HomeClickSpeed = '0.34999999403953552'">
					<xsl:text>デフォルト</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeClickSpeed = '0.5'">
					<xsl:text>遅く</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeClickSpeed = '0.69999998807907104'">
					<xsl:text>最も遅く</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeClickSpeed = ''">
					<xsl:text>デフォルト</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/HomeClickSpeed/@master = '0.34999999403953552'">
					<xsl:text>デフォルト</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeClickSpeed/@master = '0.5'">
					<xsl:text>遅く</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeClickSpeed/@master = '0.69999998807907104'">
					<xsl:text>最も遅く</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeClickSpeed/@master = ''">
					<xsl:text>デフォルト</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'HomeButtonAssistantPreference'" />
		<xsl:with-param name="title3" select="'押したままにして話す'" />
		<xsl:with-param name="valueNode" select="/RESULT/HomeButtonAssistantPreference" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/HomeButtonAssistantPreference = '0'">
					<xsl:text>Siri</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeButtonAssistantPreference = '1'">
					<xsl:text>音声コントロール（クラシック）</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeButtonAssistantPreference = '2'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeButtonAssistantPreference = ''">
					<xsl:text>Siri</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/HomeButtonAssistantPreference/@master = '0'">
					<xsl:text>Siri</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeButtonAssistantPreference/@master = '1'">
					<xsl:text>音声コントロール（クラシック）</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeButtonAssistantPreference/@master = '2'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HomeButtonAssistantPreference/@master = ''">
					<xsl:text>Siri</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AXRestingHomeButtonUnlock'" />
		<xsl:with-param name="title3" select="'指を当てて開く'" />
		<xsl:with-param name="valueNode" select="/RESULT/AXRestingHomeButtonUnlock" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/AXRestingHomeButtonUnlock = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXRestingHomeButtonUnlock = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXRestingHomeButtonUnlock = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/AXRestingHomeButtonUnlock/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXRestingHomeButtonUnlock/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXRestingHomeButtonUnlock/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AppleTVSimpleGesturesEnabled'" />
		<xsl:with-param name="title2" select="'Apple TV Remote'" />
		<xsl:with-param name="title3" select="'方向ボタン'" />
		<xsl:with-param name="valueNode" select="/RESULT/AppleTVSimpleGesturesEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/AppleTVSimpleGesturesEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AppleTVSimpleGesturesEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AppleTVSimpleGesturesEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/AppleTVSimpleGesturesEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AppleTVSimpleGesturesEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AppleTVSimpleGesturesEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'FullKeyboardAccessEnabled'" />
		<xsl:with-param name="title2" select="'キーボード'" />
		<xsl:with-param name="title3" select="'フルキーボードアクセス'" />
		<xsl:with-param name="valueNode" select="/RESULT/FullKeyboardAccessEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/FullKeyboardAccessEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/FullKeyboardAccessEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/FullKeyboardAccessEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/FullKeyboardAccessEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/FullKeyboardAccessEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/FullKeyboardAccessEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'KeyRepeatEnabled'" />
		<xsl:with-param name="title3" select="'キーのリピート'" />
		<xsl:with-param name="valueNode" select="/RESULT/KeyRepeatEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/KeyRepeatEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/KeyRepeatEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/KeyRepeatEnabled = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>オン</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/KeyRepeatEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/KeyRepeatEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/KeyRepeatEnabled/@master = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>オン</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'StickyKeysEnabled'" />
		<xsl:with-param name="title3" select="'複合キー'" />
		<xsl:with-param name="valueNode" select="/RESULT/StickyKeysEnabled" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	</xsl:call-template>

	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'StickyKeysShiftToggleEnabled'" />
		<xsl:with-param name="title4" select="'Shiftキーで切り替え'" />
		<xsl:with-param name="valueNode" select="/RESULT/StickyKeysShiftToggleEnabled" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'StickyKeysBeepEnabled'" />
		<xsl:with-param name="title4" select="'サウンド'" />
		<xsl:with-param name="valueNode" select="/RESULT/StickyKeysBeepEnabled" />
        <xsl:with-param name="template" select="'defaultOn'"/>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'SlowKeysEnabled'" />
		<xsl:with-param name="title3" select="'スローキー'" />
		<xsl:with-param name="valueNode" select="/RESULT/SlowKeysEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/SlowKeysEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/SlowKeysEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/SlowKeysEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/SlowKeysEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/SlowKeysEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/SlowKeysEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'LowerCaseKeyboard'" />
		<xsl:with-param name="title3" select="'小文字キーを表示'" />
		<xsl:with-param name="valueNode" select="/RESULT/LowerCaseKeyboard" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/LowerCaseKeyboard = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/LowerCaseKeyboard = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/LowerCaseKeyboard = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/LowerCaseKeyboard/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/LowerCaseKeyboard/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/LowerCaseKeyboard/@master = ''">
					<xsl:text>オン</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'HearingAidCompliance'" />
		<xsl:with-param name="title2" select="'ヒアリングデバイス'" />
		<xsl:with-param name="title3" select="'補聴器の互換性'" />
		<xsl:with-param name="valueNode" select="/RESULT/HearingAidCompliance" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/HearingAidCompliance = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HearingAidCompliance = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HearingAidCompliance = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/HearingAidCompliance/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HearingAidCompliance/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/HearingAidCompliance/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AXSEnabledSoundDetectionState'" />
		<xsl:with-param name="title2" select="'サウンド認識'" />
		<xsl:with-param name="valueNode" select="/RESULT/AXSEnabledSoundDetectionState" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/AXSEnabledSoundDetectionState = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXSEnabledSoundDetectionState = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXSEnabledSoundDetectionState = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/AXSEnabledSoundDetectionState/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXSEnabledSoundDetectionState/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AXSEnabledSoundDetectionState/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'PersonalMediaEnabled'" />
		<xsl:with-param name="title2" select="'オーディオ/ビジュアル'" />
		<xsl:with-param name="title3" select="'ヘッドフォン調整'" />
		<xsl:with-param name="valueNode" select="/RESULT/PersonalMediaEnabled" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	</xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'MonoAudioEnabled'" />
		<xsl:with-param name="title3" select="'モノラルオーディオ'" />
		<xsl:with-param name="valueNode" select="/RESULT/MonoAudioEnabled" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/MonoAudioEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MonoAudioEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MonoAudioEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/MonoAudioEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MonoAudioEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MonoAudioEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'MasterStereoBalance'" />
      <xsl:with-param name="title2" select="'左右'" />
      <xsl:with-param name="valueNode" select="/RESULT/MasterStereoBalance" />
      <xsl:with-param name="value">
        <xsl:call-template name="slider4">
          <xsl:with-param name="position" select="/RESULT/MasterStereoBalance"/>
          <xsl:with-param name="range" select="2"/>
          <xsl:with-param name="default" select="0"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:if test="/RESULT/MasterStereoBalance/@master">
          <xsl:call-template name="slider4">
            <xsl:with-param name="position" select="/RESULT/MasterStereoBalance/@master"/>
            <xsl:with-param name="range" select="2"/>
            <xsl:with-param name="default" select="0"/>
          </xsl:call-template>
          <xsl:call-template name="Margin">
            <xsl:with-param name="margin" select="MasterStereoBalance/@margin"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:with-param>
    </xsl:call-template>
	
	<xsl:if test="/RESULT/DeviceClass = 'iPhone'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'VisualAlertEnabled'" />
        <xsl:with-param name="title3" select="'LEDフラッシュ通知'" />
        <xsl:with-param name="valueNode" select="/RESULT/VisualAlertEnabled" />
        <xsl:with-param name="template" select="'defaultOff'" />
      </xsl:call-template>
    </xsl:if>

	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'MACaptionDisplayType'" />
        <xsl:with-param name="title2" select="'標準字幕とバリアフリー字幕'" />
        <xsl:with-param name="title3" select="'クローズドキャプション+SDH'" />
        <xsl:with-param name="valueNode" select="/RESULT/MACaptionDisplayType" />
        <xsl:with-param name="value">
          <xsl:call-template name="ClosedCaption">
            <xsl:with-param name="value" select="/RESULT/MACaptionDisplayType"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:if test="/RESULT/MACaptionDisplayType/@master">
            <xsl:call-template name="ClosedCaption">
              <xsl:with-param name="value" select="/RESULT/MACaptionDisplayType/@master"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:with-param>
      </xsl:call-template>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'MACaptionActiveProfile'" />
		<xsl:with-param name="title3" select="'スタイル'" />
		<xsl:with-param name="valueNode" select="/RESULT/MACaptionActiveProfile" />
        <xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/MACaptionActiveProfile = 'MACaptionProfile-OutlineText'">
					<xsl:text>アウトラインテキスト</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MACaptionActiveProfile = 'MACaptionProfile-Default'">
					<xsl:text>透明な背景</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MACaptionActiveProfile = 'MACaptionProfile-LargeText'">
					<xsl:text>大きな文字</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MACaptionActiveProfile = 'MACaptionProfile-Classic'">
					<xsl:text>クラシック</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MACaptionActiveProfile = ''">
					<xsl:text>アウトラインテキスト</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/MACaptionActiveProfile/@master = 'MACaptionProfile-OutlineText'">
					<xsl:text>アウトラインテキスト</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MACaptionActiveProfile/@master = 'MACaptionProfile-Default'">
					<xsl:text>透明な背景</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MACaptionActiveProfile/@master = 'MACaptionProfile-LargeText'">
					<xsl:text>大きな文字</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MACaptionActiveProfile/@master = 'MACaptionProfile-Classic'">
					<xsl:text>クラシック</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/MACaptionActiveProfile/@master = ''">
					<xsl:text>アウトラインテキスト</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>

	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ShowAudioTranscriptionsEnabled'" />
		<xsl:with-param name="title3" select="'オーディオ発音表記を表示'" />
		<xsl:with-param name="valueNode" select="/RESULT/ShowAudioTranscriptionsEnabled" />
		<xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/ShowAudioTranscriptionsEnabled = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ShowAudioTranscriptionsEnabled = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ShowAudioTranscriptionsEnabled = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/ShowAudioTranscriptionsEnabled/@master = '0'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ShowAudioTranscriptionsEnabled/@master = '1'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/ShowAudioTranscriptionsEnabled/@master = ''">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	


    <!-- <xsl:call-template name="settingtable"> -->
      <!-- <xsl:with-param name="id" select="'GrayscaleDisplay'" /> -->
      <!-- <xsl:with-param name="title2" select="'グレイスケール'" /> -->
      <!-- <xsl:with-param name="valueNode" select="/RESULT/GrayscaleDisplay" /> -->
      <!-- <xsl:with-param name="template" select="'defaultOff'" /> -->
    <!-- </xsl:call-template> -->

    <!-- <xsl:call-template name="settingtable"> -->
      <!-- <xsl:with-param name="id" select="'SpeakThisEnabled'" /> -->
      <!-- <xsl:with-param name="title3" select="'画面の読み上げ'" /> -->
      <!-- <xsl:with-param name="valueNode" select="/RESULT/SpeakThisEnabled" /> -->
      <!-- <xsl:with-param name="template" select="'defaultOff'" /> -->
    <!-- </xsl:call-template> -->

    <!-- <xsl:call-template name="settingtable"> -->
      <!-- <xsl:with-param name="id" select="'largeTextUsesExtendedRange'" /> -->
      <!-- <xsl:with-param name="title2" select="'より大きな文字'" /> -->
      <!-- <xsl:with-param name="valueNode" select="/RESULT/largeTextUsesExtendedRange" /> -->
      <!-- <xsl:with-param name="template" select="'defaultOff'" /> -->
    <!-- </xsl:call-template> -->

    <!-- <xsl:call-template name="settingtable"> -->
      <!-- <xsl:with-param name="id" select="'UIPreferredContentSizeCategoryName'" /> -->
      <!-- <xsl:with-param name="title3" select="'スライダ位置'" /> -->
      <!-- <xsl:with-param name="valueNode" select="/RESULT/UIPreferredContentSizeCategoryName" /> -->
      <!-- <xsl:with-param name="value"> -->
        <!-- <xsl:call-template name="UISize"> -->
          <!-- <xsl:with-param name="value" select="/RESULT/UIPreferredContentSizeCategoryName"/> -->
        <!-- </xsl:call-template> -->
      <!-- </xsl:with-param> -->
      <!-- <xsl:with-param name="mastervalue"> -->
        <!-- <xsl:call-template name="UISize"> -->
          <!-- <xsl:with-param name="value" select="/RESULT/UIPreferredContentSizeCategoryName/@master"/> -->
        <!-- </xsl:call-template> -->
      <!-- </xsl:with-param> -->
    <!-- </xsl:call-template> -->
    



    <!--聴覚サポート-->
    <!-- <xsl:if test="/RESULT/DeviceClass = 'iPhone'"> -->
      <!-- <xsl:call-template name="settingtable"> -->
        <!-- <xsl:with-param name="id" select="'EarpieceNoiseCancellationPreference'" /> -->
        <!-- <xsl:with-param name="title2" select="'補聴器'" /> -->
        <!-- <xsl:with-param name="title3" select="'補聴器モード'" /> -->
        <!-- <xsl:with-param name="valueNode" select="/RESULT/EarpieceNoiseCancellationPreference" /> -->
        <!-- <xsl:with-param name="template" select="'defaultOn'" /> -->
      <!-- </xsl:call-template> -->
    <!-- </xsl:if> -->




   <!-- <xsl:if test="$MajorVersion &lt;= 13"> -->
      <!-- <xsl:call-template name="settingtable"> -->
        <!-- <xsl:with-param name="id" select="'MonoAudioEnabled'" /> -->
		<!-- <xsl:with-param name="title2" select="'モノラルオーディオ'" /> -->
		<!-- <xsl:with-param name="valueNode" select="/RESULT/MonoAudioEnabled" /> -->
		<!-- <xsl:with-param name="template" select="'defaultOff'" /> -->
      <!-- </xsl:call-template> -->
	<!-- </xsl:if> -->

    <!--電話ノイズキャンセリング-->


    <!-- <xsl:copy-of select="$MACaption"/> -->

    <!-- <xsl:call-template name="settingtable"> -->
      <!-- <xsl:with-param name="id" select="'MAAudibleMediaPrefPreferDescriptiveVideo'" /> -->
      <!-- <xsl:with-param name="title2" select="'ビデオ説明サービス'" /> -->
      <!-- <xsl:with-param name="valueNode" select="/RESULT/MAAudibleMediaPrefPreferDescriptiveVideo" /> -->
      <!-- <xsl:with-param name="template" select="'defaultOff'" /> -->
    <!-- </xsl:call-template> -->

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'GuidedAccessEnabled7'" />
      <xsl:with-param name="title2" select="'アクセスガイド'" />
      <xsl:with-param name="valueNode" select="/RESULT/GuidedAccessEnabled7" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	<xsl:if test="/RESULT/GuidedAccessEnabled7 = '1' or /RESULT/GuidedAccessEnabled7/@master = '1'">
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'GuidedAccessToneIdentifierForTimeRestrictionEvent'" />
	  <xsl:with-param name="title3" select="'時間制限'" />
      <xsl:with-param name="title4" select="'サウンド'" />
      <xsl:with-param name="valueNode" select="/RESULT/GuidedAccessToneIdentifierForTimeRestrictionEvent" />
      <xsl:with-param name="value">
		<xsl:choose>
			<xsl:when test="/RESULT/GuidedAccessToneIdentifierForTimeRestrictionEvent = ''">
				<xsl:text>なし</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				 <xsl:value-of select="/RESULT/GuidedAccessToneIdentifierForTimeRestrictionEvent/text()"/>
			</xsl:otherwise>
		</xsl:choose>
      </xsl:with-param>
	  <xsl:with-param name="mastervalue">
		<xsl:choose>
			<xsl:when test="/RESULT/GuidedAccessToneIdentifierForTimeRestrictionEvent/@master = ''">
				<xsl:text>なし</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="/RESULT/SafariMyInfo/@master"/>
			</xsl:otherwise>
		  </xsl:choose>
		</xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'GuidedAccessSpeakForTimeRestrictionEvent'" />
      <xsl:with-param name="title4" select="'読み上げる'" />
      <xsl:with-param name="valueNode" select="/RESULT/GuidedAccessSpeakForTimeRestrictionEvent" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'kAXSGuidedAccessAXFeaturesEnabled'" />
      <xsl:with-param name="title4" select="'ショートカットを表示'" />
      <xsl:with-param name="valueNode" select="/RESULT/kAXSGuidedAccessAXFeaturesEnabled" />
      <xsl:with-param name="template" select="'defaultOff'" />
    </xsl:call-template>
	
	</xsl:if>
	
	<xsl:if test="/RESULT/HomeButtonAssistant = 'true' or /RESULT/VoiceTriggerEnabled = 'true'">
	  <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'SiriUITextInputEnabled'" />
		<xsl:with-param name="title2" select="'Siri'" />
		<xsl:with-param name="title3" select="'Siriにタイプ入力'" />
		<xsl:with-param name="valueNode" select="/RESULT/SiriUITextInputEnabled" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	  </xsl:call-template>
	
	  <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AccessiblityUsedevicespeakerforTTS'" />
		<xsl:with-param name="title3" select="'音声フィードバック'" />
		<xsl:with-param name="valueNode" select="/RESULT/AccessiblityUsedevicespeakerforTTS" />
		<xsl:with-param name="value">
			<xsl:choose>
				<xsl:when test="/RESULT/AccessiblityUsedevicespeakerforTTS = '1'">
					<xsl:text>消音モードオフ設定</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AccessiblityUsedevicespeakerforTTS = '2'">
					<xsl:text>応答を常に読み上げる</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AccessiblityUsedevicespeakerforTTS = '3'">
					<xsl:text>”Hey Siri”使用時のみ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AccessiblityUsedevicespeakerforTTS = ''">
					<xsl:text>消音モードオフ設定</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
		<xsl:with-param name="mastervalue">
			<xsl:choose>
				<xsl:when test="/RESULT/AccessiblityUsedevicespeakerforTTS/@master = '1'">
					<xsl:text>消音モードオフ設定</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AccessiblityUsedevicespeakerforTTS/@master = '2'">
					<xsl:text>応答を常に読み上げる</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AccessiblityUsedevicespeakerforTTS/@master = '3'">
					<xsl:text>”Hey Siri”使用時のみ</xsl:text>
				</xsl:when>
				<xsl:when test="/RESULT/AccessiblityUsedevicespeakerforTTS/@master = ''">
					<xsl:text>消音モードオフ設定</xsl:text>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	  </xsl:call-template>
	
	  <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AlwaysAllowVoiceActivation'" />
		<xsl:with-param name="title3" select="'”HeySiri”を常に聞き取る'" />
		<xsl:with-param name="valueNode" select="/RESULT/AlwaysAllowVoiceActivation" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	  </xsl:call-template>
	
	  <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AlwaysObscureBackgroundContentWhenActive'" />
		<xsl:with-param name="title3" select="'Siriの背後にAppを表示'" />
		<xsl:with-param name="valueNode" select="/RESULT/AlwaysObscureBackgroundContentWhenActive" />
        <xsl:with-param name="template" select="'defaultOff'"/>
		<xsl:with-param name="param1" select="'オフ'"/>
        <xsl:with-param name="param2" select="'オン'"/>
	  </xsl:call-template>
	</xsl:if>

    <!-- <xsl:call-template name="settingtable"> -->
      <!-- <xsl:with-param name="id" select="'HomeClickSpeed'" /> -->
      <!-- <xsl:with-param name="title2" select="'ホームクリックの間隔'" /> -->
      <!-- <xsl:with-param name="valueNode" select="/RESULT/HomeClickSpeed" /> -->
      <!-- <xsl:with-param name="value"> -->
        <!-- <xsl:call-template name="HomeClickSpeed"> -->
          <!-- <xsl:with-param name="this" select="/RESULT/HomeClickSpeed"/> -->
        <!-- </xsl:call-template> -->
      <!-- </xsl:with-param> -->
      <!-- <xsl:with-param name="mastervalue"> -->
        <!-- <xsl:call-template name="HomeClickSpeed"> -->
          <!-- <xsl:with-param name="this" select="/RESULT/HomeClickSpeed/@master"/> -->
        <!-- </xsl:call-template> -->
      <!-- </xsl:with-param> -->
    <!-- </xsl:call-template> -->

    <!-- <xsl:if test="/RESULT/DeviceClass = 'iPhone'"> -->
      <!-- <xsl:call-template name="settingtable"> -->
        <!-- <xsl:with-param name="id" select="'DefaultRouteForCallPreference'" /> -->
        <!-- <xsl:with-param name="title2" select="'着信'" /> -->
        <!-- <xsl:with-param name="valueNode" select="/RESULT/DefaultRouteForCallPreference" /> -->
        <!-- <xsl:with-param name="value"> -->
          <!-- <xsl:call-template name="DefaultRouteForCall"> -->
            <!-- <xsl:with-param name="value" select="/RESULT/DefaultRouteForCallPreference"/> -->
          <!-- </xsl:call-template> -->
        <!-- </xsl:with-param> -->
        <!-- <xsl:with-param name="mastervalue"> -->
          <!-- <xsl:call-template name="DefaultRouteForCall"> -->
            <!-- <xsl:with-param name="value" select="/RESULT/DefaultRouteForCallPreference/@master"/> -->
          <!-- </xsl:call-template> -->
        <!-- </xsl:with-param> -->
      <!-- </xsl:call-template> -->
    <!-- </xsl:if> -->

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'TripleClickChoice'" />
      <xsl:with-param name="title2" select="'ショートカット'" />
      <xsl:with-param name="valueNode" select="/RESULT/TripleClickChoice" />
      <xsl:with-param name="value">
        <xsl:choose>
          <xsl:when test="/RESULT/TripleClickChoice = ''">オフ</xsl:when>
          <xsl:otherwise>
            <xsl:for-each select="/RESULT/TripleClickChoice/string">
              <xsl:call-template name="TripleClickName">
                <xsl:with-param name="value" select="./text()"/>
              </xsl:call-template>
              <xsl:text> </xsl:text>
            </xsl:for-each>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:choose>
          <xsl:when test="count(TripleClickChoice/string[@master]) = 0">オフ</xsl:when>
          <xsl:otherwise>
            <xsl:for-each select="/RESULT/TripleClickChoice/string">
              <xsl:call-template name="TripleClickName">
                <xsl:with-param name="value" select="./@master"/>
              </xsl:call-template>
            </xsl:for-each>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:with-param>
    </xsl:call-template>

  </xsl:template>

</xsl:stylesheet>