<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl">

  <xsl:template name="SectioniCloud">

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'Accounts/iCloud/Username'" />
      <xsl:with-param name="title1">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>iCloud</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>メール</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>アカウント名</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 11 and $MajorVersion &lt;= 13">
          <xsl:text>iCloud</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>アカウント</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &gt;= 11 and $MajorVersion &lt;= 13">
          <xsl:text>アカウント名</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>iCloud</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>アカウント名</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/Accounts/iCloud/Username" />
      <xsl:with-param name="template" select="'text'"/>
    </xsl:call-template>

    <!--iCloud Drive-->
    <xsl:variable name="iCloudDriveApp">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'EnablediCloudDrive'" />
        <xsl:with-param name="title2">
          <xsl:if test="$MajorVersion &lt;= 10">
            <xsl:text>iCloud Drive</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title3">
          <xsl:if test="$MajorVersion &gt;= 11 and $MajorVersion &lt;= 13">
            <xsl:text>iCloud Drive</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title5">
          <xsl:if test="$MajorVersion &gt;= 14">
            <xsl:text>iCloud Drive</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/RESULT/EnablediCloudDrive" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>

      <!--App-->
      <xsl:for-each select="/RESULT/iCloudDriveApp/Application">
        <xsl:sort select="cs:GetAppName(Identifier, /RESULT/DeviceClass, /RESULT/Applications)"/>
        <!--並び替え前の位置を取得-->
        <xsl:variable name="id" select="Identifier"/>
        <xsl:variable name="pos" select="count(/RESULT/iCloudDriveApp/Application[./Identifier = $id]/preceding-sibling::*)+1"/>

        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="concat('iCloudDriveApp/Application_', $pos, '/Allowed')" />
          <xsl:with-param name="title3">
            <xsl:if test="$MajorVersion &lt;= 10 or $MajorVersion = 13">
              <xsl:call-template name="GetAppName">
                <xsl:with-param name="appID" select="Identifier"/>
                <xsl:with-param name="device" select="/RESULT/DeviceClass"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title4">
            <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
              <xsl:call-template name="GetAppName">
                <xsl:with-param name="appID" select="Identifier"/>
                <xsl:with-param name="device" select="/RESULT/DeviceClass"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title5">
            <xsl:if test="$MajorVersion &gt;= 14">
              <xsl:call-template name="GetAppName">
                <xsl:with-param name="appID" select="Identifier"/>
                <xsl:with-param name="device" select="/Root/DeviceClass"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="Allowed" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:for-each>
    </xsl:variable>

    <xsl:if test="$MajorVersion &lt; 13">
      <xsl:copy-of select="$iCloudDriveApp"/>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'dataclassesEnabledForCellular'" />
        <xsl:with-param name="title3">
          <xsl:if test="$MajorVersion &lt;= 10">
            <xsl:text>モバイルデータ通信を使用</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title4">
          <xsl:if test="$MajorVersion &gt;= 11">
            <xsl:text>モバイルデータ通信を使用</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/RESULT/dataclassesEnabledForCellular" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:if>

    <!--写真-->
	<xsl:if test="$MajorVersion &lt;= 13">
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'cloudPhotosEnable'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>写真</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>iCloudフォトライブラリ</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>写真</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>ICLOUDを使用しているAPP</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>iCloud写真</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>写真</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>ICLOUDを使用しているAPP</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
          <xsl:if test="$MajorVersion = 13">
            <xsl:text>iCloud写真</xsl:text>
          </xsl:if>
          <xsl:if test="$MajorVersion &gt;= 13">
            <xsl:text>写真</xsl:text>
          </xsl:if>
        </xsl:with-param>
		<xsl:with-param name="title6">
          <xsl:if test="$MajorVersion &gt;= 13">
            <xsl:text>iCloud写真</xsl:text>
          </xsl:if>
        </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/cloudPhotosEnable" />
      <xsl:with-param name="template" select="'defaultOff'"/>
    </xsl:call-template>
	</xsl:if>
	
	<xsl:if test="$MajorVersion &gt;= 14">
		<xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'iCloudPhoto'" />
          <xsl:with-param name="title4">
              <xsl:text>ICLOUDを使用しているAPP</xsl:text>
          </xsl:with-param>
		  <xsl:with-param name="title5">
              <xsl:text>写真</xsl:text>
          </xsl:with-param>
		  <xsl:with-param name="title6">
              <xsl:text>iCloud写真</xsl:text>
          </xsl:with-param>
		  <xsl:with-param name="valueNode" select="/RESULT/iCloudPhoto" />
          <xsl:with-param name="template" select="'defaultOn'"/>
		</xsl:call-template>
	</xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'optimizePhotoStorage'" />
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>iPhone/iPadのストレージを最適化</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>iPhone/iPadのストレージを最適化</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>iPhone/iPadのストレージを最適化</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title6">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>iPhone/iPadのストレージを最適化</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/optimizePhotoStorage" />
      <xsl:with-param name="template" select="'defaultOff'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'downloadAndKeepOriginals'" />
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>オリジナルをダウンロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>オリジナルをダウンロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>オリジナルをダウンロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title6">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>オリジナルをダウンロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/downloadAndKeepOriginals" />
      <xsl:with-param name="template" select="'defaultOff'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudMyPhotoStream'" />
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>マイフォトストリーム</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>マイフォトストリームにアップロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>マイフォトストリームにアップロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title6">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>マイフォトストリームにアップロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudMyPhotoStream" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>
	
	<xsl:if test="$MajorVersion &lt; 14">
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'PLPhotoStreamHidesAvalanches'" />
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>バーストの写真をアップロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>バーストの写真をアップロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>バーストの写真をアップロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title6">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>バーストの写真をアップロード</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/PLPhotoStreamHidesAvalanches" />
      <xsl:with-param name="value">
        <xsl:call-template name="falseOn">
          <xsl:with-param select="/RESULT/PLPhotoStreamHidesAvalanches" name="bool"/>
        </xsl:call-template>
      </xsl:with-param>
      <xsl:with-param name="mastervalue">
        <xsl:call-template name="falseOn">
          <xsl:with-param select="/RESULT/PLPhotoStreamHidesAvalanches/@master" name="bool"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
	</xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudSharePhotos'" />
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>iCloud写真共有</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>共有アルバム</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>共有アルバム</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title6">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>共有アルバム</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudSharePhotos" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <!--メール-->
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudMailEnable'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>メール</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>メール</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion  = 13">
          <xsl:text>メール</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>メール</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudMailEnable" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudContacts'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>連絡先</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>連絡先</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>連絡先</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>連絡先</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudContacts" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudCalendars'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>カレンダー</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>カレンダー</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>カレンダー</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>カレンダー</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudCalendars" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudReminders'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>リマインダー</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>リマインダー</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>リマインダー</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>リマインダー</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudReminders" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudNotes'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>メモ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>メモ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion  = 13">
          <xsl:text>メモ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>メモ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudNotes" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudMessages'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>メッセージ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>メッセージ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>メッセージ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>メッセージ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudMessages" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudBookmarks'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>Safari</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>Safari</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>Safari</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>Safari</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudBookmarks" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudStocks'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>株価</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>株価</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>株価</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>株価</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudStocks" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudHome'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>ホーム</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>ホーム</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>ホーム</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>ホーム</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudHome" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudHealth'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>ヘルスケア</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>ヘルスケア</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion  = 13">
          <xsl:text>ヘルスケア</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>ヘルスケア</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudHealth" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>
	
	<xsl:if test="/Root/DeviceClass = 'iPhone'">
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudWallet'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>Wallet</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>Wallet</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion  = 13">
          <xsl:text>Wallet</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>Wallet</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudWallet" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>
	</xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudGameCenter'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>Game Center</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>Game Center</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion  = 13">
          <xsl:text>Game Center</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>Game Center</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudGameCenter" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudSiri'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>Siri</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>Siri</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion  = 13">
          <xsl:text>Siri</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>Siri</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudSiri" />
      <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>

    <xsl:choose>
        <xsl:when test="/RESULT/allowCloudKeychainSync != ''">
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'allowCloudKeychainSync'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>キーチェーン</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>キーチェーン</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>キーチェーン</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>キーチェーン</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/allowCloudKeychainSync" />
      <xsl:with-param name="template" select="'OnOff'"/>
	  </xsl:call-template>
	  </xsl:when>
        <xsl:otherwise>
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'allowCloudKeychainSync'" />
            <xsl:with-param name="title2">
              <xsl:if test="$MajorVersion &lt;= 10">
                <xsl:text>キーチェーン</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title3">
              <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
                <xsl:text>キーチェーン</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title4">
              <xsl:if test="$MajorVersion = 13">
                <xsl:text>キーチェーン</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title5">
              <xsl:if test="$MajorVersion &gt;= 14">
                <xsl:text>キーチェーン</xsl:text>
              </xsl:if>
            </xsl:with-param>
			<xsl:with-param name="valueNode" select="/RESULT/allowCloudKeychainSync" />
            <xsl:with-param name="template" select="'defaultOff'"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'CloudBackupEnabled'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>バックアップ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion = 11 or $MajorVersion = 12">
          <xsl:text>iCloudバックアップ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>iCloudバックアップ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>iCloudバックアップ</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/CloudBackupEnabled" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:if test="$MajorVersion &gt;= 13">
      <xsl:copy-of select="$iCloudDriveApp"/>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'iCloudFindMyiPhone'" />
      <xsl:with-param name="title2">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>iPhone/iPadを探す</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 13 and $MajorVersion &lt;= 13">
          <xsl:text>探す</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &gt;= 11 and $MajorVersion &lt;= 13">
          <xsl:text>iPhone/iPadを探す</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion = 13">
          <xsl:text>iPhone/iPadを探す</xsl:text>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>探す</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title5">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>iPhone/iPadを探す</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title6">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>iPhone/iPadを探す</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/iCloudFindMyiPhone" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

    <xsl:if test="$MajorVersion &gt;= 13">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'SPSettingsServiceState'" />
        <xsl:with-param name="title4">
          <xsl:if test="$MajorVersion = 13">
            <xsl:text>”オフラインのデバイスを探す”を有効にする</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title6">
          <xsl:if test="$MajorVersion &gt;= 14">
            <xsl:text>”探す”のネットワーク</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/RESULT/SPSettingsServiceState" />
        <xsl:with-param name="template" select="'defaultOn'" />
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'lowBatteryLocate'" />
      <xsl:with-param name="title3">
        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:text>最後の位置を送信</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title4">
        <xsl:if test="$MajorVersion &gt;= 11 and $MajorVersion &lt;= 13">
          <xsl:text>最後の位置情報を送信</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="title6">
        <xsl:if test="$MajorVersion &gt;= 14">
          <xsl:text>最後の位置情報を送信</xsl:text>
        </xsl:if>
      </xsl:with-param>
      <xsl:with-param name="valueNode" select="/RESULT/lowBatteryLocate" />
      <xsl:with-param name="template" select="'defaultOn'"/>
    </xsl:call-template>

  </xsl:template>

</xsl:stylesheet>