<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

  <xsl:template name="SectionNotification">
	
	<xsl:if test="$MajorVersion &lt; 10">
		<xsl:call-template name="settingtable">
			<xsl:with-param name="id" select="'NoticeSectionOrderRule'" />
			<xsl:with-param name="title1" select="'通知'" />
			<xsl:with-param name="valueNode" select="/RESULT/NoticeSectionOrderRule" />
			<xsl:with-param name="value">
			  <xsl:call-template name ="NoticeOrderRule">
				<xsl:with-param name="value" select="/RESULT/NoticeSectionOrderRule"/>
			  </xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="mastervalue">
			  <xsl:call-template name ="NoticeOrderRule">
				<xsl:with-param name="value" select="/RESULT/NoticeSectionOrderRule/@master"/>
			  </xsl:call-template>
			</xsl:with-param>
		</xsl:call-template>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'BBContentPreviewsSetting'" />
        <xsl:with-param name="title1" select="'通知'" />
        <xsl:with-param name="title2" select="'プレビューを表示'" />
        <xsl:with-param name="valueNode" select="/RESULT/BBContentPreviewsSetting" />
        <xsl:with-param name="value">
          <xsl:call-template name ="ContentPreviewsSetting">
            <xsl:with-param name="value" select="/RESULT/BBContentPreviewsSetting"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:call-template name ="ContentPreviewsSetting">
            <xsl:with-param name="value" select="/RESULT/BBContentPreviewsSetting/@master"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'LockScreenSuggestionsEnabled'" />
        <xsl:with-param name="title2" select="'Siriからの提案'" />
        <xsl:with-param name="title3" select="'ロック画面上での提案'" />
        <xsl:with-param name="valueNode" select="/RESULT/LockScreenSuggestionsEnabled" />
        <xsl:with-param name="template" select="'defaultOn'" />
    </xsl:call-template>
		
	<xsl:for-each select="/RESULT/SBSearchResults/Item">
		<xsl:sort select="cs:GetAppName(Identifier, /RESULT/DeviceClass, /RESULT/Applications)"/>
		<!--並び替え前の位置を取得-->
		<xsl:variable name="id" select="Identifier"/>
		<xsl:variable name="pos" select="count(/RESULT/SBSearchResults/Item[./Identifier = $id]/preceding-sibling::*)+1"/>

		<xsl:call-template name="settingtable">
			<xsl:with-param name="id" select="concat('SBSearchResults/Item_', $pos, '/Lockscreen')" />
			<xsl:with-param name="title4">
				<xsl:call-template name="GetAppName">
					<xsl:with-param name="appID" select="Identifier"/>
					<xsl:with-param name="device" select="/RESULT/DeviceClass"/>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="valueNode" select="Lockscreen" />
			<xsl:with-param name="template" select="'OnOff'"/>
		</xsl:call-template>
	</xsl:for-each>
		
	

    <xsl:for-each select="/RESULT/Notifications/Item">
		  <xsl:sort select="cs:GetAppName(Identifier, /RESULT/DeviceClass, /RESULT/Applications)"/>
		  <!--並び替え前の位置を取得-->
		  <xsl:variable name="id" select="Identifier"/>
		  <xsl:variable name="pos" select="count(/RESULT/Notifications/Item[./Identifier = $id]/preceding-sibling::*)+1"/>

        <xsl:if test="(starts-with(Identifier,'com.apple.mobilecal.bulletin-subsection') 
		and /RESULT/Notifications/Item[./Identifier/text() = 'com.apple.mobilecal']/authorizationStatus/@master = '2')
	or not(starts-with(Identifier,'com.apple.mobilecal.bulletin-subsection'))">
	
	<xsl:if test="(starts-with(Identifier,'com.apple.tv.bulletins.') 
		and /RESULT/Notifications/Item[./Identifier/text() = 'com.apple.tv']/authorizationStatus/@master = '2')
	or not(starts-with(Identifier,'com.apple.tv.bulletins.'))">
	
		<xsl:if test="(starts-with(Identifier,'com.apple.mobileslideshow.') 
		and /RESULT/Notifications/Item[./Identifier/text() = 'com.apple.mobileslideshow']/authorizationStatus/@master = '2')
	or not(starts-with(Identifier,'com.apple.mobileslideshow.'))">
			<xsl:call-template name="settingtable">
				<xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/authorizationStatus')" />
				<xsl:with-param name="title2">
				  <xsl:if test="position() = 1">通知スタイル</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="title3">
				  <xsl:call-template name="GetAppName">
					<xsl:with-param name="appID" select="Identifier"/>
					<xsl:with-param name="device" select="/RESULT/DeviceClass"/>
				  </xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="title4">
				  <xsl:text>通知を許可</xsl:text>
				</xsl:with-param>
				<xsl:with-param name="valueNode" select="authorizationStatus" />
				<xsl:with-param name="value">
				<xsl:choose>
					<xsl:when test="authorizationStatus = '2'">
						<xsl:text>オン</xsl:text>
					</xsl:when>
					<xsl:when test="authorizationStatus = '1'">
						<xsl:text>オフ</xsl:text>
					</xsl:when>
					</xsl:choose>
				</xsl:with-param>

				<xsl:with-param name="mastervalue">
					<xsl:choose>
						<xsl:when test="authorizationStatus/@master = '2'">
							<xsl:text>オン</xsl:text>
						</xsl:when>
						<xsl:when test="authorizationStatus/@master = '1'">
							<xsl:text>オフ</xsl:text>
						</xsl:when>
					</xsl:choose>
				</xsl:with-param>
			</xsl:call-template>
		  
			<xsl:if test="/RESULT/Notifications/Item[./Identifier = $id]/authorizationStatus = '2' or /RESULT/Notifications/Item[./Identifier = $id]/authorizationStatus/@master = '2'">
		  
				<xsl:if test="Identifier != 'com.apple.mobilecal' and 
				Identifier != 'com.apple.tv' and 
				Identifier != 'com.apple.mobileslideshow'">
					<xsl:call-template name="settingtable">
						<xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/showsInLockScreen')" />
						<xsl:with-param name="title4">
						  <xsl:text>ロック画面</xsl:text>
						</xsl:with-param>
						<xsl:with-param name="valueNode" select="showsInLockScreen" />
						<xsl:with-param name="template" select="'OnOff'"/>
					</xsl:call-template>

					<xsl:call-template name="settingtable">
						<xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/showsInNotificationCenter')" />
						<xsl:with-param name="title4">
						  <xsl:text>通知センター</xsl:text>
						</xsl:with-param>
						<xsl:with-param name="valueNode" select="showsInNotificationCenter" />
						<xsl:with-param name="template" select="'OnOff'"/>
					</xsl:call-template>

 
					<xsl:if test="Identifier != 'com.apple.tips'">
						<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/alertType')" />
							<xsl:with-param name="title4">
								<xsl:text>バナー</xsl:text>
							</xsl:with-param>
							<xsl:with-param name="valueNode" select="alertType" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="alertType = '0'">
										<xsl:text>オフ</xsl:text>
									</xsl:when>
									<xsl:when test="alertType = '1'">
										<xsl:text>オン/一時的</xsl:text>
									</xsl:when>
									<xsl:when test="alertType = '2'">
										<xsl:text>オン/持続的</xsl:text>
									</xsl:when>
								</xsl:choose>
							</xsl:with-param>

							<xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="alertType/@master = '0'">
										<xsl:text>オフ</xsl:text>
									</xsl:when>
									<xsl:when test="alertType/@master = '1'">
										<xsl:text>オン/一時的</xsl:text>
									</xsl:when>
									<xsl:when test="alertType/@master = '2'">
										<xsl:text>オン/持続的</xsl:text>
									</xsl:when>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
 
		
					<xsl:if test="Identifier != 'com.apple.facetime' and 
					Identifier != 'com.apple.mobilemail' and
					Identifier != 'com.apple.tips' and
					Identifier != 'com.apple.MobileSMS' and 
					Identifier != 'com.apple.Maps' and
					Identifier != 'com.apple.reminders' and
					Identifier != 'com.apple.mobilephone' and
					Identifier != 'com.apple.mobilecal.bulletin-subsection.upcomingEvents' and
					Identifier != 'com.apple.mobilecal.bulletin-subsection.invitations' and 
					Identifier != 'com.apple.mobilecal.bulletin-subsection.Responses' and
					Identifier != 'com.apple.mobilecal.bulletin-subsection.resourceChanges' and 
					Identifier != 'com.apple.mobilecal.bulletin-subsection.suggestions'">
						<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/sound')" />
							<xsl:with-param name="title4">
							<xsl:text>サウンド</xsl:text>
							</xsl:with-param>
							<xsl:with-param name="valueNode" select="sound" />
							<xsl:with-param name="template" select="'OnOff'"/>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier = 'com.apple.facetime' or Identifier = 'com.apple.mobilephone'">
						<xsl:call-template name="settingtable">
						  <xsl:with-param name="id" select="'ringtone'" />
						  <xsl:with-param name="title4" select="'サウンド'" />
						  <xsl:with-param name="title5" select="'着信音/通知音'" />
						  <xsl:with-param name="valueNode" select="/RESULT/ringtone" />
						  <xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="/RESULT/ringtone = ''">
									<xsl:text>オープニング</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/ringtone"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>

							<xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="/RESULT/ringtone/@master = ''">
										<xsl:text>オープニング</xsl:text>
									</xsl:when>
									<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/ringtone/@master"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier = 'com.apple.MobileSMS'">
						<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="'sms-sound-identifier'" />
							<xsl:with-param name="title4" select="'サウンド'" />
							<xsl:with-param name="title5" select="'着信音/通知音'" />
							<xsl:with-param name="valueNode" select="/RESULT/sms-sound-identifier" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="/RESULT/sms-sound-identifier = ''">
									<xsl:text>メモ</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="sound" >
											<xsl:with-param name="value" select="/RESULT/sms-sound-identifier"/>
										</xsl:call-template>
										</xsl:otherwise>
									</xsl:choose>
							</xsl:with-param>

							<xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="/RESULT/sms-sound-identifier/@master = ''">
										<xsl:text>メモ</xsl:text>
									</xsl:when>
									<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/sms-sound-identifier/@master"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier = 'com.apple.mobilemail'">
						<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="'newmail-sound-identifier'" />
							<xsl:with-param name="title4" select="'サウンド'" />
							<xsl:with-param name="title5" select="'着信音/通知音'" />
							<xsl:with-param name="valueNode" select="/RESULT/newmail-sound-identifier" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="/RESULT/newmail-sound-identifier = ''">
									<xsl:text>なし</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="sound" >
											<xsl:with-param name="value" select="/RESULT/newmail-sound-identifier"/>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>

							<xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="/RESULT/newmail-sound-identifier/@master = ''">
										<xsl:text>なし</xsl:text>
									</xsl:when>
									<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/newmail-sound-identifier/@master"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier = 'com.apple.reminders'">
						<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="'reminderalert-sound-identifier'" />
							<xsl:with-param name="title4" select="'サウンド'" />
							<xsl:with-param name="title5" select="'着信音/通知音'" />
							<xsl:with-param name="valueNode" select="/RESULT/reminderalert-sound-identifier" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="/RESULT/reminderalert-sound-identifier = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="sound" >
											<xsl:with-param name="value" select="/RESULT/reminderalert-sound-identifier"/>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
							<xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="/RESULT/reminderalert-sound-identifier/@master = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/reminderalert-sound-identifier/@master"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.upcomingEvents'">
						<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="'SoundcalUpcomingEvents'" />
							<xsl:with-param name="title4" select="'サウンド'" />
							<xsl:with-param name="title5" select="'着信音/通知音'" />
							<xsl:with-param name="valueNode" select="/RESULT/SoundcalUpcomingEvents" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalUpcomingEvents = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="sound" >
											<xsl:with-param name="value" select="/RESULT/SoundcalUpcomingEvents"/>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
							<xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalUpcomingEvents/@master = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/SoundcalUpcomingEvents/@master"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.invitations'">
							<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="'SoundcalInvitations'" />
							<xsl:with-param name="title4" select="'サウンド'" />
							<xsl:with-param name="title5" select="'着信音/通知音'" />
							<xsl:with-param name="valueNode" select="/RESULT/SoundcalInvitations" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalInvitations = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="sound" >
											<xsl:with-param name="value" select="/RESULT/SoundcalInvitations"/>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							  </xsl:with-param>
							  <xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalInvitations/@master = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/SoundcalInvitations/@master"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.Responses'">
						<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="'SoundcalResponses'" />
							<xsl:with-param name="title4" select="'サウンド'" />
							<xsl:with-param name="title5" select="'着信音/通知音'" />
							<xsl:with-param name="valueNode" select="/RESULT/SoundcalResponses" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalResponses = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="sound" >
											<xsl:with-param name="value" select="/RESULT/SoundcalResponses"/>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
							<xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalResponses/@master = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/SoundcalResponses/@master"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.resourceChanges'">
						<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="'SoundcalResourceChanges'" />
							<xsl:with-param name="title4" select="'サウンド'" />
							<xsl:with-param name="title5" select="'着信音/通知音'" />
							<xsl:with-param name="valueNode" select="/RESULT/SoundcalResourceChanges" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalResourceChanges = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="sound" >
											<xsl:with-param name="value" select="/RESULT/SoundcalResourceChanges"/>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
							<xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalResourceChanges/@master = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/SoundcalResourceChanges/@master"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.suggestions'">
						<xsl:call-template name="settingtable">
							<xsl:with-param name="id" select="'SoundcalSuggestions'" />
							<xsl:with-param name="title4" select="'サウンド'" />
							<xsl:with-param name="title5" select="'着信音/通知音'" />
							<xsl:with-param name="valueNode" select="/RESULT/SoundcalSuggestions" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalSuggestions = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="sound" >
											<xsl:with-param name="value" select="/RESULT/SoundcalSuggestions"/>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
							<xsl:with-param name="mastervalue">
								<xsl:choose>
									<xsl:when test="/RESULT/SoundcalSuggestions/@master = ''">
										<xsl:text>和音</xsl:text>
									</xsl:when>
									<xsl:otherwise>
									<xsl:call-template name="sound" >
										<xsl:with-param name="value" select="/RESULT/SoundcalSuggestions/@master"/>
									</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
		
					<xsl:if test="Identifier != 'com.apple.Maps' and 
					Identifier != 'com.apple.ScreenTimeNotifications' and 
					Identifier != 'com.apple.iBooks' and 
				  Identifier != 'com.apple.tips' and 
				  Identifier != 'com.apple.mobileslideshow.SharingSuggestions' and 
				  Identifier != 'com.apple.mobileslideshow.memories'">
						<xsl:call-template name="settingtable">
						  <xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/badge')" />
						  <xsl:with-param name="title4">
							<xsl:text>バッジ</xsl:text>
						  </xsl:with-param>
						  <xsl:with-param name="valueNode" select="badge" />
						  <xsl:with-param name="template" select="'OnOff'"/>
						</xsl:call-template>
					</xsl:if>
					
					<xsl:call-template name="settingtable">
					  <xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/contentPreviewSetting')" />
					  <xsl:with-param name="title4">
						<xsl:text>プレビューを表示</xsl:text>
					  </xsl:with-param>
					  <xsl:with-param name="valueNode" select="contentPreviewSetting" />
					  <xsl:with-param name="value">
							<xsl:choose>
								<xsl:when test="contentPreviewSetting = '2'">
									<xsl:text>ロックされていないときのみ</xsl:text>
								</xsl:when>
								<xsl:when test="contentPreviewSetting = '3'">
									<xsl:text>しない</xsl:text>
								</xsl:when>
								<xsl:when test="contentPreviewSetting = '0'">
									<xsl:text>常に（デフォルト）</xsl:text>
								</xsl:when>
								<xsl:when test="contentPreviewSetting = '1'">
									<xsl:text>常に（デフォルト）</xsl:text>
								</xsl:when>
							</xsl:choose>
						</xsl:with-param>

						<xsl:with-param name="mastervalue">
							<xsl:choose>
								<xsl:when test="contentPreviewSetting/@master = '2'">
									<xsl:text>ロックされていないときのみ</xsl:text>
								</xsl:when>
								<xsl:when test="contentPreviewSetting/@master = '3'">
									<xsl:text>しない</xsl:text>
								</xsl:when>
								<xsl:when test="contentPreviewSetting/@master = '0'">
									<xsl:text>常に（デフォルト）</xsl:text>
								</xsl:when>
								<xsl:when test="contentPreviewSetting/@master = '1'">
									<xsl:text>常に（デフォルト）</xsl:text>
								</xsl:when>
							</xsl:choose>
						</xsl:with-param>
					  </xsl:call-template>
				</xsl:if>
		
				<xsl:if test="Identifier != 'com.apple.mobilecal.bulletin-subsection.upcomingEvents' and 
				Identifier != 'com.apple.mobilecal.bulletin-subsection.invitations' and
				Identifier != 'com.apple.mobilecal.bulletin-subsection.Responses' and
				Identifier != 'com.apple.mobilecal.bulletin-subsection.resourceChanges' and
				Identifier != 'com.apple.mobilecal.bulletin-subsection.suggestions' and 
				Identifier != 'com.apple.tv.bulletins.explicit' and
				Identifier != 'com.apple.tv.bulletins.marketing' and
				Identifier != 'com.apple.mobileslideshow.memories' and
				Identifier != 'com.apple.mobileslideshow.iCloudPhotoSharing' and
				Identifier != 'com.apple.mobileslideshow.SharingSuggestions'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/bulletinGroupingSetting')" />
				  <xsl:with-param name="title4">
					<xsl:text>通知のグループ化</xsl:text>
				  </xsl:with-param>
				  <xsl:with-param name="valueNode" select="bulletinGroupingSetting" />
				  <xsl:with-param name="value">
						<xsl:choose>
							<xsl:when test="bulletinGroupingSetting = '1'">
								<xsl:text>App別</xsl:text>
							</xsl:when>
							<xsl:when test="bulletinGroupingSetting = '2'">
								<xsl:text>オフ</xsl:text>
							</xsl:when>
							<xsl:when test="bulletinGroupingSetting = '0'">
								<xsl:text>自動</xsl:text>
							</xsl:when>
						</xsl:choose>
					</xsl:with-param>

					<xsl:with-param name="mastervalue">
						<xsl:choose>
							<xsl:when test="bulletinGroupingSetting/@master = '1'">
								<xsl:text>App別</xsl:text>
							</xsl:when>
							<xsl:when test="bulletinGroupingSetting/@master = '2'">
								<xsl:text>オフ</xsl:text>
							</xsl:when>
							<xsl:when test="bulletinGroupingSetting/@master = '0'">
								<xsl:text>自動</xsl:text>
							</xsl:when>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
				</xsl:if>
	
				<xsl:if test="Identifier = 'com.apple.MobileSMS'">
					<xsl:call-template name="settingtable">
						<xsl:with-param name="id" select="'IncomingMessageAlertCount'" />
						<xsl:with-param name="title4" select="'通知を繰り返す'" />
						<xsl:with-param name="valueNode" select="/RESULT/IncomingMessageAlertCount" />
						<xsl:with-param name="value">
						<xsl:choose>
							<xsl:when test="/RESULT/IncomingMessageAlertCount = ''">
								<xsl:text>1回</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="AlertCount" >
									<xsl:with-param name="value" select="/RESULT/IncomingMessageAlertCount"/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
						</xsl:with-param>
						<xsl:with-param name="mastervalue">
							<xsl:choose>
								<xsl:when test="/RESULT/IncomingMessageAlertCount/@master = ''">
									<xsl:text>1回</xsl:text>
								</xsl:when>
								<xsl:otherwise>
								<xsl:call-template name="AlertCount" >
									<xsl:with-param name="value" select="/RESULT/IncomingMessageAlertCount/@master"/>
								</xsl:call-template>
							</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
		
				<xsl:if test="Identifier = 'com.apple.gamecenter'">
					<xsl:call-template name="settingtable">
						<xsl:with-param name="id" select="'ShowAllIncomingMessage'" />
						<xsl:with-param name="title4" select="'メールによる事後連絡'" />
						<xsl:with-param name="valueNode" select="/RESULT/ShowAllIncomingMessage" />
						<xsl:with-param name="template" select="'defaultOn'" />
						<xsl:with-param name="param1" select="'すべての人から通知を表示（デフォルト）'"/>
						<xsl:with-param name="param2" select="'登録済み連絡先のみ通知を表示'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
		</xsl:if>
		</xsl:if>
		</xsl:if>

	</xsl:for-each>
  </xsl:template>

</xsl:stylesheet>