<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

  <xsl:template name="SectionNotification">
  
      <xsl:if test="$MajorVersion &lt; 10">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'NoticeSectionOrderRule'" />
        <xsl:with-param name="title1" select="'通知'" />
        <xsl:with-param name="valueNode" select="/Root/NoticeSectionOrderRule" />
        <xsl:with-param name="value">
          <xsl:call-template name ="NoticeOrderRule">
            <xsl:with-param name="value" select="/Root/NoticeSectionOrderRule"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'BBContentPreviewsSetting'" />
        <xsl:with-param name="title1" select="'通知'" />
        <xsl:with-param name="title2" select="'プレビューを表示'" />
        <xsl:with-param name="valueNode" select="/Root/BBContentPreviewsSetting" />
        <xsl:with-param name="value">
          <xsl:call-template name ="ContentPreviewsSetting">
            <xsl:with-param name="value" select="/Root/BBContentPreviewsSetting"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
	
	<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'LockScreenSuggestionsDisabled'" />
        <xsl:with-param name="title2" select="'Siriからの提案'" />
        <xsl:with-param name="title3" select="'ロック画面上での提案'" />
        <xsl:with-param name="valueNode" select="/Root/LockScreenSuggestionsDisabled" />
        <xsl:with-param name="template" select="'defaultOn'" />
      </xsl:call-template>
  <!-- 各AppSiriからの提案オンオフ -->

	<xsl:for-each select="/Root/SBSearchResults/Item">
    <xsl:sort select="cs:GetAppName(Identifier, /Root/DeviceClass, /Root/Applications)"/>
    <!--並び替え前の位置を取得-->
    <xsl:variable name="id" select="Identifier"/>
    <xsl:variable name="pos" select="count(/Root/SBSearchResults/Item[./Identifier = $id]/preceding-sibling::*)+1"/>

	<xsl:call-template name="settingtable">
		<xsl:with-param name="id" select="concat('SBSearchResults/Item_', $pos, '/Lockscreen')" />
		<xsl:with-param name="title4">
			<xsl:call-template name="GetAppName">
				<xsl:with-param name="appID" select="Identifier"/>
				<xsl:with-param name="device" select="/Root/DeviceClass"/>
			</xsl:call-template>
		</xsl:with-param>
		<xsl:with-param name="valueNode" select="Lockscreen" />
		<xsl:with-param name="template" select="'OnOff'"/>
	</xsl:call-template>

	</xsl:for-each>

    <xsl:for-each select="/Root/Notifications/Item">
      <xsl:sort select="cs:GetAppName(Identifier, /Root/DeviceClass, /Root/Applications)"/>
      <!--並び替え前の位置を取得-->
      <xsl:variable name="id" select="Identifier"/>
      <xsl:variable name="pos" select="count(/Root/Notifications/Item[./Identifier = $id]/preceding-sibling::*)+1"/>

	    <xsl:if test="(starts-with(Identifier,'com.apple.mobilecal.bulletin-subsection') 
		and /Root/Notifications/Item[./Identifier/text() = 'com.apple.mobilecal']/authorizationStatus = '2')
	or not(starts-with(Identifier,'com.apple.mobilecal.bulletin-subsection'))">
	
		<xsl:if test="(starts-with(Identifier,'com.apple.tv.bulletins.') 
		and /Root/Notifications/Item[./Identifier/text() = 'com.apple.tv']/authorizationStatus = '2')
	or not(starts-with(Identifier,'com.apple.tv.bulletins.'))">
	
		<xsl:if test="(starts-with(Identifier,'com.apple.mobileslideshow.') 
		and /Root/Notifications/Item[./Identifier/text() = 'com.apple.mobileslideshow']/authorizationStatus = '2')
	or not(starts-with(Identifier,'com.apple.mobileslideshow.'))">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/authorizationStatus')" />
            <xsl:with-param name="title2">
              <xsl:if test="position() = 1">通知スタイル</xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title3">
				<xsl:call-template name="GetAppName">
					<xsl:with-param name="appID" select="Identifier"/>
					<xsl:with-param name="device" select="/Root/DeviceClass"/>
				</xsl:call-template>
            </xsl:with-param>
            <xsl:with-param name="title4">
                  <xsl:text>通知を許可</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="authorizationStatus" />
            <xsl:with-param name="value">
			  <xsl:choose>
				<xsl:when test="authorizationStatus = '2'">
					<xsl:text>オン</xsl:text>
				</xsl:when>
				<xsl:when test="authorizationStatus = '1'">
					<xsl:text>オフ</xsl:text>
				</xsl:when>
			  </xsl:choose>
			</xsl:with-param>
          </xsl:call-template>
		  
		  
		  <xsl:if test="/Root/Notifications/Item[./Identifier = $id]/authorizationStatus = '2'">
		  
		  
			<xsl:if test="Identifier != 'com.apple.mobilecal' and 
			Identifier != 'com.apple.tv' and 
		Identifier != 'com.apple.mobileslideshow'">
			<xsl:call-template name="settingtable">
				<xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/showsInLockScreen')" />
				<xsl:with-param name="title4">
					<xsl:text>ロック画面</xsl:text>
				</xsl:with-param>
				<xsl:with-param name="valueNode" select="showsInLockScreen" />
				<xsl:with-param name="template" select="'OnOff'"/>
			</xsl:call-template>
		

			<xsl:call-template name="settingtable">
				<xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/showsInNotificationCenter')" />
				<xsl:with-param name="title4">
					<xsl:text>通知センター</xsl:text>
				</xsl:with-param>
				<xsl:with-param name="valueNode" select="showsInNotificationCenter" />
				<xsl:with-param name="template" select="'OnOff'"/>
			</xsl:call-template>

			<xsl:if test="Identifier != 'com.apple.tips'">
				<xsl:call-template name="settingtable">
					<xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/alertType')" />
					<xsl:with-param name="title4">
						<xsl:text>バナー</xsl:text>
					</xsl:with-param>
					<xsl:with-param name="valueNode" select="alertType" />
					<xsl:with-param name="value">
						<xsl:choose>
							<xsl:when test="alertType = '0'">
								<xsl:text>オフ</xsl:text>
							</xsl:when>
							<xsl:when test="alertType = '1'">
								<xsl:text>オン/一時的</xsl:text>
							</xsl:when>
							<xsl:when test="alertType = '2'">
								<xsl:text>オン/持続的</xsl:text>
							</xsl:when>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
	
 
 
		
			<xsl:if test="Identifier != 'com.apple.facetime' and 
			Identifier != 'com.apple.mobilemail' and
			Identifier != 'com.apple.tips' and
			Identifier != 'com.apple.MobileSMS' and 
			Identifier != 'com.apple.reminders' and
			Identifier != 'com.apple.Maps' and
			Identifier != 'com.apple.mobilephone' and
			Identifier != 'com.apple.mobilecal.bulletin-subsection.upcomingEvents' and
			Identifier != 'com.apple.mobilecal.bulletin-subsection.invitations' and 
			Identifier != 'com.apple.mobilecal.bulletin-subsection.Responses' and
			Identifier != 'com.apple.mobilecal.bulletin-subsection.resourceChanges' and 
			Identifier != 'com.apple.mobilecal.bulletin-subsection.suggestions'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/sound')" />
				  <xsl:with-param name="title4">
					<xsl:text>サウンド</xsl:text>
				  </xsl:with-param>
				  <xsl:with-param name="valueNode" select="sound" />
				  <xsl:with-param name="template" select="'OnOff'"/>
				</xsl:call-template>
			</xsl:if>
		
		
		
			<xsl:if test="Identifier = 'com.apple.facetime' or Identifier = 'com.apple.mobilephone'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="'ringtone'" />
				  <xsl:with-param name="title4" select="'サウンド'" />
				  <xsl:with-param name="title5" select="'着信音/通知音'" />
				  <xsl:with-param name="valueNode" select="/Root/ringtone" />
				  <xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="/Root/ringtone = ''">
							<xsl:text>オープニング</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="sound" >
								<xsl:with-param name="value" select="/Root/ringtone"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				  </xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		
			<xsl:if test="Identifier = 'com.apple.MobileSMS'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="'sms-sound-identifier'" />
				  <xsl:with-param name="title4" select="'サウンド'" />
				  <xsl:with-param name="title5" select="'着信音/通知音'" />
				  <xsl:with-param name="valueNode" select="/Root/sms-sound-identifier" />
				  <xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="/Root/sms-sound-identifier = ''">
							<xsl:text>メモ</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="sound" >
								<xsl:with-param name="value" select="/Root/sms-sound-identifier"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				  </xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		
			<xsl:if test="Identifier = 'com.apple.mobilemail'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="'newmail-sound-identifier'" />
				  <xsl:with-param name="title4" select="'サウンド'" />
				  <xsl:with-param name="title5" select="'着信音/通知音'" />
				  <xsl:with-param name="valueNode" select="/Root/newmail-sound-identifier" />
				  <xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="/Root/newmail-sound-identifier = ''">
							<xsl:text>なし</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="sound" >
								<xsl:with-param name="value" select="/Root/newmail-sound-identifier"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				  </xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		
			<xsl:if test="Identifier = 'com.apple.reminders'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="'reminderalert-sound-identifier'" />
				  <xsl:with-param name="title4" select="'サウンド'" />
				  <xsl:with-param name="title5" select="'着信音/通知音'" />
				  <xsl:with-param name="valueNode" select="/Root/reminderalert-sound-identifier" />
				  <xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="/Root/reminderalert-sound-identifier = ''">
							<xsl:text>和音</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="sound" >
								<xsl:with-param name="value" select="/Root/reminderalert-sound-identifier"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				  </xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.upcomingEvents'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="'SoundcalUpcomingEvents'" />
				  <xsl:with-param name="title4" select="'サウンド'" />
				  <xsl:with-param name="title5" select="'着信音/通知音'" />
				  <xsl:with-param name="valueNode" select="/Root/SoundcalUpcomingEvents" />
				  <xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="/Root/SoundcalUpcomingEvents = ''">
							<xsl:text>和音</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="sound" >
								<xsl:with-param name="value" select="/Root/SoundcalUpcomingEvents"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				  </xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		
			<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.invitations'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="'SoundcalInvitations'" />
				  <xsl:with-param name="title4" select="'サウンド'" />
				  <xsl:with-param name="title5" select="'着信音/通知音'" />
				  <xsl:with-param name="valueNode" select="/Root/SoundcalInvitations" />
				  <xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="/Root/SoundcalInvitations = ''">
							<xsl:text>和音</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="sound" >
								<xsl:with-param name="value" select="/Root/SoundcalInvitations"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				  </xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		
			<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.Responses'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="'SoundcalResponses'" />
				  <xsl:with-param name="title4" select="'サウンド'" />
				  <xsl:with-param name="title5" select="'着信音/通知音'" />
				  <xsl:with-param name="valueNode" select="/Root/SoundcalResponses" />
				  <xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="/Root/SoundcalResponses = ''">
							<xsl:text>和音</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="sound" >
								<xsl:with-param name="value" select="/Root/SoundcalResponses"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				  </xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		
			<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.resourceChanges'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="'SoundcalResourceChanges'" />
				  <xsl:with-param name="title4" select="'サウンド'" />
				  <xsl:with-param name="title5" select="'着信音/通知音'" />
				  <xsl:with-param name="valueNode" select="/Root/SoundcalResourceChanges" />
				  <xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="/Root/SoundcalResourceChanges = ''">
							<xsl:text>和音</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="sound" >
								<xsl:with-param name="value" select="/Root/SoundcalResourceChanges"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				  </xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="Identifier = 'com.apple.mobilecal.bulletin-subsection.suggestions'">
				<xsl:call-template name="settingtable">
				  <xsl:with-param name="id" select="'SoundcalSuggestions'" />
				  <xsl:with-param name="title4" select="'サウンド'" />
				  <xsl:with-param name="title5" select="'着信音/通知音'" />
				  <xsl:with-param name="valueNode" select="/Root/SoundcalSuggestions" />
				  <xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="/Root/SoundcalSuggestions = ''">
							<xsl:text>和音</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="sound" >
								<xsl:with-param name="value" select="/Root/SoundcalSuggestions"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				  </xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		
		
			<xsl:if test="Identifier != 'com.apple.Maps' and 
			Identifier != 'com.apple.ScreenTimeNotifications' and 
			Identifier != 'com.apple.iBooks' and 
			Identifier != 'com.apple.tips' and 
			Identifier != 'com.apple.mobileslideshow.SharingSuggestions' and 
			Identifier != 'com.apple.mobileslideshow.memories'">
			<xsl:call-template name="settingtable">
			  <xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/badge')" />
				<xsl:with-param name="title4" select="'バッジ'" />
				<xsl:with-param name="valueNode" select="badge" />
				<xsl:with-param name="template" select="'OnOff'"/>
			</xsl:call-template>
			</xsl:if>


			<xsl:call-template name="settingtable">
			  <xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/contentPreviewSetting')" />
			  <xsl:with-param name="title4">
				<xsl:text>プレビューを表示</xsl:text>
			  </xsl:with-param>
			  <xsl:with-param name="valueNode" select="contentPreviewSetting" />
			  <xsl:with-param name="value">
				<xsl:choose>
					<xsl:when test="contentPreviewSetting = '2'">
						<xsl:text>ロックされていないときのみ</xsl:text>
					</xsl:when>
					<xsl:when test="contentPreviewSetting = '3'">
						<xsl:text>しない</xsl:text>
					</xsl:when>
					<xsl:when test="contentPreviewSetting = '0'">
						<xsl:text>常に（デフォルト）</xsl:text>
					</xsl:when>
					<xsl:when test="contentPreviewSetting = '1'">
						<xsl:text>常に（デフォルト）</xsl:text>
					</xsl:when>
				</xsl:choose>
			</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		
		<xsl:if test="Identifier != 'com.apple.mobilecal.bulletin-subsection.upcomingEvents' and 
			Identifier != 'com.apple.mobilecal.bulletin-subsection.invitations' and
			Identifier != 'com.apple.mobilecal.bulletin-subsection.Responses' and
			Identifier != 'com.apple.mobilecal.bulletin-subsection.resourceChanges' and
			Identifier != 'com.apple.mobilecal.bulletin-subsection.suggestions' and 
			Identifier != 'com.apple.tv.bulletins.explicit' and
			Identifier != 'com.apple.tv.bulletins.marketing' and
			Identifier != 'com.apple.mobileslideshow.memories' and
			Identifier != 'com.apple.mobileslideshow.iCloudPhotoSharing' and
			Identifier != 'com.apple.mobileslideshow.SharingSuggestions'">
			<xsl:call-template name="settingtable">
			  <xsl:with-param name="id" select="concat('Notifications/Item_', $pos, '/bulletinGroupingSetting')" />
			  <xsl:with-param name="title4">
				<xsl:text>通知のグループ化</xsl:text>
			  </xsl:with-param>
			  <xsl:with-param name="valueNode" select="bulletinGroupingSetting" />
			  <xsl:with-param name="value">
				<xsl:choose>
					<xsl:when test="bulletinGroupingSetting = '1'">
						<xsl:text>App別</xsl:text>
					</xsl:when>
					<xsl:when test="bulletinGroupingSetting = '2'">
						<xsl:text>オフ</xsl:text>
					</xsl:when>
					<xsl:when test="bulletinGroupingSetting = '0'">
						<xsl:text>自動</xsl:text>
					</xsl:when>
				</xsl:choose>
			</xsl:with-param>
			</xsl:call-template>
			</xsl:if>
		
			<xsl:if test="Identifier = 'com.apple.MobileSMS'">
				<xsl:call-template name="settingtable">
					<xsl:with-param name="id" select="'IncomingMessageAlertCount'" />
					<xsl:with-param name="title4" select="'通知を繰り返す'" />
					<xsl:with-param name="valueNode" select="/Root/IncomingMessageAlertCount" />
					<xsl:with-param name="value">
						<xsl:choose>
							<xsl:when test="/Root/IncomingMessageAlertCount = ''">
								<xsl:text>1回</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="AlertCount" >
									<xsl:with-param name="value" select="/Root/IncomingMessageAlertCount"/>
								</xsl:call-template>
							</xsl:otherwise>
							
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
	  
			<xsl:if test="Identifier = 'com.apple.gamecenter'">
				<xsl:call-template name="settingtable">
					<xsl:with-param name="id" select="'ShowAllIncomingMessage'" />
					<xsl:with-param name="title4" select="'メールによる事後連絡'" />
					<xsl:with-param name="valueNode" select="/Root/ShowAllIncomingMessage" />
					<xsl:with-param name="template" select="'defaultOn'" />
					<xsl:with-param name="param1" select="'すべての人から通知を表示（デフォルト）'"/>
					<xsl:with-param name="param2" select="'登録済み連絡先のみ通知を表示'"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		  </xsl:if>
		</xsl:if>
		</xsl:if>
    </xsl:for-each>
  
  
  </xsl:template>

</xsl:stylesheet>