<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

  <xsl:template name="SectionSiri">

    <xsl:if test="$MajorVersion = 12">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'SiriMyShortcuts'" />
        <xsl:with-param name="title1">
          <xsl:if test="$MajorVersion &gt;= 12">
            <xsl:text>Siriと検索</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title2" select="'SIRIショートカット'" />
        <xsl:with-param name="title3" select="'マイショートカット'" />
        <xsl:with-param name="valueNode" select="/Root/SiriMyShortcuts" />
        <xsl:with-param name="value" select="'[ショートカットの内容をチェック]'" />
      </xsl:call-template>

      <xsl:for-each select="/Root/SiriMyShortcuts/string">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'hide_part'" />
          <xsl:with-param name="title4">
            <xsl:text>ショートカット(</xsl:text>
            <xsl:value-of select="position()"/>
            <xsl:text>)</xsl:text>
          </xsl:with-param>
          <xsl:with-param name="value">
            <xsl:value-of select="./text()"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:for-each>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 7">

      <xsl:variable name="AssistantEnabled">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AssistantEnabled'" />
          <xsl:with-param name="title1">
            <xsl:if test="$MajorVersion = 10">
              <xsl:text>Siri</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title2" >
            <xsl:if test="$MajorVersion &lt; 10">
              <xsl:text>Siri</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/AssistantEnabled" />
          <xsl:with-param name="value">
            <xsl:call-template name="defaultOff">
              <xsl:with-param name="bool" select="/Root/AssistantEnabled"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:variable>

      <xsl:variable name="HomeButtonAssistant">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'HomeButtonAssistant'" />
          <xsl:with-param name="title2" >
            <xsl:text>ホームボタンを押してSiriを使用</xsl:text>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/HomeButtonAssistant" />
          <xsl:with-param name="value">
            <xsl:call-template name="defaultOff">
              <xsl:with-param name="bool" select="/Root/HomeButtonAssistant"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:variable>


      <xsl:variable name="VoiceTriggerEnabled">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'VoiceTriggerEnabled'" />
          <xsl:with-param name="title1">
            <xsl:if test="$MajorVersion = 11 or $MajorVersion &gt;= 13">
              <xsl:text>Siriと検索</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title2">
            <xsl:if test="$MajorVersion = 10">
              <xsl:text>”Hey Siri”を許可</xsl:text>
            </xsl:if>
            <xsl:if test="$MajorVersion &gt;= 11">
              <xsl:text>”Hey Siri”を聞き取る</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title3" >
            <xsl:if test="$MajorVersion &lt; 10">
              <xsl:text>”Hey Siri”を許可</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/VoiceTriggerEnabled" />
          <xsl:with-param name="template" select="'defaultOff'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:if test="$MajorVersion &lt;= 10">
        <xsl:copy-of select="$AssistantEnabled"/>
      </xsl:if>
      <xsl:if test="$MajorVersion &gt;= 11">
        <xsl:copy-of select="$VoiceTriggerEnabled"/>
        <xsl:copy-of select="$HomeButtonAssistant"/>
      </xsl:if>




      <xsl:if test="/Root/AssistantEnabled = 'true'">
        <xsl:if test="$MajorVersion &gt;= 10">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'allowAssistantWhileLocked'" />
            <xsl:with-param name="title2">
              <xsl:if test="$MajorVersion = 10">
                <xsl:text>ロック画面でのアクセス</xsl:text>
              </xsl:if>
              <xsl:if test="$MajorVersion &gt;= 11">
                <xsl:text>ロック中にSiriを許可</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/allowAssistantWhileLocked" />
            <xsl:with-param name="template" select="'OnOff'"/>
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:copy-of select="$VoiceTriggerEnabled"/>
        </xsl:if>

        <xsl:if test="$MajorVersion &lt;= 7">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'AssistantLanguage'" />
			<xsl:with-param name="title2">
              <xsl:if test="$MajorVersion &gt;= 14">
                <xsl:text>言語</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title3" >
              <xsl:if test="$MajorVersion &lt; 7">
                <xsl:text>言語</xsl:text>
              </xsl:if>
			</xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/AssistantLanguage" />
            <xsl:with-param name="value">
              <xsl:choose>
                <xsl:when test="/Root/AssistantLanguage = ''">
                  <xsl:text>日本語</xsl:text>
                </xsl:when>
                <xsl:when test="/Root/AssistantLanguage">
                  <xsl:call-template name="language3" >
                    <xsl:with-param name="countrycode" select="/Root/AssistantLanguage"/>
                  </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>日本語</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 8 and $MajorVersion &lt;= 13">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'AssistantLanguage8'" />
            <xsl:with-param name="title2">
              <xsl:if test="$MajorVersion &gt;= 10">
                <xsl:text>言語</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title3" >
              <xsl:if test="$MajorVersion &lt; 10">
                <xsl:text>言語</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/AssistantLanguage8" />
            <xsl:with-param name="value">
              <xsl:choose>
                <xsl:when test="/Root/AssistantLanguage8 = ''">
                  <xsl:text>英語</xsl:text>
                </xsl:when>
                <xsl:when test="/Root/AssistantLanguage8">
                  <xsl:call-template name="language3" >
                    <xsl:with-param name="countrycode" select="/Root/AssistantLanguage8"/>
                  </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>英語</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>
		
		 <xsl:if test="$MajorVersion &gt;= 14">
			<xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'Sirilanguagepattern'" />
			<xsl:with-param name="title2">
                <xsl:text>言語</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/Sirilanguagepattern" />
            <xsl:with-param name="value">
              <xsl:choose>
                <xsl:when test="/Root/Sirilanguagepattern = ''">
                  <xsl:text>日本語</xsl:text>
                </xsl:when>
                <xsl:when test="/Root/Sirilanguagepattern">
                  <xsl:call-template name="language3" >
                    <xsl:with-param name="countrycode" select="/Root/Sirilanguagepattern"/>
                  </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>日本語</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
          </xsl:call-template>
		
		</xsl:if>
		

        <xsl:if test="$MajorVersion &lt;= 7">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'AssistantGender'" />
            <xsl:with-param name="title3" select="'声の性別'" />
            <xsl:with-param name="valueNode" select="/Root/AssistantGender" />
            <xsl:with-param name="value">
              <xsl:call-template name="Gender" >
                <xsl:with-param name="value" select="/Root/AssistantGender"/>
              </xsl:call-template>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 8">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'AssistantGender8'" />
            <xsl:with-param name="title2">
              <xsl:if test="$MajorVersion &gt;= 9">
                <xsl:text>Siriの声</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title3" >
              <xsl:if test="$MajorVersion &lt; 9">
                <xsl:text>声の性別</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/AssistantGender8" />
            <xsl:with-param name="value">
              <xsl:call-template name="Gender" >
                <xsl:with-param name="value" select="/Root/AssistantGender8"/>
              </xsl:call-template>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="$MajorVersion &lt;= 10">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'HandsFreeMode'" />
            <xsl:with-param name="title2">
              <xsl:if test="$MajorVersion = 10">
                <xsl:text>音声フィードバック</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title3" >
              <xsl:if test="$MajorVersion &lt; 10">
                <xsl:text>音声フィードバック</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/HandsFreeMode" />
            <xsl:with-param name="value">
              <xsl:call-template name="HandsFreeMode" >
                <xsl:with-param name="value" select="/Root/HandsFreeMode"/>
              </xsl:call-template>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 11 and $MajorVersion &lt; 14">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'UsedevicespeakerforTTS'" />
            <xsl:with-param name="title2">
              <xsl:text>音声フィードバック</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/UsedevicespeakerforTTS" />
            <xsl:with-param name="value">
              <xsl:call-template name="SiriAudioFeedback" >
                <xsl:with-param name="value" select="/Root/UsedevicespeakerforTTS"/>
              </xsl:call-template>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>
		
	  <xsl:if test="/Root/HomeButtonAssistant = 'true' or /Root/VoiceTriggerEnabled = 'true'">
		<xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'UsedevicespeakerforSiri'" />
		<xsl:with-param name="title2" select="'Siriの応答'" />
		<xsl:with-param name="title3" select="'応答の読み上げ'" />
		<xsl:with-param name="valueNode" select="/Root/UsedevicespeakerforSiri" />
        <xsl:with-param name="value">
		<xsl:choose>
			<xsl:when test="/Root/UsedevicespeakerforSiri = '1'">
				<xsl:text>消音モードがオフの時</xsl:text>
			</xsl:when>
			<xsl:when test="/Root/UsedevicespeakerforSiri = '2'">
				<xsl:text>常に</xsl:text>
			</xsl:when>
			<xsl:when test="/Root/UsedevicespeakerforSiri = '3'">
				<xsl:text>"Hey Siri"使用時のみ</xsl:text>
			</xsl:when>
			<xsl:when test="/Root/UsedevicespeakerforSiri = ''">
				<xsl:text>消音モードがオフの時</xsl:text>
			</xsl:when>
		</xsl:choose>
		</xsl:with-param>
	  </xsl:call-template>
	
	  <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AlwaysPrintSiriResponse'" />
        <xsl:with-param name="title3" select="'Siriキャプションを常に表示'" />
        <xsl:with-param name="valueNode" select="/Root/AlwaysPrintSiriResponse" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	  </xsl:call-template>
	
	  <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AlwaysShowRecognizedSpeech'" />
        <xsl:with-param name="title3" select="'話した内容を常に表示'" />
        <xsl:with-param name="valueNode" select="/Root/AlwaysShowRecognizedSpeech" />
        <xsl:with-param name="template" select="'defaultOff'"/>
	  </xsl:call-template>
    </xsl:if>

        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AssitantMyInfo'" />
          <xsl:with-param name="title2">
            <xsl:if test="$MajorVersion &gt;= 10">
              <xsl:text>自分の情報</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title3" >
            <xsl:if test="$MajorVersion &lt; 10">
              <xsl:text>自分の情報</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/AssitantMyInfo" />
          <xsl:with-param name="value">
            <xsl:choose>
			<xsl:when test="/Root/AssitantMyInfo = ''">
				<xsl:text>なし</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				 <xsl:value-of select="/Root/AssitantMyInfo/text()"/>
			</xsl:otherwise>
		</xsl:choose>
          </xsl:with-param>
        </xsl:call-template>

        <xsl:if test="/Root/DeviceClass = 'iPhone' and $MajorVersion &lt; 8">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'GestureServiceEnabled'" />
            <xsl:with-param name="title3" >
              <xsl:text>耳にあてて話す</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/GestureServiceEnabled" />
            <xsl:with-param name="value">
              <xsl:call-template name="ZeroOffOneOn" >
                <xsl:with-param name="value" select="/Root/GestureServiceEnabled"/>
              </xsl:call-template>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>
      </xsl:if>
    </xsl:if>

  </xsl:template>

</xsl:stylesheet>